@@ -19,7 +19,6 @@ except ImportError:
 import pytest
 
 from astropy import __version__
-from astropy.tests.helper import enable_deprecations_as_exceptions
 
 # This is needed to silence a warning from matplotlib caused by
 # PyInstaller's matplotlib runtime hook.  This can be removed once the
@@ -38,13 +37,6 @@ from astropy.utils.compat.optional_deps import HAS_MATPLOTLIB
 if HAS_MATPLOTLIB:
     import matplotlib
 
-enable_deprecations_as_exceptions(
-    include_astropy_deprecations=False,
-    # This is a workaround for the OpenSSL deprecation warning that comes from
-    # the `requests` module. It only appears when both asdf and sphinx are
-    # installed. This can be removed once pyopenssl 1.7.20+ is released.
-    modules_to_ignore_on_import=['requests'])
-
 matplotlibrc_cache = {}
 
 
