@@ -7,7 +7,6 @@ import numpy as np
 
 from astropy.constants import Constant
 from astropy.units import Quantity as Q
-from astropy.utils.exceptions import AstropyDeprecationWarning
 
 
 def test_c():
@@ -187,25 +186,3 @@ def test_view():
 
     c4 = Q(c, subok=True, copy=False)
     assert c4 is c
-
-
-def test_context_manager():
-    from astropy import constants as const
-
-    with pytest.warns(AstropyDeprecationWarning,
-                      match="Use 'astropy.physical_constants'"):
-        with const.set_enabled_constants('astropyconst13'):
-            assert const.h.value == 6.62606957e-34  # CODATA2010
-
-    with pytest.warns(AstropyDeprecationWarning,
-                      match="Use 'astropy.physical_constants'"):
-        with const.set_enabled_constants('astropyconst20'):
-            assert const.h.value == 6.626070040e-34  # CODATA2014
-
-    assert const.h.value == 6.62607015e-34  # CODATA2018
-
-    with pytest.raises(ImportError):
-        with pytest.warns(AstropyDeprecationWarning,
-                          match="Use 'astropy.physical_constants'"):
-            with const.set_enabled_constants('notreal'):
-                const.h
