@@ -3,9 +3,9 @@
 
 from .core import *  # noqa
 from .kernels import *  # noqa
-from .utils import discretize_model  # noqa
+from .utils import discretize_model, KernelSizeError  # noqa
 
-from .convolve import convolve, convolve_fft, interpolate_replace_nans, convolve_models  # noqa
+from .convolve import convolve, convolve_fft, interpolate_replace_nans, convolve_models, convolve_models_fft  # noqa
 
 # Deprecated kernels that are not defined in __all__
 from .kernels import MexicanHat1DKernel, MexicanHat2DKernel
