@@ -3,12 +3,12 @@
 import pytest
 import numpy as np
 import numpy.ma as ma
+from contextlib import nullcontext
 
 from astropy.convolution.convolve import convolve, convolve_fft
 from astropy.convolution.kernels import Gaussian2DKernel
 from astropy.utils.exceptions import AstropyUserWarning
 from astropy import units as u
-from astropy.utils.compat.context import nullcontext
 from astropy.utils.compat.optional_deps import HAS_SCIPY, HAS_PANDAS  # noqa
 
 from numpy.testing import (assert_array_almost_equal_nulp,
@@ -134,7 +134,7 @@ class TestConvolve1D:
                      normalize_kernel=normalize_kernel, preserve_nan=preserve_nan)
 
         # ( NaN == NaN ) = False
-        # Only compare non NaN values for canonical equivalance
+        # Only compare non NaN values for canonical equivalence
         # and then check NaN explicitly with np.isnan()
         array_is_nan = np.isnan(array)
         kernel_is_nan = np.isnan(kernel)
@@ -1007,3 +1007,13 @@ def test_regressiontest_issue9168():
                           preserve_nan=True)
     result = convolve(x, kernel, boundary='fill', fill_value=np.nan,
                       preserve_nan=True)
+
+
+def test_convolve_nan_zero_sum_kernel():
+    with pytest.raises(ValueError,
+                      match="Setting nan_treatment='interpolate' "
+                      "requires the kernel to be normalized, but the "
+                      "input kernel has a sum close to zero. For a "
+                      "zero-sum kernel and data with NaNs, set "
+                      "nan_treatment='fill'."):
+        convolve([1, np.nan, 3], [-1, 2, -1], normalize_kernel=False)
