@@ -1,6 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 import itertools
+from contextlib import nullcontext
 
 import pytest
 import numpy as np
@@ -9,7 +10,6 @@ from numpy.testing import assert_allclose, assert_array_equal, assert_array_almo
 from astropy.convolution.convolve import convolve_fft, convolve
 from astropy.utils.exceptions import AstropyUserWarning
 from astropy import units as u
-from astropy.utils.compat.context import nullcontext
 
 VALID_DTYPES = ('>f4', '<f4', '>f8', '<f8')
 VALID_DTYPE_MATRIX = list(itertools.product(VALID_DTYPES, VALID_DTYPES))
@@ -31,10 +31,11 @@ Convolved with [0, 1] = [0, 1, 2, 3, 4]
 """
 
 # NOTE: use_numpy_fft is redundant if you don't have FFTW installed
-option_names = ('boundary', 'nan_treatment', 'normalize_kernel')
+option_names = ('boundary', 'nan_treatment', 'normalize_kernel', 'dealias')
 options = list(itertools.product(BOUNDARY_OPTIONS,
                                  NANTREATMENT_OPTIONS,
                                  (True, False),
+                                 (True, False)
                                  ))
 option_names_preserve_nan = ('boundary', 'nan_treatment',
                              'normalize_kernel', 'preserve_nan')
@@ -56,6 +57,17 @@ def expected_boundary_warning(boundary=None):
     return ctx
 
 
+def expected_dealias_error(boundary=None, dealias=False):
+    # Helper that returns the appropriate context manager for the boundary=None
+    # warning depending on the value of boundary.
+
+    if dealias and boundary == 'wrap':
+        ctx = pytest.raises(ValueError)
+    else:
+        ctx = nullcontext()
+    return ctx
+
+
 def assert_floatclose(x, y):
     """Assert arrays are close to within expected floating point rounding.
 
@@ -71,7 +83,7 @@ def assert_floatclose(x, y):
 class TestConvolve1D:
 
     @pytest.mark.parametrize(option_names, options)
-    def test_quantity(self, boundary, nan_treatment, normalize_kernel):
+    def test_quantity(self, boundary, nan_treatment, normalize_kernel, dealias):
         """
         Test that convolve_fft works correctly when input array is a Quantity
         """
@@ -80,14 +92,16 @@ class TestConvolve1D:
         y = np.array([0.2, 0.6, 0.2], dtype='float64')
 
         with expected_boundary_warning(boundary=boundary):
-            z = convolve_fft(x, y, boundary=boundary,
-                             nan_treatment=nan_treatment,
-                             normalize_kernel=normalize_kernel)
+            with expected_dealias_error(boundary=boundary, dealias=dealias):
+                z = convolve_fft(x, y, boundary=boundary,
+                                 nan_treatment=nan_treatment,
+                                 normalize_kernel=normalize_kernel,
+                                 dealias=dealias)
 
-        assert x.unit == z.unit
+                assert x.unit == z.unit
 
     @pytest.mark.parametrize(option_names, options)
-    def test_unity_1_none(self, boundary, nan_treatment, normalize_kernel):
+    def test_unity_1_none(self, boundary, nan_treatment, normalize_kernel, dealias):
         '''
         Test that a unit kernel with a single element returns the same array
         '''
@@ -97,14 +111,16 @@ class TestConvolve1D:
         y = np.array([1.], dtype='float64')
 
         with expected_boundary_warning(boundary=boundary):
-            z = convolve_fft(x, y, boundary=boundary,
-                             nan_treatment=nan_treatment,
-                             normalize_kernel=normalize_kernel)
+            with expected_dealias_error(boundary=boundary, dealias=dealias):
+                z = convolve_fft(x, y, boundary=boundary,
+                                 nan_treatment=nan_treatment,
+                                 normalize_kernel=normalize_kernel,
+                                 dealias=dealias)
 
-        assert_floatclose(z, x)
+                assert_floatclose(z, x)
 
     @pytest.mark.parametrize(option_names, options)
-    def test_unity_3(self, boundary, nan_treatment, normalize_kernel):
+    def test_unity_3(self, boundary, nan_treatment, normalize_kernel, dealias):
         '''
         Test that a unit kernel with three elements returns the same array
         (except when boundary is None).
@@ -115,14 +131,16 @@ class TestConvolve1D:
         y = np.array([0., 1., 0.], dtype='float64')
 
         with expected_boundary_warning(boundary=boundary):
-            z = convolve_fft(x, y, boundary=boundary,
-                             nan_treatment=nan_treatment,
-                             normalize_kernel=normalize_kernel)
+            with expected_dealias_error(boundary=boundary, dealias=dealias):
+                z = convolve_fft(x, y, boundary=boundary,
+                                 nan_treatment=nan_treatment,
+                                 normalize_kernel=normalize_kernel,
+                                 dealias=dealias)
 
-        assert_floatclose(z, x)
+                assert_floatclose(z, x)
 
     @pytest.mark.parametrize(option_names, options)
-    def test_uniform_3(self, boundary, nan_treatment, normalize_kernel):
+    def test_uniform_3(self, boundary, nan_treatment, normalize_kernel, dealias):
         '''
         Test that the different modes are producing the correct results using
         a uniform kernel with three elements
@@ -133,36 +151,38 @@ class TestConvolve1D:
         y = np.array([1., 1., 1.], dtype='float64')
 
         with expected_boundary_warning(boundary=boundary):
-            z = convolve_fft(x, y, boundary=boundary,
-                             nan_treatment=nan_treatment,
-                             normalize_kernel=normalize_kernel)
+            with expected_dealias_error(boundary=boundary, dealias=dealias):
+                z = convolve_fft(x, y, boundary=boundary,
+                                 nan_treatment=nan_treatment,
+                                 normalize_kernel=normalize_kernel,
+                                 dealias=dealias)
 
-        answer_key = (boundary, nan_treatment, normalize_kernel)
+                answer_key = (boundary, nan_treatment, normalize_kernel)
 
-        answer_dict = {
-            'sum_fill_zeros': np.array([1., 4., 3.], dtype='float64'),
-            'average_fill_zeros': np.array([1 / 3., 4 / 3., 1.], dtype='float64'),
-            'sum_wrap': np.array([4., 4., 4.], dtype='float64'),
-            'average_wrap': np.array([4 / 3., 4 / 3., 4 / 3.], dtype='float64'),
-        }
+                answer_dict = {
+                    'sum_fill_zeros': np.array([1., 4., 3.], dtype='float64'),
+                    'average_fill_zeros': np.array([1 / 3., 4 / 3., 1.], dtype='float64'),
+                    'sum_wrap': np.array([4., 4., 4.], dtype='float64'),
+                    'average_wrap': np.array([4 / 3., 4 / 3., 4 / 3.], dtype='float64'),
+                }
 
-        result_dict = {
-            # boundary, nan_treatment, normalize_kernel
-            ('fill', 'interpolate', True): answer_dict['average_fill_zeros'],
-            ('wrap', 'interpolate', True): answer_dict['average_wrap'],
-            ('fill', 'interpolate', False): answer_dict['sum_fill_zeros'],
-            ('wrap', 'interpolate', False): answer_dict['sum_wrap'],
-        }
-        for k in list(result_dict.keys()):
-            result_dict[(k[0], 'fill', k[2])] = result_dict[k]
-        for k in list(result_dict.keys()):
-            if k[0] == 'fill':
-                result_dict[(None, k[1], k[2])] = result_dict[k]
+                result_dict = {
+                    # boundary, nan_treatment, normalize_kernel
+                    ('fill', 'interpolate', True): answer_dict['average_fill_zeros'],
+                    ('wrap', 'interpolate', True): answer_dict['average_wrap'],
+                    ('fill', 'interpolate', False): answer_dict['sum_fill_zeros'],
+                    ('wrap', 'interpolate', False): answer_dict['sum_wrap'],
+                }
+                for k in list(result_dict.keys()):
+                    result_dict[(k[0], 'fill', k[2])] = result_dict[k]
+                for k in list(result_dict.keys()):
+                    if k[0] == 'fill':
+                        result_dict[(None, k[1], k[2])] = result_dict[k]
 
-        assert_floatclose(z, result_dict[answer_key])
+                assert_floatclose(z, result_dict[answer_key])
 
     @pytest.mark.parametrize(option_names, options)
-    def test_halfity_3(self, boundary, nan_treatment, normalize_kernel):
+    def test_halfity_3(self, boundary, nan_treatment, normalize_kernel, dealias):
         '''
         Test that the different modes are producing the correct results using
         a uniform, non-unity kernel with three elements
@@ -173,33 +193,35 @@ class TestConvolve1D:
         y = np.array([0.5, 0.5, 0.5], dtype='float64')
 
         with expected_boundary_warning(boundary=boundary):
-            z = convolve_fft(x, y, boundary=boundary,
-                             nan_treatment=nan_treatment,
-                             normalize_kernel=normalize_kernel)
+            with expected_dealias_error(boundary=boundary, dealias=dealias):
+                z = convolve_fft(x, y, boundary=boundary,
+                                 nan_treatment=nan_treatment,
+                                 normalize_kernel=normalize_kernel,
+                                 dealias=dealias)
 
-        answer_dict = {
-            'sum': np.array([0.5, 2.0, 1.5], dtype='float64'),
-            'sum_zeros': np.array([0.5, 2., 1.5], dtype='float64'),
-            'sum_nozeros': np.array([0.5, 2., 1.5], dtype='float64'),
-            'average': np.array([1 / 3., 4 / 3., 1.], dtype='float64'),
-            'sum_wrap': np.array([2., 2., 2.], dtype='float64'),
-            'average_wrap': np.array([4 / 3., 4 / 3., 4 / 3.], dtype='float64'),
-            'average_zeros': np.array([1 / 3., 4 / 3., 1.], dtype='float64'),
-            'average_nozeros': np.array([0.5, 4 / 3., 1.5], dtype='float64'),
-        }
+                answer_dict = {
+                    'sum': np.array([0.5, 2.0, 1.5], dtype='float64'),
+                    'sum_zeros': np.array([0.5, 2., 1.5], dtype='float64'),
+                    'sum_nozeros': np.array([0.5, 2., 1.5], dtype='float64'),
+                    'average': np.array([1 / 3., 4 / 3., 1.], dtype='float64'),
+                    'sum_wrap': np.array([2., 2., 2.], dtype='float64'),
+                    'average_wrap': np.array([4 / 3., 4 / 3., 4 / 3.], dtype='float64'),
+                    'average_zeros': np.array([1 / 3., 4 / 3., 1.], dtype='float64'),
+                    'average_nozeros': np.array([0.5, 4 / 3., 1.5], dtype='float64'),
+                }
 
-        if normalize_kernel:
-            answer_key = 'average'
-        else:
-            answer_key = 'sum'
+                if normalize_kernel:
+                    answer_key = 'average'
+                else:
+                    answer_key = 'sum'
 
-        if boundary == 'wrap':
-            answer_key += '_wrap'
-        else:
-            # average = average_zeros; sum = sum_zeros
-            answer_key += '_zeros'
+                if boundary == 'wrap':
+                    answer_key += '_wrap'
+                else:
+                    # average = average_zeros; sum = sum_zeros
+                    answer_key += '_zeros'
 
-        assert_floatclose(z, answer_dict[answer_key])
+                assert_floatclose(z, answer_dict[answer_key])
 
     @pytest.mark.parametrize(option_names_preserve_nan, options_preserve_nan)
     def test_unity_3_withnan(self, boundary, nan_treatment, normalize_kernel,
@@ -418,7 +440,8 @@ class TestConvolve1D:
     @pytest.mark.parametrize(option_names, options)
     def test_normalization_is_respected(self, boundary,
                                         nan_treatment,
-                                        normalize_kernel):
+                                        normalize_kernel,
+                                        dealias):
         """
         Check that if normalize_kernel is False then the normalization
         tolerance is respected.
@@ -450,7 +473,7 @@ class TestConvolve1D:
 class TestConvolve2D:
 
     @pytest.mark.parametrize(option_names, options)
-    def test_unity_1x1_none(self, boundary, nan_treatment, normalize_kernel):
+    def test_unity_1x1_none(self, boundary, nan_treatment, normalize_kernel, dealias):
         '''
         Test that a 1x1 unit kernel returns the same array
         '''
@@ -462,14 +485,16 @@ class TestConvolve2D:
         y = np.array([[1.]], dtype='float64')
 
         with expected_boundary_warning(boundary=boundary):
-            z = convolve_fft(x, y, boundary=boundary,
-                             nan_treatment=nan_treatment,
-                             normalize_kernel=normalize_kernel)
+            with expected_dealias_error(boundary=boundary, dealias=dealias):
+                z = convolve_fft(x, y, boundary=boundary,
+                                 nan_treatment=nan_treatment,
+                                 normalize_kernel=normalize_kernel,
+                                 dealias=dealias)
 
-        assert_floatclose(z, x)
+                assert_floatclose(z, x)
 
     @pytest.mark.parametrize(option_names, options)
-    def test_unity_3x3(self, boundary, nan_treatment, normalize_kernel):
+    def test_unity_3x3(self, boundary, nan_treatment, normalize_kernel, dealias):
         '''
         Test that a 3x3 unit kernel returns the same array (except when
         boundary is None).
@@ -484,14 +509,16 @@ class TestConvolve2D:
                       [0., 0., 0.]], dtype='float64')
 
         with expected_boundary_warning(boundary=boundary):
-            z = convolve_fft(x, y, boundary=boundary,
-                             nan_treatment=nan_treatment,
-                             normalize_kernel=normalize_kernel)
+            with expected_dealias_error(boundary=boundary, dealias=dealias):
+                z = convolve_fft(x, y, boundary=boundary,
+                                 nan_treatment=nan_treatment,
+                                 normalize_kernel=normalize_kernel,
+                                 dealias=dealias)
 
-        assert_floatclose(z, x)
+                assert_floatclose(z, x)
 
     @pytest.mark.parametrize(option_names, options)
-    def test_uniform_3x3(self, boundary, nan_treatment, normalize_kernel):
+    def test_uniform_3x3(self, boundary, nan_treatment, normalize_kernel, dealias):
         '''
         Test that the different modes are producing the correct results using
         a 3x3 uniform kernel.
@@ -506,39 +533,41 @@ class TestConvolve2D:
                       [1., 1., 1.]], dtype='float64')
 
         with expected_boundary_warning(boundary=boundary):
-            z = convolve_fft(x, y, boundary=boundary,
-                             nan_treatment=nan_treatment,
-                             fill_value=np.nan if normalize_kernel else 0,
-                             normalize_kernel=normalize_kernel)
+            with expected_dealias_error(boundary=boundary, dealias=dealias):
+                z = convolve_fft(x, y, boundary=boundary,
+                                 nan_treatment=nan_treatment,
+                                 fill_value=np.nan if normalize_kernel else 0,
+                                 normalize_kernel=normalize_kernel,
+                                 dealias=dealias)
 
-        w = np.array([[4., 6., 4.],
-                      [6., 9., 6.],
-                      [4., 6., 4.]], dtype='float64')
-        answer_dict = {
-            'sum': np.array([[1., 4., 3.],
-                             [3., 6., 5.],
-                             [3., 3., 2.]], dtype='float64'),
-            'sum_wrap': np.array([[6., 6., 6.],
-                                  [6., 6., 6.],
-                                  [6., 6., 6.]], dtype='float64'),
-        }
-        answer_dict['average'] = answer_dict['sum'] / w
-        answer_dict['average_wrap'] = answer_dict['sum_wrap'] / 9.
-        answer_dict['average_withzeros'] = answer_dict['sum'] / 9.
-        answer_dict['sum_withzeros'] = answer_dict['sum']
+                w = np.array([[4., 6., 4.],
+                              [6., 9., 6.],
+                              [4., 6., 4.]], dtype='float64')
+                answer_dict = {
+                    'sum': np.array([[1., 4., 3.],
+                                     [3., 6., 5.],
+                                     [3., 3., 2.]], dtype='float64'),
+                    'sum_wrap': np.array([[6., 6., 6.],
+                                          [6., 6., 6.],
+                                          [6., 6., 6.]], dtype='float64'),
+                }
+                answer_dict['average'] = answer_dict['sum'] / w
+                answer_dict['average_wrap'] = answer_dict['sum_wrap'] / 9.
+                answer_dict['average_withzeros'] = answer_dict['sum'] / 9.
+                answer_dict['sum_withzeros'] = answer_dict['sum']
 
-        if normalize_kernel:
-            answer_key = 'average'
-        else:
-            answer_key = 'sum'
+                if normalize_kernel:
+                    answer_key = 'average'
+                else:
+                    answer_key = 'sum'
 
-        if boundary == 'wrap':
-            answer_key += '_wrap'
-        elif nan_treatment == 'fill':
-            answer_key += '_withzeros'
+                if boundary == 'wrap':
+                    answer_key += '_wrap'
+                elif nan_treatment == 'fill':
+                    answer_key += '_withzeros'
 
-        a = answer_dict[answer_key]
-        assert_floatclose(z, a)
+                a = answer_dict[answer_key]
+                assert_floatclose(z, a)
 
     @pytest.mark.parametrize(option_names_preserve_nan, options_preserve_nan)
     def test_unity_3x3_withnan(self, boundary, nan_treatment,
@@ -813,3 +842,29 @@ def test_input_unmodified_with_nan(boundary, nan_treatment,
     assert np.all(y_copy[kernel_not_nan] == y[kernel_not_nan])
     assert np.all(np.isnan(x[array_is_nan]))
     assert np.all(np.isnan(y[kernel_is_nan]))
+
+
+@pytest.mark.parametrize('error_kwarg', [{'psf_pad': True}, {'fft_pad': True}, {'dealias': True}])
+def test_convolve_fft_boundary_wrap_error(error_kwarg):
+    x = np.array([[1., 2., 3.],
+                  [4., 5., 6.],
+                  [7., 8., 9.]], dtype='>f8')
+    y = np.array([[1.]], dtype='>f8')
+    assert (convolve_fft(x, y, boundary='wrap') == x).all()
+
+    with pytest.raises(ValueError) as err:
+        convolve_fft(x, y, boundary='wrap', **error_kwarg)
+    assert str(err.value) == \
+        f"With boundary='wrap', {list(error_kwarg.keys())[0]} cannot be enabled."
+
+
+def test_convolve_fft_boundary_extend_error():
+    x = np.array([[1., 2., 3.],
+                  [4., 5., 6.],
+                  [7., 8., 9.]], dtype='>f8')
+    y = np.array([[1.]], dtype='>f8')
+
+    with pytest.raises(NotImplementedError) as err:
+        convolve_fft(x, y, boundary='extend')
+    assert str(err.value) == \
+        "The 'extend' option is not implemented for fft-based convolution"
