@@ -4,7 +4,7 @@ import numpy as np
 
 from astropy.modeling.core import FittableModel, custom_model
 
-__all__ = ['discretize_model']
+__all__ = ['discretize_model', 'KernelSizeError']
 
 
 class DiscretizationError(Exception):
