@@ -17,7 +17,7 @@ class ITRS(BaseCoordinateFrame):
     (ITRS).  This is approximately a geocentric system, although strictly it is
     defined by a series of reference locations near the surface of the Earth.
     For more background on the ITRS, see the references provided in the
-    :ref:`astropy-coordinates-seealso` section of the documentation.
+    :ref:`astropy:astropy-coordinates-seealso` section of the documentation.
     """
 
     default_representation = CartesianRepresentation
