@@ -417,9 +417,9 @@ class SkyCoord(ShapedLikeNDArray):
         method : str or callable
             If str, it is the name of a method that is applied to the internal
             ``components``. If callable, the function is applied.
-        args : tuple
+        *args
             Any positional arguments for ``method``.
-        kwargs : dict
+        **kwargs : dict
             Any keyword arguments for ``method``.
         """
         def apply_method(value):
@@ -971,7 +971,7 @@ class SkyCoord(ShapedLikeNDArray):
         style : {'hmsdms', 'dms', 'decimal'}
             The formatting specification to use. These encode the three most
             common ways to represent coordinates. The default is `decimal`.
-        kwargs
+        **kwargs
             Keyword args passed to :meth:`~astropy.coordinates.Angle.to_string`.
         """
 
@@ -1225,8 +1225,10 @@ class SkyCoord(ShapedLikeNDArray):
 
         See Also
         --------
-        separation : for the *total* angular offset (not broken out into components).
-        position_angle : for the direction of the offset.
+        separation :
+            for the *total* angular offset (not broken out into components).
+        position_angle :
+            for the direction of the offset.
 
         """
         if not self.is_equivalent_frame(tocoord):
@@ -1589,7 +1591,6 @@ class SkyCoord(ShapedLikeNDArray):
 
         Examples
         --------
-
         >>> c1 = SkyCoord(0*u.deg, 0*u.deg)
         >>> c2 = SkyCoord(1*u.deg, 0*u.deg)
         >>> c1.position_angle(c2).degree
@@ -1750,13 +1751,13 @@ class SkyCoord(ShapedLikeNDArray):
             Optional.  The image associated with the wcs object that the cooordinate
             is being checked against. If not given the naxis keywords will be used
             to determine if the coordinate falls within the wcs footprint.
-        **kwargs :
-           Additional arguments to pass to `~astropy.coordinates.SkyCoord.to_pixel`
+        **kwargs
+            Additional arguments to pass to `~astropy.coordinates.SkyCoord.to_pixel`
 
         Returns
         -------
         response : bool
-           True means the WCS footprint contains the coordinate, False means it does not.
+            True means the WCS footprint contains the coordinate, False means it does not.
         """
 
         if image is not None:
@@ -2102,7 +2103,7 @@ class SkyCoord(ShapedLikeNDArray):
             The name of the object to get coordinates for, e.g. ``'M42'``.
         frame : str or `BaseCoordinateFrame` class or instance
             The frame to transform the object to.
-        parse: bool
+        parse : bool
             Whether to attempt extracting the coordinates from the name by
             parsing with a regex. For objects catalog names that have
             J-coordinates embedded in their names, e.g.,
