@@ -126,6 +126,10 @@ def test_distances_scipy():
     with pytest.raises(ValueError):
         Distance()
 
+    # Regression test for #12531
+    with pytest.raises(ValueError, match='more than one'):
+        Distance(z=0.23, parallax=1*u.mas)
+
     # vectors!  regression test for #11949
     d4 = Distance(z=[0.23, 0.45])  # as of writing, Planck18
     npt.assert_allclose(d4.z, [0.23, 0.45], rtol=1e-8)
@@ -237,6 +241,11 @@ def test_parallax():
     with pytest.warns(AstropyWarning):
         Distance(parallax=[10, 1, -1] * u.mas, allow_negative=True)
 
+    # Regression test for #12569; `unit` was ignored if `parallax` was given.
+    d = Distance(parallax=1*u.mas, unit=u.kpc)
+    assert d.value == 1.
+    assert d.unit is u.kpc
+
 
 def test_distance_in_coordinates():
     """
