@@ -155,7 +155,8 @@ def test_name_resolve_cache(tmpdir):
 
         urls = get_cached_urls()
         assert len(urls) == 1
-        assert 'http://cdsweb.u-strasbg.fr/cgi-bin/nph-sesame/' in urls[0]
+        expected_urls = sesame_url.get()
+        assert any([urls[0].startswith(x) for x in expected_urls]), f'{urls[0]} not in {expected_urls}'
 
         # Try reloading coordinates, now should just reload cached data:
         with no_internet():
