@@ -2,7 +2,6 @@
 This file tests the behavior of subclasses of Representation and Frames
 """
 from copy import deepcopy
-from collections import OrderedDict
 
 import pytest
 
@@ -45,13 +44,13 @@ def test_unit_representation_subclass():
             return self
 
     class UnitSphericalWrap180Representation(UnitSphericalRepresentation):
-        attr_classes = OrderedDict([('lon', Longitude180),
-                                    ('lat', Latitude)])
+        attr_classes = {'lon': Longitude180,
+                        'lat': Latitude}
 
     class SphericalWrap180Representation(SphericalRepresentation):
-        attr_classes = OrderedDict([('lon', Longitude180),
-                                    ('lat', Latitude),
-                                    ('distance', u.Quantity)])
+        attr_classes = {'lon': Longitude180,
+                        'lat': Latitude,
+                        'distance': u.Quantity}
 
         _unit_representation = UnitSphericalWrap180Representation
 
