@@ -8,53 +8,26 @@ from astropy.utils.exceptions import AstropyDeprecationWarning
 from astropy.utils.state import ScienceState
 
 from . import parameters
-from .core import Cosmology, FlatLambdaCDM, LambdaCDM
+from .core import _COSMOLOGY_CLASSES, Cosmology
 
-__all__ = ["default_cosmology"] + parameters.available
+__all__ = ["default_cosmology"] + list(parameters.available)
 
 __doctest_requires__ = {"*": ["scipy"]}
 
+
 # Pre-defined cosmologies. This loops over the parameter sets in the
-# parameters module and creates a LambdaCDM or FlatLambdaCDM instance
-# with the same name as the parameter set in the current module's namespace.
-
+# parameters module and creates a corresponding cosmology instance
 for key in parameters.available:
-    par = getattr(parameters, key)
-
-    if par["cosmology"] == "FlatLambdaCDM":
-        cosmo = FlatLambdaCDM(
-            par["H0"],
-            par["Om0"],
-            Tcmb0=par["Tcmb0"],
-            Neff=par["Neff"],
-            m_nu=u.Quantity(par["m_nu"], u.eV),
-            name=key,
-            Ob0=par["Ob0"],
-        )
-        docstr = "{} instance of FlatLambdaCDM cosmology\n\n(from {})"
-        cosmo.__doc__ = docstr.format(key, par["reference"])
-    else:
-        warnings.warn("Please open a PR for your added cosmology realization.")
-        # For a non-flat LCDM realization, the following is the code necessary
-        # to create the realization, given the parameters. We comment this out
-        # as there are not currently any such built-in realizations.
-        # cosmo = LambdaCDM(
-        #     par["H0"],
-        #     par["Om0"],
-        #     par["Ode0"],
-        #     Tcmb0=par["Tcmb0"],
-        #     Neff=par["Neff"],
-        #     m_nu=u.Quantity(par["m_nu"], u.eV),
-        #     name=key,
-        #     Ob0=par["Ob0"],
-        # )
-        # docstr = "{} instance of LambdaCDM cosmology\n\n(from {})"
-        # cosmo.__doc__ = docstr.format(key, par["reference"])
-
+    params = dict(getattr(parameters, key))  # get parameters dict (copy)
+    params.setdefault("name", key)
+    # make cosmology
+    cosmo = Cosmology.from_format(params, format="mapping", move_to_meta=True)
+    cosmo.__doc__ = (f"{key} instance of {cosmo.__class__.__qualname__} "
+                     f"cosmology\n(from {cosmo.meta['reference']})")
+    # put in this namespace
     setattr(sys.modules[__name__], key, cosmo)
 
-# don't leave these variables floating around in the namespace
-del key, par, cosmo
+del key, params, cosmo  # clean the namespace
 
 #########################################################################
 # The science state below contains the current cosmology.
