@@ -391,7 +391,7 @@ class Ipac(basic.Basic):
     of missing or bad data. On writing, this value defaults to ``null``.
     To specify a different null value, use the ``fill_values`` option to
     replace masked values with a string or number of your choice as
-    described in :ref:`io_ascii_write_parameters`::
+    described in :ref:`astropy:io_ascii_write_parameters`::
 
         >>> from astropy.io.ascii import masked
         >>> fill = [(masked, 'N/A', 'ra'), (masked, -999, 'sptype')]
@@ -407,7 +407,7 @@ class Ipac(basic.Basic):
 
     When writing a table with a column of integers, the data type is output
     as ``int`` when the column ``dtype.itemsize`` is less than or equal to 2;
-    othewise the data type is ``long``. For a column of floating-point values,
+    otherwise the data type is ``long``. For a column of floating-point values,
     the data type is ``float`` when ``dtype.itemsize`` is less than or equal
     to 4; otherwise the data type is ``double``.
 
