@@ -2,7 +2,7 @@
 """
 This package contains functions for reading and writing QDP tables that are
 not meant to be used directly, but instead are available as readers/writers in
-`astropy.table`. See :ref:`table_io` for more details.
+`astropy.table`. See :ref:`astropy:table_io` for more details.
 """
 import re
 import copy
@@ -139,6 +139,8 @@ def _get_lines_from_file(qdp_file):
             lines = [line.strip() for line in fobj.readlines()]
     elif isinstance(qdp_file, Iterable):
         lines = qdp_file
+    else:
+        raise ValueError('invalid value of qdb_file')
 
     return lines
 
