@@ -25,6 +25,7 @@ from astropy.units import allclose as quantity_allclose
 from astropy.units import QuantityInfo
 
 from astropy.utils.exceptions import AstropyUserWarning
+from astropy.utils.compat import NUMPY_LT_1_19_1
 
 from astropy.io.ascii.ecsv import DELIMITERS
 from astropy.io import ascii
@@ -743,6 +744,26 @@ a
         Table.read(txt, format='ascii.ecsv')
 
 
+@pytest.mark.skipif(NUMPY_LT_1_19_1,
+                    reason="numpy<=1.19.0 cannot parse 'complex' as string")
+def test_read_complex_v09():
+    """Test an ECSV file with a complex column for version 0.9
+    Note: ECSV Version <=0.9 files should not raise ValueError
+    for complex datatype to maintain backwards compatibility.
+    """
+    txt = """\
+# %ECSV 0.9
+# ---
+# datatype:
+# - {name: a, datatype: complex}
+# schema: astropy-2.0
+a
+1+1j
+2+2j"""
+    t = Table.read(txt, format='ascii.ecsv')
+    assert t['a'].dtype.type is np.complex128
+
+
 def test_read_bad_datatype_for_object_subtype():
     """Test a malformed ECSV file"""
     txt = """\
@@ -775,6 +796,26 @@ fail
         Table.read(txt, format='ascii.ecsv')
 
 
+def test_read_bad_datatype_v09():
+    """Test a malformed ECSV file for version 0.9
+    Note: ECSV Version <=0.9 files should not raise ValueError
+    for malformed datatypes to maintain backwards compatibility.
+    """
+    txt = """\
+# %ECSV 0.9
+# ---
+# datatype:
+# - {name: a, datatype: object}
+# schema: astropy-2.0
+a
+fail
+[3,4]"""
+    t = Table.read(txt, format='ascii.ecsv')
+    assert t['a'][0] == "fail"
+    assert type(t['a'][1]) is str
+    assert type(t['a'].dtype) == np.dtype("O")
+
+
 def test_full_repr_roundtrip():
     """Test round-trip of float values to full precision even with format
     specified"""
