@@ -178,7 +178,7 @@ def test_read_with_names_arg(fast_reader):
     """
     Test that a bad value of `names` raises an exception.
     """
-    # CParser only uses columns in `names` and thus reports mismach in num_col
+    # CParser only uses columns in `names` and thus reports mismatch in num_col
     with pytest.raises(ascii.InconsistentTableError):
         ascii.read(['c d', 'e f'], names=('a', ), guess=False, fast_reader=fast_reader)
 
@@ -445,7 +445,7 @@ def test_from_string(fast_reader):
     f = 'data/simple.txt'
     with open(f) as fd:
         table = fd.read()
-    testfile = get_testfiles(f)
+    testfile = get_testfiles(f)[0]
     data = ascii.read(table, fast_reader=fast_reader, **testfile['opts'])
     assert_equal(data.dtype.names, testfile['cols'])
     assert_equal(len(data), testfile['nrows'])
@@ -454,7 +454,7 @@ def test_from_string(fast_reader):
 @pytest.mark.parametrize('fast_reader', [True, False, 'force'])
 def test_from_filelike(fast_reader):
     f = 'data/simple.txt'
-    testfile = get_testfiles(f)
+    testfile = get_testfiles(f)[0]
     with open(f, 'rb') as fd:
         data = ascii.read(fd, fast_reader=fast_reader, **testfile['opts'])
     assert_equal(data.dtype.names, testfile['cols'])
@@ -466,7 +466,7 @@ def test_from_lines(fast_reader):
     f = 'data/simple.txt'
     with open(f) as fd:
         table = fd.readlines()
-    testfile = get_testfiles(f)
+    testfile = get_testfiles(f)[0]
     data = ascii.read(table, fast_reader=fast_reader, **testfile['opts'])
     assert_equal(data.dtype.names, testfile['cols'])
     assert_equal(len(data), testfile['nrows'])
@@ -539,18 +539,18 @@ def test_fill_values_list(fast_reader):
     assert_true((data['a'] == [42, 42]).all())
 
 
-def test_masking_Cds():
-    f = 'data/cds.dat'
-    testfile = get_testfiles(f)
-    data = ascii.read(f,
-                      **testfile['opts'])
-    assert_true(data['AK'].mask[0])
-    assert not hasattr(data['Fit'], 'mask')
+def test_masking_Cds_Mrt():
+    f = 'data/cds.dat'  # Tested for CDS and MRT
+    for testfile in get_testfiles(f):
+        data = ascii.read(f,
+                          **testfile['opts'])
+        assert_true(data['AK'].mask[0])
+        assert not hasattr(data['Fit'], 'mask')
 
 
 def test_null_Ipac():
     f = 'data/ipac.dat'
-    testfile = get_testfiles(f)
+    testfile = get_testfiles(f)[0]
     data = ascii.read(f, **testfile['opts'])
     mask = np.array([(True, False, True, False, True),
                      (False, False, False, False, False)],
@@ -569,7 +569,7 @@ def test_Ipac_meta():
                             ('key_continue', 'IPAC keywords can continue across lines')))
     comments = ['This is an example of a valid comment']
     f = 'data/ipac.dat'
-    testfile = get_testfiles(f)
+    testfile = get_testfiles(f)[0]
     data = ascii.read(f, **testfile['opts'])
     assert data.meta['keywords'].keys() == keywords.keys()
     for data_kv, kv in zip(data.meta['keywords'].values(), keywords.values()):
@@ -587,7 +587,7 @@ def test_set_guess_kwarg():
 
 @pytest.mark.parametrize('fast_reader', [True, False, 'force'])
 def test_read_rdb_wrong_type(fast_reader):
-    """Read RDB data with inconstent data type (except failure)"""
+    """Read RDB data with inconsistent data type (except failure)"""
     table = """col1\tcol2
 N\tN
 1\tHello"""
@@ -671,6 +671,21 @@ def get_testfiles(name=None):
          'name': 'data/cds.dat',
          'nrows': 1,
          'opts': {'Reader': ascii.Cds}},
+        {'cols': ('Index',
+                  'RAh',
+                  'RAm',
+                  'RAs',
+                  'DE-',
+                  'DEd',
+                  'DEm',
+                  'DEs',
+                  'Match',
+                  'Class',
+                  'AK',
+                  'Fit'),
+         'name': 'data/cds.dat',
+         'nrows': 1,
+         'opts': {'Reader': ascii.Mrt}},
         # Test malformed CDS file (issues #2241 #467)
         {'cols': ('Index',
                   'RAh',
@@ -764,6 +779,21 @@ def get_testfiles(name=None):
          'name': 'data/no_data_cds.dat',
          'nrows': 0,
          'opts': {'Reader': ascii.Cds}},
+        {'cols': ('Index',
+                  'RAh',
+                  'RAm',
+                  'RAs',
+                  'DE-',
+                  'DEd',
+                  'DEm',
+                  'DEs',
+                  'Match',
+                  'Class',
+                  'AK',
+                  'Fit'),
+         'name': 'data/no_data_cds.dat',
+         'nrows': 0,
+         'opts': {'Reader': ascii.Mrt}},
         {'cols': ('ID',
                   'XCENTER',
                   'YCENTER',
@@ -896,9 +926,15 @@ def get_testfiles(name=None):
         pass
 
     if name is not None:
-        return [x for x in testfiles if x['name'] == name][0]
+        # If there are multiple matches then return a list, else return just
+        # the one match.
+        out = [x for x in testfiles if x['name'] == name]
+        if len(out) == 1:
+            out = out[0]
     else:
-        return testfiles
+        out = testfiles
+
+    return out
 
 
 def test_header_start_exception():
@@ -910,7 +946,7 @@ def test_header_start_exception():
     '''
     for readerclass in [ascii.NoHeader, ascii.SExtractor, ascii.Ipac,
                         ascii.BaseReader, ascii.FixedWidthNoHeader,
-                        ascii.Cds, ascii.Daophot]:
+                        ascii.Cds, ascii.Mrt, ascii.Daophot]:
         with pytest.raises(ValueError):
             ascii.core._get_reader(readerclass, header_start=5)
 
@@ -1047,7 +1083,8 @@ def test_guessing_file_object():
     """
     Test guessing a file object.  Fixes #3013 and similar issue noted in #3019.
     """
-    t = ascii.read(open('data/ipac.dat.bz2', 'rb'))
+    with open('data/ipac.dat.bz2', 'rb') as fd:
+        t = ascii.read(fd)
     assert t.colnames == ['ra', 'dec', 'sai', 'v2', 'sptype']
 
 
@@ -1412,25 +1449,27 @@ def test_read_chunks_input_types():
     fpath = 'data/test5.dat'
     t1 = ascii.read(fpath, header_start=1, data_start=3, )
 
-    for fp in (fpath, open(fpath, 'r'), open(fpath, 'r').read()):
-        t_gen = ascii.read(fp, header_start=1, data_start=3,
-                           guess=False, format='fast_basic',
-                           fast_reader={'chunk_size': 400, 'chunk_generator': True})
-        ts = list(t_gen)
-        for t in ts:
-            for col, col1 in zip(t.columns.values(), t1.columns.values()):
-                assert col.name == col1.name
-                assert col.dtype.kind == col1.dtype.kind
+    with open(fpath, 'r') as fd1, open(fpath, 'r') as fd2:
+        for fp in (fpath, fd1, fd2.read()):
+            t_gen = ascii.read(fp, header_start=1, data_start=3,
+                               guess=False, format='fast_basic',
+                               fast_reader={'chunk_size': 400, 'chunk_generator': True})
+            ts = list(t_gen)
+            for t in ts:
+                for col, col1 in zip(t.columns.values(), t1.columns.values()):
+                    assert col.name == col1.name
+                    assert col.dtype.kind == col1.dtype.kind
 
-        assert len(ts) == 4
-        t2 = table.vstack(ts)
-        assert np.all(t1 == t2)
+            assert len(ts) == 4
+            t2 = table.vstack(ts)
+            assert np.all(t1 == t2)
 
-    for fp in (fpath, open(fpath, 'r'), open(fpath, 'r').read()):
-        # Now read the full table in chunks
-        t3 = ascii.read(fp, header_start=1, data_start=3,
-                        fast_reader={'chunk_size': 300})
-        assert np.all(t1 == t3)
+    with open(fpath, 'r') as fd1, open(fpath, 'r') as fd2:
+        for fp in (fpath, fd1, fd2.read()):
+            # Now read the full table in chunks
+            t3 = ascii.read(fp, header_start=1, data_start=3,
+                            fast_reader={'chunk_size': 300})
+            assert np.all(t1 == t3)
 
 
 @pytest.mark.parametrize('masked', [True, False])
@@ -1637,3 +1676,13 @@ False   5
     assert col.dtype.kind == 'b'
     assert np.all(col.mask == [False, False, False, True, False])
     assert np.all(col == [True, False, True, False, False])
+
+
+def test_read_converters_wildcard():
+    '''Test converters where the column name is specified with
+    a wildcard.
+    '''
+    converters = {'F*': [ascii.convert_numpy(np.float32)]}
+    t = ascii.read(['Fabc Iabc', '1 2'], converters=converters)
+    assert np.issubdtype(t['Fabc'].dtype, np.float32)
+    assert not np.issubdtype(t['Iabc'].dtype, np.float32)
