@@ -24,6 +24,7 @@ import numpy as np
 from . import core
 from . import basic
 from . import cds
+from . import mrt
 from . import daophot
 from . import ecsv
 from . import sextractor
@@ -38,7 +39,8 @@ from .docs import READ_KWARG_TYPES, WRITE_KWARG_TYPES
 
 from astropy.table import Table, MaskedColumn
 from astropy.utils.data import get_readable_fileobj
-from astropy.utils.exceptions import AstropyWarning, AstropyDeprecationWarning
+from astropy.utils.exceptions import AstropyWarning
+from astropy.utils.misc import NOT_OVERWRITING_MSG
 
 _read_trace = []
 
@@ -62,8 +64,9 @@ def _probably_html(table, maxchars=100000):
             for i, line in enumerate(table):
                 size += len(line)
                 if size > maxchars:
+                    table = table[:i + 1]
                     break
-            table = os.linesep.join(table[:i + 1])
+            table = os.linesep.join(table)
         except Exception:
             pass
 
@@ -247,6 +250,10 @@ def _validate_read_write_kwargs(read_write, **kwargs):
 
 
 def read(table, guess=None, **kwargs):
+    # This the final output from reading. Static analysis indicates the reading
+    # logic (which is indeed complex) might not define `dat`, thus do so here.
+    dat = None
+
     # Docstring defined below
     del _read_trace[:]
 
@@ -372,6 +379,12 @@ def read(table, guess=None, **kwargs):
                                 'status': 'Success with specified Reader class '
                                           '(no guessing)'})
 
+    # Static analysis (pyright) indicates `dat` might be left undefined, so just
+    # to be sure define it at the beginning and check here.
+    if dat is None:
+        raise RuntimeError('read() function failed due to code logic error, '
+                           'please report this bug on github')
+
     return dat
 
 
@@ -514,7 +527,7 @@ def _guess(table, read_kwargs, format, fast_reader):
             return dat
 
         except guess_exception_classes as err:
-            _read_trace.append({'kwargs': copy.deepcopy(guess_kwargs),
+            _read_trace.append({'kwargs': copy.deepcopy(read_kwargs),
                                 'status': f'{err.__class__.__name__}: {str(err)}'})
             failed_kwargs.append(read_kwargs)
             lines = ['\nERROR: Unable to guess table format with the guesses listed below:']
@@ -585,7 +598,7 @@ def _get_guess_kwargs_list(read_kwargs):
                    fastbasic.FastBasic, basic.Basic,
                    fastbasic.FastRdb, basic.Rdb,
                    fastbasic.FastTab, basic.Tab,
-                   cds.Cds, daophot.Daophot, sextractor.SExtractor,
+                   cds.Cds, mrt.Mrt, daophot.Daophot, sextractor.SExtractor,
                    ipac.Ipac, latex.Latex, latex.AASTex):
         guess_kwargs_list.append(dict(Reader=reader))
 
@@ -782,22 +795,15 @@ def get_writer(Writer=None, fast_writer=True, **kwargs):
 
 
 def write(table, output=None, format=None, Writer=None, fast_writer=True, *,
-          overwrite=None, **kwargs):
+          overwrite=False, **kwargs):
     # Docstring inserted below
 
     _validate_read_write_kwargs('write', format=format, fast_writer=fast_writer,
                                 overwrite=overwrite, **kwargs)
 
     if isinstance(output, str):
-        if os.path.lexists(output):
-            if overwrite is None:
-                warnings.warn(
-                    "{} already exists. "
-                    "Automatically overwriting ASCII files is deprecated. "
-                    "Use the argument 'overwrite=True' in the future.".format(
-                        output), AstropyDeprecationWarning)
-            elif not overwrite:
-                raise OSError(f"{output} already exists")
+        if not overwrite and os.path.lexists(output):
+            raise OSError(NOT_OVERWRITING_MSG.format(output))
 
     if output is None:
         output = sys.stdout
@@ -805,23 +811,12 @@ def write(table, output=None, format=None, Writer=None, fast_writer=True, *,
     # Ensure that `table` is a Table subclass.
     names = kwargs.get('names')
     if isinstance(table, Table):
-        # Note that making a copy of the table here is inefficient but
-        # without this copy a number of tests break (e.g. in test_fixedwidth).
-        # See #7605.
-        new_tbl = table.__class__(table, names=names)
-
-        # This makes a copy of the table columns.  This is subject to a
-        # corner-case problem if writing a table with masked columns to ECSV
-        # where serialize_method is set to 'data_mask'.  In this case that
-        # attribute gets dropped in the copy, so do the copy here.  This
-        # should be removed when `info` really contains all the attributes
-        # (#6720).
-        for new_col, col in zip(new_tbl.itercols(), table.itercols()):
-            if isinstance(col, MaskedColumn):
-                new_col.info.serialize_method = col.info.serialize_method
-        table = new_tbl
+        # While we are only going to read data from columns, we may need to
+        # to adjust info attributes such as format, so we make a shallow copy.
+        table = table.__class__(table, names=names, copy=False)
     else:
-        table = Table(table, names=names)
+        # Otherwise, create a table from the input.
+        table = Table(table, names=names, copy=False)
 
     table0 = table[:0].copy()
     core._apply_include_exclude_names(table0, kwargs.get('names'),
@@ -830,7 +825,7 @@ def write(table, output=None, format=None, Writer=None, fast_writer=True, *,
 
     if diff_format_with_names:
         warnings.warn(
-            'The keys {} specified in the formats argument does not match a column name.'
+            'The key(s) {} specified in the formats argument do not match a column name.'
             .format(diff_format_with_names), AstropyWarning)
 
     if table.has_mixin_columns:
