@@ -701,7 +701,11 @@ class Header:
             s += ' ' * _pad_length(len(s))
         return s
 
-    @deprecated_renamed_argument('clobber', 'overwrite', '2.0')
+    @deprecated_renamed_argument('clobber', 'overwrite', '2.0',
+                                 message='"clobber" was deprecated in version '
+                                         '2.0 and will be removed in version '
+                                         '5.1. Use argument "overwrite" '
+                                         'instead.')
     def tofile(self, fileobj, sep='', endcard=True, padding=True,
                overwrite=False):
         r"""
@@ -778,7 +782,11 @@ class Header:
 
         return cls.fromfile(fileobj, sep='\n', endcard=endcard, padding=False)
 
-    @deprecated_renamed_argument('clobber', 'overwrite', '2.0')
+    @deprecated_renamed_argument('clobber', 'overwrite', '2.0',
+                                 message='"clobber" was deprecated in version '
+                                         '2.0 and will be removed in version '
+                                         '5.1. Use argument "overwrite" '
+                                         'instead.')
     def totextfile(self, fileobj, endcard=False, overwrite=False):
         """
         Write the header as text to a file or a file-like object.
@@ -989,7 +997,7 @@ class Header:
         """Like :meth:`dict.items`."""
 
         for card in self._cards:
-            yield (card.keyword, card.value)
+            yield card.keyword, None if card.value == UNDEFINED else card.value
 
     def keys(self):
         """
@@ -1004,7 +1012,7 @@ class Header:
         """Like :meth:`dict.values`."""
 
         for card in self._cards:
-            yield card.value
+            yield None if card.value == UNDEFINED else card.value
 
     def pop(self, *args):
         """
@@ -2140,10 +2148,6 @@ class _CardAccessor:
         return False
 
 
-collections.abc.Mapping.register(_CardAccessor)
-collections.abc.Sequence.register(_CardAccessor)
-
-
 class _HeaderComments(_CardAccessor):
     """
     A class used internally by the Header class for the Header.comments
