@@ -4,35 +4,34 @@
 import os
 
 from asdf.extension import AsdfExtension, BuiltinExtension
-from asdf.resolver import Resolver, DEFAULT_URL_MAPPING
 from asdf.util import filepath_to_url
 
 # Make sure that all tag implementations are imported by the time we create
 # the extension class so that _astropy_asdf_types is populated correctly. We
 # could do this using __init__ files, except it causes pytest import errors in
 # the case that asdf is not installed.
-from .tags.coordinates.angle import *
-from .tags.coordinates.frames import *
-from .tags.coordinates.earthlocation import *
-from .tags.coordinates.skycoord import *
-from .tags.coordinates.representation import *
-from .tags.coordinates.spectralcoord import *
-from .tags.fits.fits import *
-from .tags.table.table import *
-from .tags.time.time import *
-from .tags.time.timedelta import *
-from .tags.transform.basic import *
-from .tags.transform.compound import *
-from .tags.transform.functional_models import *
-from .tags.transform.physical_models import *
-from .tags.transform.math import *
-from .tags.transform.polynomial import *
-from .tags.transform.powerlaws import *
-from .tags.transform.projections import *
-from .tags.transform.tabular import *
-from .tags.unit.quantity import *
-from .tags.unit.unit import *
-from .tags.unit.equivalency import *
+from .tags.coordinates.angle import *  # noqa
+from .tags.coordinates.frames import *  # noqa
+from .tags.coordinates.earthlocation import *  # noqa
+from .tags.coordinates.skycoord import *  # noqa
+from .tags.coordinates.representation import *  # noqa
+from .tags.coordinates.spectralcoord import *  # noqa
+from .tags.fits.fits import *  # noqa
+from .tags.table.table import *  # noqa
+from .tags.time.time import *  # noqa
+from .tags.time.timedelta import *  # noqa
+from .tags.transform.basic import *  # noqa
+from .tags.transform.compound import *  # noqa
+from .tags.transform.functional_models import *  # noqa
+from .tags.transform.physical_models import *  # noqa
+from .tags.transform.math import *  # noqa
+from .tags.transform.polynomial import *  # noqa
+from .tags.transform.powerlaws import *  # noqa
+from .tags.transform.projections import *  # noqa
+from .tags.transform.tabular import *  # noqa
+from .tags.unit.quantity import *  # noqa
+from .tags.unit.unit import *  # noqa
+from .tags.unit.equivalency import *  # noqa
 from .types import _astropy_types, _astropy_asdf_types
 
 
