@@ -1,14 +1,11 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 # -*- coding: utf-8 -*-
 
-from numpy import isscalar
 from astropy.units import Quantity
 
-from asdf.yamlutil import custom_tree_to_tagged_tree
 from asdf.tags.core import NDArrayType
 
 from astropy.io.misc.asdf.types import AstropyAsdfType
-from .unit import UnitType
 
 
 class QuantityType(AstropyAsdfType):
@@ -21,17 +18,17 @@ class QuantityType(AstropyAsdfType):
     def to_tree(cls, quantity, ctx):
         node = {}
         if isinstance(quantity, Quantity):
-            node['value'] = custom_tree_to_tagged_tree(quantity.value, ctx)
-            node['unit'] = custom_tree_to_tagged_tree(quantity.unit, ctx)
+            node['value'] = quantity.value
+            node['unit'] = quantity.unit
             return node
-        raise TypeError("'{0}' is not a valid Quantity".format(quantity))
+        raise TypeError(f"'{quantity}' is not a valid Quantity")
 
     @classmethod
     def from_tree(cls, node, ctx):
         if isinstance(node, Quantity):
             return node
 
-        unit = UnitType.from_tree(node['unit'], ctx)
+        unit = node['unit']
         value = node['value']
         if isinstance(value, NDArrayType):
             value = value._make_array()
