@@ -1,13 +1,14 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 # -*- coding: utf-8 -*-
 
-import io
 import pytest
 
+asdf = pytest.importorskip('asdf')
+
+import io
+
 from astropy import units as u
-from astropy import __minimum_asdf_version__
 
-asdf = pytest.importorskip('asdf', minversion=__minimum_asdf_version__)
 from asdf.tests import helpers
 
 
