@@ -1,8 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 # -*- coding: utf-8 -*-
 
-import six
-
 from astropy.units import Unit, UnitBase
 from astropy.io.misc.asdf.types import AstropyAsdfType
 
@@ -14,7 +12,7 @@ class UnitType(AstropyAsdfType):
 
     @classmethod
     def to_tree(cls, node, ctx):
-        if isinstance(node, six.string_types):
+        if isinstance(node, str):
             node = Unit(node, format='vounit', parse_strict='warn')
         if isinstance(node, UnitBase):
             return node.to_string(format='vounit')
