@@ -12,11 +12,13 @@ from astropy.coordinates import (SkyCoord, Latitude, Longitude, Angle, EarthLoca
                                  SphericalRepresentation, CartesianRepresentation,
                                  SphericalCosLatDifferential)
 from astropy.time import Time, TimeDelta
+from astropy.units import allclose as quantity_allclose
 from astropy.units.quantity import QuantityInfo
 from astropy.utils.exceptions import AstropyUserWarning
 from astropy.utils.data import get_pkg_data_filename
+from astropy.utils.misc import _NOT_OVERWRITING_MSG_MATCH
 from astropy.io.misc.hdf5 import meta_path
-from astropy.utils.compat.optional_deps import HAS_H5PY, HAS_YAML  # noqa
+from astropy.utils.compat.optional_deps import HAS_H5PY  # noqa
 if HAS_H5PY:
     import h5py
 
@@ -180,9 +182,8 @@ def test_read_write_existing(tmpdir):
     h5py.File(test_file, 'w').close()  # create empty file
     t1 = Table()
     t1.add_column(Column(name='a', data=[1, 2, 3]))
-    with pytest.raises(OSError) as exc:
+    with pytest.raises(OSError, match=_NOT_OVERWRITING_MSG_MATCH):
         t1.write(test_file, path='the_table')
-    assert exc.value.args[0].startswith("File exists:")
 
 
 @pytest.mark.skipif('not HAS_H5PY')
@@ -429,7 +430,7 @@ def test_preserve_meta(tmpdir):
         assert np.all(t1.meta[key] == t2.meta[key])
 
 
-@pytest.mark.skipif('not HAS_H5PY or not HAS_YAML')
+@pytest.mark.skipif('not HAS_H5PY')
 def test_preserve_serialized(tmpdir):
     test_file = str(tmpdir.join('test.hdf5'))
 
@@ -458,7 +459,7 @@ def test_preserve_serialized(tmpdir):
     assert meta_lines.dtype.kind == 'S'
 
 
-@pytest.mark.skipif('not HAS_H5PY or not HAS_YAML')
+@pytest.mark.skipif('not HAS_H5PY')
 def test_preserve_serialized_old_meta_format(tmpdir):
     """Test the old meta format
 
@@ -484,7 +485,7 @@ def test_preserve_serialized_old_meta_format(tmpdir):
     assert t1.meta == t2.meta
 
 
-@pytest.mark.skipif('not HAS_H5PY or not HAS_YAML')
+@pytest.mark.skipif('not HAS_H5PY')
 def test_preserve_serialized_in_complicated_path(tmpdir):
     test_file = str(tmpdir.join('test.hdf5'))
 
@@ -509,7 +510,7 @@ def test_preserve_serialized_in_complicated_path(tmpdir):
     assert t1.meta == t2.meta
 
 
-@pytest.mark.skipif('not HAS_H5PY or not HAS_YAML')
+@pytest.mark.skipif('not HAS_H5PY')
 def test_metadata_very_large(tmpdir):
     """Test that very large datasets work, now!"""
     test_file = str(tmpdir.join('test.hdf5'))
@@ -557,7 +558,7 @@ def test_skip_meta(tmpdir):
     assert len(w) == 1
 
 
-@pytest.mark.skipif('not HAS_H5PY or not HAS_YAML')
+@pytest.mark.skipif('not HAS_H5PY')
 def test_fail_meta_serialize(tmpdir):
 
     test_file = str(tmpdir.join('test.hdf5'))
@@ -652,10 +653,14 @@ def assert_objects_equal(obj1, obj2, attrs, compare_class=True):
             if a2 is None:
                 a2 = {}
 
-        assert np.all(a1 == a2)
+        if isinstance(a1, np.ndarray) and a1.dtype.kind == 'f':
+            assert quantity_allclose(a1, a2, rtol=1e-15)
+        else:
+            assert np.all(a1 == a2)
 
 # Testing HDF5 table read/write with mixins.  This is mostly
 # copied from FITS mixin testing, and it might be good to unify it.
+# Analogous tests also exist for ECSV.
 
 
 el = EarthLocation(x=1 * u.km, y=3 * u.km, z=5 * u.km)
@@ -669,8 +674,17 @@ sd = SphericalCosLatDifferential(
 srd = SphericalRepresentation(sr, differentials=sd)
 sc = SkyCoord([1, 2], [3, 4], unit='deg,deg', frame='fk4',
               obstime='J1990.5')
-scc = sc.copy()
-scc.representation_type = 'cartesian'
+scd = SkyCoord([1, 2], [3, 4], [5, 6], unit='deg,deg,m', frame='fk4',
+               obstime=['J1990.5', 'J1991.5'])
+scdc = scd.copy()
+scdc.representation_type = 'cartesian'
+scpm = SkyCoord([1, 2], [3, 4], [5, 6], unit='deg,deg,pc',
+                pm_ra_cosdec=[7, 8]*u.mas/u.yr, pm_dec=[9, 10]*u.mas/u.yr)
+scpmrv = SkyCoord([1, 2], [3, 4], [5, 6], unit='deg,deg,pc',
+                  pm_ra_cosdec=[7, 8]*u.mas/u.yr, pm_dec=[9, 10]*u.mas/u.yr,
+                  radial_velocity=[11, 12]*u.km/u.s)
+scrv = SkyCoord([1, 2], [3, 4], [5, 6], unit='deg,deg,pc',
+                radial_velocity=[11, 12]*u.km/u.s)
 tm = Time([2450814.5, 2450815.5], format='jd', scale='tai', location=el)
 
 # NOTE: in the test below the name of the column "x" for the Quantity is
@@ -680,9 +694,11 @@ mixin_cols = {
     'tm': tm,
     'dt': TimeDelta([1, 2] * u.day),
     'sc': sc,
-    'scc': scc,
-    'scd': SkyCoord([1, 2], [3, 4], [5, 6], unit='deg,deg,m', frame='fk4',
-                    obstime=['J1990.5', 'J1991.5']),
+    'scd': scd,
+    'scdc': scdc,
+    'scpm': scpm,
+    'scpmrv': scpmrv,
+    'scrv': scrv,
     'x': [1, 2] * u.m,
     'qdb': [10, 20] * u.dB(u.mW),
     'qdex': [4.5, 5.5] * u.dex(u.cm/u.s**2),
@@ -704,8 +720,14 @@ compare_attrs = {
     'tm': time_attrs,
     'dt': ['shape', 'value', 'format', 'scale'],
     'sc': ['ra', 'dec', 'representation_type', 'frame.name'],
-    'scc': ['x', 'y', 'z', 'representation_type', 'frame.name'],
     'scd': ['ra', 'dec', 'distance', 'representation_type', 'frame.name'],
+    'scdc': ['x', 'y', 'z', 'representation_type', 'frame.name'],
+    'scpm': ['ra', 'dec', 'distance', 'pm_ra_cosdec', 'pm_dec',
+             'representation_type', 'frame.name'],
+    'scpmrv': ['ra', 'dec', 'distance', 'pm_ra_cosdec', 'pm_dec',
+               'radial_velocity', 'representation_type', 'frame.name'],
+    'scrv': ['ra', 'dec', 'distance', 'radial_velocity', 'representation_type',
+             'frame.name'],
     'x': ['value', 'unit'],
     'qdb': ['value', 'unit'],
     'qdex': ['value', 'unit'],
@@ -723,7 +745,7 @@ compare_attrs = {
 }
 
 
-@pytest.mark.skipif('not HAS_H5PY or not HAS_YAML')
+@pytest.mark.skipif('not HAS_H5PY')
 def test_hdf5_mixins_qtable_to_table(tmpdir):
     """Test writing as QTable and reading as Table.  Ensure correct classes
     come out.
@@ -761,7 +783,7 @@ def test_hdf5_mixins_qtable_to_table(tmpdir):
         assert_objects_equal(col, col2, attrs, compare_class)
 
 
-@pytest.mark.skipif('not HAS_H5PY or not HAS_YAML')
+@pytest.mark.skipif('not HAS_H5PY')
 @pytest.mark.parametrize('table_cls', (Table, QTable))
 def test_hdf5_mixins_as_one(table_cls, tmpdir):
     """Test write/read all cols at once and validate intermediate column names"""
@@ -778,9 +800,17 @@ def test_hdf5_mixins_as_one(table_cls, tmpdir):
                         'qdex',
                         'qmag',
                         'sc.ra', 'sc.dec',
-                        'scc.x', 'scc.y', 'scc.z',
                         'scd.ra', 'scd.dec', 'scd.distance',
                         'scd.obstime.jd1', 'scd.obstime.jd2',
+                        'scdc.x', 'scdc.y', 'scdc.z',
+                        'scdc.obstime.jd1', 'scdc.obstime.jd2',
+                        'scpm.ra', 'scpm.dec', 'scpm.distance',
+                        'scpm.pm_ra_cosdec', 'scpm.pm_dec',
+                        'scpmrv.ra', 'scpmrv.dec', 'scpmrv.distance',
+                        'scpmrv.pm_ra_cosdec', 'scpmrv.pm_dec',
+                        'scpmrv.radial_velocity',
+                        'scrv.ra', 'scrv.dec', 'scrv.distance',
+                        'scrv.radial_velocity',
                         'sd.d_lon_coslat', 'sd.d_lat', 'sd.d_distance',
                         'sr.lon', 'sr.lat', 'sr.distance',
                         'srd.lon', 'srd.lat', 'srd.distance',
@@ -811,7 +841,7 @@ def test_hdf5_mixins_as_one(table_cls, tmpdir):
     h5.close()
 
 
-@pytest.mark.skipif('not HAS_H5PY or not HAS_YAML')
+@pytest.mark.skipif('not HAS_H5PY')
 @pytest.mark.parametrize('name_col', list(mixin_cols.items()))
 @pytest.mark.parametrize('table_cls', (Table, QTable))
 def test_hdf5_mixins_per_column(table_cls, name_col, tmpdir):
@@ -844,27 +874,7 @@ def test_hdf5_mixins_per_column(table_cls, name_col, tmpdir):
         assert t2[name]._time.jd2.__class__ is np.ndarray
 
 
-@pytest.mark.skipif('HAS_YAML or not HAS_H5PY')
-def test_warn_for_dropped_info_attributes(tmpdir):
-    filename = str(tmpdir.join('test.hdf5'))
-    t = Table([[1, 2]])
-    t['col0'].info.description = 'hello'
-    with pytest.warns(AstropyUserWarning, match=r"table contains column\(s\) "
-                      r"with defined 'unit'") as warns:
-        t.write(filename, path='root', serialize_meta=False)
-    assert len(warns) == 1
-
-
-@pytest.mark.skipif('HAS_YAML or not HAS_H5PY')
-def test_error_for_mixins_but_no_yaml(tmpdir):
-    filename = str(tmpdir.join('test.hdf5'))
-    t = Table([mixin_cols['sc']])
-    with pytest.raises(TypeError) as err:
-        t.write(filename, path='root', serialize_meta=True)
-    assert "cannot write type SkyCoord column 'col0' to HDF5 without PyYAML" in str(err.value)
-
-
-@pytest.mark.skipif('not HAS_YAML or not HAS_H5PY')
+@pytest.mark.skipif('not HAS_H5PY')
 def test_round_trip_masked_table_default(tmpdir):
     """Test round-trip of MaskedColumn through HDF5 using default serialization
     that writes a separate mask column.  Note:
@@ -898,7 +908,7 @@ def test_round_trip_masked_table_default(tmpdir):
         assert np.all(t2[name] == t[name])
 
 
-@pytest.mark.skipif('not HAS_YAML or not HAS_H5PY')
+@pytest.mark.skipif('not HAS_H5PY')
 def test_overwrite_serialized_meta():
     # This used to cause an error because the meta data table
     # was not removed from the existing file.
