@@ -137,7 +137,7 @@ def bool_to_bitarray(value):
     if bit_no != 7:
         bytes.append(byte)
 
-    return struct_pack("{}B".format(len(bytes)), *bytes)
+    return struct_pack(f"{len(bytes)}B", *bytes)
 
 
 class Converter:
@@ -189,7 +189,8 @@ class Converter:
 
         Returns
         -------
-        native : tuple (value, mask)
+        native : tuple
+            A two-element tuple of: value, mask.
             The value as a Numpy array or scalar, and *mask* is True
             if the value is missing.
         """
@@ -210,7 +211,8 @@ class Converter:
 
         Returns
         -------
-        native : tuple (value, mask)
+        native : (2,) tuple
+            (value, mask)
             The value as a Numpy array or scalar, and *mask* is True
             if the value is missing.
         """
@@ -224,8 +226,8 @@ class Converter:
 
         Parameters
         ----------
-        value : native type corresponding to this converter
-            The value
+        value
+            The value, the native type corresponding to this converter
 
         mask : bool
             If `True`, will return the string representation of a
@@ -253,9 +255,9 @@ class Converter:
 
         Returns
         -------
-        native : tuple (value, mask)
-            The value as a Numpy array or scalar, and *mask* is True
-            if the value is missing.
+        native : (2,) tuple
+            (value, mask). The value as a Numpy array or scalar, and *mask* is
+            True if the value is missing.
         """
         raise NotImplementedError(
             "This datatype must implement a 'binparse' method.")
@@ -268,8 +270,8 @@ class Converter:
 
         Parameters
         ----------
-        value : native type corresponding to this converter
-            The value
+        value
+            The value, the native type corresponding to this converter
 
         mask : bool
             If `True`, will return the string representation of a
@@ -277,7 +279,7 @@ class Converter:
 
         Returns
         -------
-        bytes : byte string
+        bytes : bytes
             The binary representation of the value, suitable for
             serialization in the BINARY_ format.
         """
@@ -583,7 +585,7 @@ class NumericArray(Array):
 
         self._base = base
         self._arraysize = arraysize
-        self.format = "{}{}".format(tuple(arraysize), base.format)
+        self.format = f"{tuple(arraysize)}{base.format}"
 
         self._items = 1
         for dim in arraysize:
@@ -706,11 +708,11 @@ class FloatingPoint(Numeric):
 
         if precision is not None:
             if precision.startswith("E"):
-                format_parts.append('.{:d}g'.format(int(precision[1:])))
+                format_parts.append(f'.{int(precision[1:]):d}g')
             elif precision.startswith("F"):
-                format_parts.append('.{:d}f'.format(int(precision[1:])))
+                format_parts.append(f'.{int(precision[1:]):d}f')
             else:
-                format_parts.append('.{:d}f'.format(int(precision)))
+                format_parts.append(f'.{int(precision):d}f')
 
         format_parts.append('}')
 
