@@ -18,7 +18,6 @@ from . import tree
 from astropy.utils.xml import iterparser
 from astropy.utils import data
 from astropy.utils.decorators import deprecated_renamed_argument
-from astropy.utils.exceptions import AstropyDeprecationWarning
 
 __all__ = ['parse', 'parse_single_table', 'from_table', 'writeto', 'validate',
            'reset_vo_warnings']
@@ -26,7 +25,7 @@ __all__ = ['parse', 'parse_single_table', 'from_table', 'writeto', 'validate',
 VERIFY_OPTIONS = ['ignore', 'warn', 'exception']
 
 
-@deprecated_renamed_argument('pedantic', 'verify', pending=True, since='4.0')
+@deprecated_renamed_argument('pedantic', 'verify', since='5.0')
 def parse(source, columns=None, invalid='exception', verify=None,
           chunk_size=tree.DEFAULT_CHUNK_SIZE, table_number=None,
           table_id=None, filename=None, unit_format=None,
@@ -64,6 +63,8 @@ def parse(source, columns=None, invalid='exception', verify=None,
         .. versionchanged:: 4.0
            ``verify`` replaces the ``pedantic`` argument, which will be
            deprecated in future.
+        .. versionchanged:: 5.0
+            The ``pedantic`` argument is deprecated.
 
     chunk_size : int, optional
         The number of rows to read before converting to an array.
@@ -120,15 +121,7 @@ def parse(source, columns=None, invalid='exception', verify=None,
 
     if verify is None:
 
-        # NOTE: since the pedantic argument isn't fully deprecated yet, we need
-        # to catch the deprecation warning that occurs when accessing the
-        # configuration item, but only if it is for the pedantic option in the
-        # [io.votable] section.
-        with warnings.catch_warnings():
-            warnings.filterwarnings("ignore",
-                                    r"Config parameter \'pedantic\' in section \[io.votable\]",
-                                    AstropyDeprecationWarning)
-            conf_verify_lowercase = conf.verify.lower()
+        conf_verify_lowercase = conf.verify.lower()
 
         # We need to allow verify to be booleans as strings since the
         # configuration framework doesn't make it easy/possible to have mixed
@@ -203,7 +196,7 @@ def writeto(table, file, tabledata_format=None):
         one of ``tabledata`` (text representation), ``binary`` or
         ``binary2``.  By default, use the format that was specified in
         each ``table`` object as it was created or read in.  See
-        :ref:`votable-serialization`.
+        :ref:`astropy:astropy:votable-serialization`.
     """
     from astropy.table import Table
     if isinstance(table, Table):
@@ -216,7 +209,7 @@ def writeto(table, file, tabledata_format=None):
                  _debug_python_based_parser=True)
 
 
-def validate(source, output=None, xmllint=False, filename=None):
+def validate(source, output=sys.stdout, xmllint=False, filename=None):
     """
     Prints a validation report for the given file.
 
@@ -251,12 +244,10 @@ def validate(source, output=None, xmllint=False, filename=None):
 
     from astropy.utils.console import print_code_line, color_print
 
-    if output is None:
-        output = sys.stdout
-
     return_as_str = False
     if output is None:
         output = io.StringIO()
+        return_as_str = True
 
     lines = []
     votable = None
@@ -415,5 +406,7 @@ def reset_vo_warnings():
     #  warning out of this, we have to delete all of them first. #
     # -----------------------------------------------------------#
     for module in (converters, exceptions, tree, xmlutil):
-        if hasattr(module, '__warningregistry__'):
+        try:
             del module.__warningregistry__
+        except AttributeError:
+            pass
