@@ -12,11 +12,13 @@ import numpy as np
 from astropy.config import set_temp_config, reload_config
 from astropy.utils.data import get_pkg_data_filename, get_pkg_data_fileobj
 from astropy.io.votable.table import parse, writeto
-from astropy.io.votable import tree, conf
+from astropy.io.votable import tree, conf, validate
 from astropy.io.votable.exceptions import VOWarning, W39, E25
 from astropy.table import Column, Table
+from astropy.table.table_helpers import simple_table
 from astropy.units import Unit
 from astropy.utils.exceptions import AstropyDeprecationWarning
+from astropy.utils.misc import _NOT_OVERWRITING_MSG_MATCH
 
 
 def test_table(tmpdir):
@@ -180,6 +182,15 @@ def test_write_with_format():
     assert b'TABLEDATA' not in obuff
 
 
+def test_write_overwrite(tmpdir):
+    t = simple_table(3, 3)
+    filename = os.path.join(tmpdir, 'overwrite_test.vot')
+    t.write(filename, format='votable')
+    with pytest.raises(OSError, match=_NOT_OVERWRITING_MSG_MATCH):
+        t.write(filename, format='votable')
+    t.write(filename, format='votable', overwrite=True)
+
+
 def test_empty_table():
     votable = parse(get_pkg_data_filename('data/empty_table.xml'))
     table = votable.get_first_table()
@@ -213,6 +224,51 @@ def test_binary2_masked_strings():
     astropy_table.write(output, format='votable')
 
 
+def test_validate_output_invalid():
+    """
+    Issue #12603. Test that we get the correct output from votable.validate with an invalid
+    votable.
+    """
+
+    # A votable with errors
+    invalid_votable_filepath = get_pkg_data_filename('data/regression.xml')
+
+    # When output is None, check that validate returns validation output as a string
+    validate_out = validate(invalid_votable_filepath, output=None)
+    assert isinstance(validate_out, str)
+    # Check for known error string
+    assert "E02: Incorrect number of elements in array." in validate_out
+
+    # When output is not set, check that validate returns a bool
+    validate_out = validate(invalid_votable_filepath)
+    assert isinstance(validate_out, bool)
+    # Check that validation output is correct (votable is not valid)
+    assert validate_out is False
+
+
+def test_validate_output_valid():
+    """
+    Issue #12603. Test that we get the correct output from votable.validate with a valid
+    votable
+    """
+
+    # A valid votable. (Example from the votable standard:
+    # https://www.ivoa.net/documents/VOTable/20191021/REC-VOTable-1.4-20191021.html )
+    valid_votable_filepath = get_pkg_data_filename('data/valid_votable.xml')
+
+    # When output is None, check that validate returns validation output as a string
+    validate_out = validate(valid_votable_filepath, output=None)
+    assert isinstance(validate_out, str)
+    # Check for known good output string
+    assert "astropy.io.votable found no violations" in validate_out
+
+    # When output is not set, check that validate returns a bool
+    validate_out = validate(valid_votable_filepath)
+    assert isinstance(validate_out, bool)
+    # Check that validation output is correct (votable is valid)
+    assert validate_out is True
+
+
 class TestVerifyOptions:
 
     # Start off by checking the default (ignore)
@@ -234,16 +290,17 @@ class TestVerifyOptions:
         with pytest.raises(VOWarning):
             parse(get_pkg_data_filename('data/gemini.xml'), verify='exception')
 
-    # Make sure the pedantic option still works for now (pending deprecation)
+    # Make sure the deprecated pedantic option still works for now
 
     def test_pedantic_false(self):
         with pytest.warns(VOWarning) as w:
             parse(get_pkg_data_filename('data/gemini.xml'), pedantic=False)
-        assert len(w) == 24
+        assert len(w) == 25
 
     def test_pedantic_true(self):
-        with pytest.raises(VOWarning):
-            parse(get_pkg_data_filename('data/gemini.xml'), pedantic=True)
+        with pytest.warns(AstropyDeprecationWarning):
+            with pytest.raises(VOWarning):
+                parse(get_pkg_data_filename('data/gemini.xml'), pedantic=True)
 
     # Make sure that the default behavior can be set via configuration items
 
@@ -275,7 +332,7 @@ class TestVerifyOptions:
 
             with pytest.warns(VOWarning) as w:
                 parse(get_pkg_data_filename('data/gemini.xml'))
-            assert len(w) == 24
+            assert len(w) == 25
 
     def test_conf_pedantic_true(self, tmpdir):
 
@@ -286,5 +343,6 @@ class TestVerifyOptions:
 
             reload_config('astropy.io.votable')
 
-            with pytest.raises(VOWarning):
-                parse(get_pkg_data_filename('data/gemini.xml'))
+            with pytest.warns(AstropyDeprecationWarning):
+                with pytest.raises(VOWarning):
+                    parse(get_pkg_data_filename('data/gemini.xml'))
