@@ -2,11 +2,9 @@
 """
 A set of tests for the util.py module
 """
+import pytest
 
-
-# LOCAL
 from astropy.io.votable import util
-from astropy.tests.helper import raises
 
 
 def test_range_list():
@@ -22,10 +20,10 @@ def test_range_list3():
         "5e-07,8e-07;FOO", 3)
 
 
-@raises(ValueError)
 def test_range_list4a():
-    util.coerce_range_list_param(
-        (5e-7, (None, 8e-7), (4, None), (4, 5), "J", "FOO"))
+    with pytest.raises(ValueError):
+        util.coerce_range_list_param(
+            (5e-7, (None, 8e-7), (4, None), (4, 5), "J", "FOO"))
 
 
 def test_range_list4():
@@ -34,14 +32,14 @@ def test_range_list4():
             ("5e-07,/8e-07,4/,4/5,J;FOO", 6))
 
 
-@raises(ValueError)
 def test_range_list5():
-    util.coerce_range_list_param(('FOO', ))
+    with pytest.raises(ValueError):
+        util.coerce_range_list_param(('FOO', ))
 
 
-@raises(ValueError)
 def test_range_list6():
-    print(util.coerce_range_list_param((5, 'FOO'), util.stc_reference_frames))
+    with pytest.raises(ValueError):
+        print(util.coerce_range_list_param((5, 'FOO'), util.stc_reference_frames))
 
 
 def test_range_list7():
@@ -57,9 +55,9 @@ def test_range_list8():
         assert util.coerce_range_list_param(s, numeric=False)[0] == s
 
 
-@raises(ValueError)
 def test_range_list9a():
-    util.coerce_range_list_param("52,-27.8;FOO", util.stc_reference_frames)
+    with pytest.raises(ValueError):
+        util.coerce_range_list_param("52,-27.8;FOO", util.stc_reference_frames)
 
 
 def test_range_list9():
