@@ -26,11 +26,7 @@ import abc
 import inspect
 import operator
 import warnings
-
-try:
-    from importlib.metadata import entry_points
-except ImportError:
-    from importlib_metadata import entry_points
+from importlib.metadata import entry_points
 
 from functools import reduce, wraps
 
@@ -42,6 +38,8 @@ from .utils import poly_map_domain, _combine_equivalency_dict
 from .optimizers import (SLSQP, Simplex)
 from .statistic import (leastsquare)
 from .optimizers import (DEFAULT_MAXITER, DEFAULT_EPS, DEFAULT_ACC)
+from .spline import (SplineInterpolateFitter, SplineSmoothingFitter,
+                     SplineExactKnotsFitter, SplineSplrepFitter)
 
 __all__ = ['LinearLSQFitter', 'LevMarLSQFitter', 'FittingWithOutlierRemoval',
            'SLSQPLSQFitter', 'SimplexLSQFitter', 'JointFitter', 'Fitter',
@@ -219,6 +217,11 @@ def fitter_unit_support(func):
                 # input units (to make sure that initial guesses on the parameters)
                 # are in the right unit system
                 model = model.without_units_for_data(**rename_data)
+                if isinstance(model, tuple):
+                    rename_data['_left_kwargs'] = model[1]
+                    rename_data['_right_kwargs'] = model[2]
+                    model = model[0]
+
                 # We strip away the units from the input itself
                 add_back_units = False
 
@@ -495,12 +498,12 @@ class LinearLSQFitter(metaclass=_FitterMeta):
             Input coordinates
         z : array-like, optional
             Input coordinates.
-            If the dependent (``y`` or ``z``) co-ordinate values are provided
+            If the dependent (``y`` or ``z``) coordinate values are provided
             as a `numpy.ma.MaskedArray`, any masked points are ignored when
             fitting. Note that model set fitting is significantly slower when
             there are masked points (not just an empty mask), as the matrix
             equation has to be solved for each model separately when their
-            co-ordinate grids differ.
+            coordinate grids differ.
         weights : array, optional
             Weights for fitting.
             For data with Gaussian uncertainties, the weights should be
@@ -678,7 +681,7 @@ class LinearLSQFitter(metaclass=_FitterMeta):
             # dimensionality of rhs after _convert_input "rolls" it as needed
             # by np.linalg.lstsq. The vector then gets broadcast to the right
             # number of sets (columns). This assumes all the models share the
-            # same input co-ordinates, as is currently the case.
+            # same input coordinates, as is currently the case.
             if len(model_copy) > 1:
                 sum_of_implicit_terms = sum_of_implicit_terms[..., np.newaxis]
             rhs = rhs - sum_of_implicit_terms
@@ -877,7 +880,7 @@ class FittingWithOutlierRemoval:
         # then passed to the fitter, which is the historical behavior and
         # works even for fitters that don't understand masked arrays. For model
         # sets, the fitter must be able to filter masked data internally,
-        # because fitters require a single set of x/y co-ordinates whereas the
+        # because fitters require a single set of x/y coordinates whereas the
         # eliminated points can vary between models. To avoid this limitation,
         # we could fall back to looping over individual model fits, but it
         # would likely be fiddly and involve even more overhead (and the
@@ -894,7 +897,7 @@ class FittingWithOutlierRemoval:
             # Fitters use their input model's model_set_axis to determine how
             # their input data are stacked:
             model_set_axis = model.model_set_axis
-        # Construct input co-ordinate tuples for fitters & models that are
+        # Construct input coordinate tuples for fitters & models that are
         # appropriate for the dimensionality being fitted:
         if z is None:
             coords = (x, )
@@ -1255,7 +1258,7 @@ class SLSQPLSQFitter(Fitter):
         A linear model is passed to a nonlinear fitter
 
     Notes
-    ------
+    -----
     See also the `~astropy.modeling.optimizers.SLSQP` optimizer.
 
     """
