@@ -166,8 +166,8 @@ class _PolyDomainWindow1D(PolynomialModel):
         self._default_domain_window = {'domain': None,
                                        'window': (-1, 1)
                                        }
-        self._window = _validate_domain_window(window or (-1, 1))
-        self._domain = _validate_domain_window(domain)
+        self.window = window or (-1, 1)
+        self.domain = domain
 
     def __repr__(self):
         return self._format_repr([self.degree],
@@ -189,7 +189,7 @@ class OrthoPolynomialBase(PolynomialBase):
     The polynomials implemented here require a maximum degree in x and y.
 
     For explanation of ``x_domain``, ``y_domain``, ```x_window`` and ```y_window``
-    see :ref:`Notes regarding usage of domain and window <domain-window-note>`.
+    see :ref:`Notes regarding usage of domain and window <astropy:domain-window-note>`.
 
 
     Parameters
@@ -228,10 +228,10 @@ class OrthoPolynomialBase(PolynomialBase):
             'y_domain': None
             }
 
-        self._x_window = _validate_domain_window(x_window or self._default_domain_window['x_window'])
-        self._y_window = _validate_domain_window(y_window or self._default_domain_window['y_window'])
-        self._x_domain = _validate_domain_window(x_domain)
-        self._y_domain = _validate_domain_window(y_domain)
+        self.x_window = x_window or self._default_domain_window['x_window']
+        self.y_window = y_window or self._default_domain_window['y_window']
+        self.x_domain = x_domain
+        self.y_domain = y_domain
 
         self._param_names = self._generate_coeff_names()
         if n_models:
@@ -308,6 +308,9 @@ class OrthoPolynomialBase(PolynomialBase):
             number of coefficients
         """
 
+        if self.x_degree < 0 or self.y_degree < 0:
+            raise ValueError("Degree of polynomial must be positive or null")
+
         return (self.x_degree + 1) * (self.y_degree + 1)
 
     def _invlex(self):
@@ -399,14 +402,14 @@ class OrthoPolynomialBase(PolynomialBase):
         return self.imhorner(x, y, invcoeff)
 
     def prepare_inputs(self, x, y, **kwargs):
-        inputs, format_info = super().prepare_inputs(x, y, **kwargs)
+        inputs, broadcasted_shapes = super().prepare_inputs(x, y, **kwargs)
 
         x, y = inputs
 
         if x.shape != y.shape:
             raise ValueError("Expected input arrays to have the same shape")
 
-        return (x, y), format_info
+        return (x, y), broadcasted_shapes
 
 
 class Chebyshev1D(_PolyDomainWindow1D):
@@ -484,11 +487,11 @@ class Chebyshev1D(_PolyDomainWindow1D):
         return np.rollaxis(v, 0, v.ndim)
 
     def prepare_inputs(self, x, **kwargs):
-        inputs, format_info = super().prepare_inputs(x, **kwargs)
+        inputs, broadcasted_shapes = super().prepare_inputs(x, **kwargs)
 
         x = inputs[0]
 
-        return (x,), format_info
+        return (x,), broadcasted_shapes
 
     def evaluate(self, x, *coeffs):
         if self.domain is not None:
@@ -591,11 +594,11 @@ class Hermite1D(_PolyDomainWindow1D):
         return np.rollaxis(v, 0, v.ndim)
 
     def prepare_inputs(self, x, **kwargs):
-        inputs, format_info = super().prepare_inputs(x, **kwargs)
+        inputs, broadcasted_shapes = super().prepare_inputs(x, **kwargs)
 
         x = inputs[0]
 
-        return (x,), format_info
+        return (x,), broadcasted_shapes
 
     def evaluate(self, x, *coeffs):
         if self.domain is not None:
@@ -804,11 +807,11 @@ class Legendre1D(_PolyDomainWindow1D):
             model_set_axis=model_set_axis, name=name, meta=meta, **params)
 
     def prepare_inputs(self, x, **kwargs):
-        inputs, format_info = super().prepare_inputs(x, **kwargs)
+        inputs, broadcasted_shapes = super().prepare_inputs(x, **kwargs)
 
         x = inputs[0]
 
-        return (x,), format_info
+        return (x,), broadcasted_shapes
 
     def evaluate(self, x, *coeffs):
         if self.domain is not None:
@@ -904,14 +907,14 @@ class Polynomial1D(_PolyDomainWindow1D):
         self._default_domain_window = {'domain': (-1, 1),
                                        'window': (-1, 1),
                                        }
-        self._domain = _validate_domain_window(domain or self._default_domain_window['domain'])
-        self._domain = _validate_domain_window(window or self._default_domain_window['window'])
+        self.domain = domain or self._default_domain_window['domain']
+        self.window = window or self._default_domain_window['window']
 
     def prepare_inputs(self, x, **kwargs):
-        inputs, format_info = super().prepare_inputs(x, **kwargs)
+        inputs, broadcasted_shapes = super().prepare_inputs(x, **kwargs)
 
         x = inputs[0]
-        return (x,), format_info
+        return (x,), broadcasted_shapes
 
     def evaluate(self, x, *coeffs):
         if self.domain is not None:
@@ -1026,18 +1029,17 @@ class Polynomial2D(PolynomialModel):
             'y_window': (-1, 1)
             }
 
-        self._x_domain = _validate_domain_window(x_domain or
-            self._default_domain_window['x_domain'])
-        self._y_domain = _validate_domain_window(y_domain or self._default_domain_window['y_domain'])
-        self._x_window = _validate_domain_window(x_window or self._default_domain_window['x_window'])
-        self._y_window = _validate_domain_window(y_window or self._default_domain_window['y_window'])
+        self.x_domain = x_domain or self._default_domain_window['x_domain']
+        self.y_domain = y_domain or self._default_domain_window['y_domain']
+        self.x_window = x_window or self._default_domain_window['x_window']
+        self.y_window = y_window or self._default_domain_window['y_window']
 
     def prepare_inputs(self, x, y, **kwargs):
 
-        inputs, format_info = super().prepare_inputs(x, y, **kwargs)
+        inputs, broadcasted_shapes = super().prepare_inputs(x, y, **kwargs)
 
         x, y = inputs
-        return (x, y), format_info
+        return (x, y), broadcasted_shapes
 
     def evaluate(self, x, y, *coeffs):
         if self.x_domain is not None:
