@@ -207,7 +207,7 @@ class Pix2Sky_ZenithalPerspective(Pix2SkyProjection, Zenithal):
         R &= \sqrt{x^2 + y^2 \cos^2 \gamma}
 
     Parameters
-    --------------
+    ----------
     mu : float
         Distance from point of projection to center of sphere
         in spherical radii, μ.  Default is 0.
@@ -216,8 +216,10 @@ class Pix2Sky_ZenithalPerspective(Pix2SkyProjection, Zenithal):
         Look angle γ in degrees.  Default is 0°.
     """
 
-    mu = Parameter(default=0.0)
-    gamma = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
+    mu = Parameter(default=0.0,
+                   description="Distance from point of projection to center of sphere")
+    gamma = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian,
+                      description="Look angle γ in degrees (Default = 0°)")
 
     def __init__(self, mu=mu.default, gamma=gamma.default, **kwargs):
         # units : mu - in spherical radii, gamma - in deg
@@ -266,8 +268,8 @@ class Sky2Pix_ZenithalPerspective(Sky2PixProjection, Zenithal):
         Look angle γ in degrees. Default is 0°.
     """
 
-    mu = Parameter(default=0.0)
-    gamma = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
+    mu = Parameter(default=0.0, description="Distance from point of projection to center of sphere")
+    gamma = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian, description="Look angle γ in degrees (Default=0°)")
 
     @mu.validator
     def mu(self, value):
@@ -295,7 +297,7 @@ class Pix2Sky_SlantZenithalPerspective(Pix2SkyProjection, Zenithal):
     Corresponds to the ``SZP`` projection in FITS WCS.
 
     Parameters
-    --------------
+    ----------
     mu : float
         Distance from point of projection to center of sphere
         in spherical radii, μ.  Default is 0.
@@ -311,13 +313,13 @@ class Pix2Sky_SlantZenithalPerspective(Pix2SkyProjection, Zenithal):
 
     def _validate_mu(mu):
         if np.asarray(mu == -1).any():
-            raise ValueError(
-                "Zenithal perspective projection is not defined for mu=-1")
+            raise InputParameterError(
+                "Zenithal perspective projection is not defined for mu = -1")
         return mu
 
-    mu = Parameter(default=0.0, setter=_validate_mu)
-    phi0 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
-    theta0 = Parameter(default=90.0, getter=_to_orig_unit, setter=_to_radian)
+    mu = Parameter(default=0.0, setter=_validate_mu, description="Distance from point of projection to center of sphere")
+    phi0 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian, description="The longitude φ₀ of the reference point in degrees (Default=0°)")
+    theta0 = Parameter(default=90.0, getter=_to_orig_unit, setter=_to_radian, description="The latitude θ₀ of the reference point, in degrees (Default=0°)")
 
     @property
     def inverse(self):
@@ -356,12 +358,15 @@ class Sky2Pix_SlantZenithalPerspective(Sky2PixProjection, Zenithal):
 
     def _validate_mu(mu):
         if np.asarray(mu == -1).any():
-            raise ValueError("Zenithal perspective projection is not defined for mu=-1")
+            raise InputParameterError("Zenithal perspective projection is not defined for mu = -1")
         return mu
 
-    mu = Parameter(default=0.0, setter=_validate_mu)
-    phi0 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
-    theta0 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
+    mu = Parameter(default=0.0, setter=_validate_mu,
+                   description="Distance from point of projection to center of sphere")
+    phi0 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian,
+                     description="The longitude φ₀ of the reference point in degrees")
+    theta0 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian,
+                       description="The latitude θ₀ of the reference point, in degrees")
 
     @property
     def inverse(self):
@@ -503,8 +508,8 @@ class Pix2Sky_SlantOrthographic(Pix2SkyProjection, Zenithal):
         Obliqueness parameter, η.  Default is 0.0.
     """
 
-    xi = Parameter(default=0.0)
-    eta = Parameter(default=0.0)
+    xi = Parameter(default=0.0, description="Obliqueness parameter")
+    eta = Parameter(default=0.0, description="Obliqueness parameter")
 
     @property
     def inverse(self):
@@ -698,7 +703,7 @@ class Sky2Pix_Airy(Sky2PixProjection, Zenithal):
         The latitude :math:`\theta_b` at which to minimize the error,
         in degrees.  Default is 90°.
     """
-    theta_b = Parameter(default=90.0)
+    theta_b = Parameter(default=90.0, description="The latitude at which to minimize the error,in degrees")
 
     @property
     def inverse(self):
@@ -793,8 +798,8 @@ class Sky2Pix_CylindricalPerspective(Sky2PixProjection, Cylindrical):
         Radius of the cylinder in spherical radii, λ.  Default is 0.
     """
 
-    mu = Parameter(default=1.0)
-    lam = Parameter(default=1.0)
+    mu = Parameter(default=1.0, description="Distance from center of sphere in spherical radii")
+    lam = Parameter(default=1.0, description="Radius of the cylinder in spherical radii")
 
     @mu.validator
     def mu(self, value):
@@ -833,7 +838,7 @@ class Pix2Sky_CylindricalEqualArea(Pix2SkyProjection, Cylindrical):
     Parameters
     ----------
     lam : float
-        Radius of the cylinder in spherical radii, λ.  Default is 0.
+        Radius of the cylinder in spherical radii, λ.  Default is 1.
     """
 
     lam = Parameter(default=1)
@@ -1645,7 +1650,7 @@ class Sky2Pix_BonneEqualArea(Sky2PixProjection, PseudoConic):
     theta1 : float
         Bonne conformal latitude, in degrees.
     """
-    theta1 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
+    theta1 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian, description="Bonne conformal latitude, in degrees")
     _separable = True
 
     @property
@@ -1859,8 +1864,8 @@ class Pix2Sky_HEALPix(Pix2SkyProjection, HEALPix):
     """
     _separable = True
 
-    H = Parameter(default=4.0)
-    X = Parameter(default=3.0)
+    H = Parameter(default=4.0, description="The number of facets in longitude direction.")
+    X = Parameter(default=3.0, description="The number of facets in latitude direction.")
 
     @property
     def inverse(self):
@@ -1890,8 +1895,8 @@ class Sky2Pix_HEALPix(Sky2PixProjection, HEALPix):
     """
     _separable = True
 
-    H = Parameter(default=4.0)
-    X = Parameter(default=3.0)
+    H = Parameter(default=4.0, description="The number of facets in longitude direction.")
+    X = Parameter(default=3.0, description="The number of facets in latitude direction.")
 
     @property
     def inverse(self):
@@ -1915,7 +1920,7 @@ class Pix2Sky_HEALPixPolar(Pix2SkyProjection, HEALPix):
 
     @property
     def inverse(self):
-        return Sky2Pix_HEALPix()
+        return Sky2Pix_HEALPixPolar()
 
     @classmethod
     def evaluate(cls, x, y):
@@ -1935,11 +1940,11 @@ class Sky2Pix_HEALPixPolar(Sky2PixProjection, HEALPix):
 
     @property
     def inverse(self):
-        return Pix2Sky_HEALPix()
+        return Pix2Sky_HEALPixPolar()
 
     @classmethod
     def evaluate(cls, phi, theta):
-        return _projections.hpxs2x(phi, theta)
+        return _projections.xphs2x(phi, theta)
 
 
 Sky2Pix_XPH = Sky2Pix_HEALPixPolar
