@@ -84,7 +84,7 @@ class RotationSequence3D(Model):
     n_inputs = 3
     n_outputs = 3
 
-    angles = Parameter(default=[], getter=_to_orig_unit, setter=_to_radian)
+    angles = Parameter(default=[], getter=_to_orig_unit, setter=_to_radian, description="Angles of rotation in deg in the order of axes_order")
 
     def __init__(self, angles, axes_order, name=None):
         self.axes = ['x', 'y', 'z']
@@ -95,9 +95,8 @@ class RotationSequence3D(Model):
                                                             self.axes))
         self.axes_order = axes_order
         if len(angles) != len(axes_order):
-            raise ValueError("The number of angles {0} should match the number \
-                              of axes {1}.".format(len(angles),
-                                                   len(axes_order)))
+            raise ValueError("The number of angles {0} should match the number of axes {1}."
+                             .format(len(angles), len(axes_order)))
         super().__init__(angles, name=name)
         self._inputs = ('x', 'y', 'z')
         self._outputs = ('x', 'y', 'z')
@@ -112,7 +111,7 @@ class RotationSequence3D(Model):
         """
         Apply the rotation to a set of 3D Cartesian coordinates.
         """
-        if x.shape != y.shape != z.shape:
+        if x.shape != y.shape or x.shape != z.shape:
             raise ValueError("Expected input arrays to have the same shape")
         # Note: If the original shape was () (an array scalar) convert to a
         # 1-element 1-D array on output for consistency with most other models
@@ -220,15 +219,18 @@ class EulerAngleRotation(_EulerRotation, Model):
     n_inputs = 2
     n_outputs = 2
 
-    phi = Parameter(default=0, getter=_to_orig_unit, setter=_to_radian)
-    theta = Parameter(default=0, getter=_to_orig_unit, setter=_to_radian)
-    psi = Parameter(default=0, getter=_to_orig_unit, setter=_to_radian)
+    phi = Parameter(default=0, getter=_to_orig_unit, setter=_to_radian,
+    description="1st Euler angle (Quantity or value in deg)")
+    theta = Parameter(default=0, getter=_to_orig_unit, setter=_to_radian,
+    description="2nd Euler angle (Quantity or value in deg)")
+    psi = Parameter(default=0, getter=_to_orig_unit, setter=_to_radian,
+    description="3rd Euler angle (Quantity or value in deg)")
 
     def __init__(self, phi, theta, psi, axes_order, **kwargs):
         self.axes = ['x', 'y', 'z']
         if len(axes_order) != 3:
             raise TypeError(
-                "Expected axes_order to be a character sequence of length 3,"
+                "Expected axes_order to be a character sequence of length 3, "
                 "got {}".format(axes_order))
         unrecognized = set(axes_order).difference(self.axes)
         if unrecognized:
@@ -260,9 +262,9 @@ class _SkyRotation(_EulerRotation, Model):
     Base class for RotateNative2Celestial and RotateCelestial2Native.
     """
 
-    lon = Parameter(default=0, getter=_to_orig_unit, setter=_to_radian)
-    lat = Parameter(default=0, getter=_to_orig_unit, setter=_to_radian)
-    lon_pole = Parameter(default=0, getter=_to_orig_unit, setter=_to_radian)
+    lon = Parameter(default=0, getter=_to_orig_unit, setter=_to_radian, description="Latitude")
+    lat = Parameter(default=0, getter=_to_orig_unit, setter=_to_radian, description="Longtitude")
+    lon_pole = Parameter(default=0, getter=_to_orig_unit, setter=_to_radian, description="Longitude of a pole")
 
     def __init__(self, lon, lat, lon_pole, **kwargs):
         qs = [isinstance(par, u.Quantity) for par in [lon, lat, lon_pole]]
@@ -450,7 +452,8 @@ class Rotation2D(Model):
 
     _separable = False
 
-    angle = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
+    angle = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian,
+    description="Angle of rotation (Quantity or value in deg)")
 
     def __init__(self, angle=angle, **kwargs):
         super().__init__(angle=angle, **kwargs)
