@@ -83,11 +83,6 @@ class _Tabular(Model):
 
     standard_broadcasting = False
 
-    @property
-    @abc.abstractmethod
-    def lookup_table(self):
-        pass
-
     _is_dynamic = True
 
     _id = 0
@@ -138,9 +133,8 @@ class _Tabular(Model):
         self.fill_value = fill_value
 
     def __repr__(self):
-        fmt = "<{}(points={}, lookup_table={})>".format(
+        return "<{}(points={}, lookup_table={})>".format(
             self.__class__.__name__, self.points, self.lookup_table)
-        return fmt
 
     def __str__(self):
         default_keywords = [
@@ -186,17 +180,30 @@ class _Tabular(Model):
         >>> from astropy.modeling.models import Tabular1D, Tabular2D
         >>> t1 = Tabular1D(points=[1, 2, 3], lookup_table=[10, 20, 30])
         >>> t1.bounding_box
-        (1, 3)
+        ModelBoundingBox(
+            intervals={
+                x: Interval(lower=1, upper=3)
+            }
+            model=Tabular1D(inputs=('x',))
+            order='C'
+        )
         >>> t2 = Tabular2D(points=[[1, 2, 3], [2, 3, 4]],
         ...                lookup_table=[[10, 20, 30], [20, 30, 40]])
         >>> t2.bounding_box
-        ((2, 4), (1, 3))
+        ModelBoundingBox(
+            intervals={
+                x: Interval(lower=1, upper=3)
+                y: Interval(lower=2, upper=4)
+            }
+            model=Tabular2D(inputs=('x', 'y'))
+            order='C'
+        )
 
         """
         bbox = [(min(p), max(p)) for p in self.points][::-1]
         if len(bbox) == 1:
             bbox = bbox[0]
-        return tuple(bbox)
+        return bbox
 
     def evaluate(self, *inputs):
         """
@@ -210,8 +217,6 @@ class _Tabular(Model):
         """
         inputs = np.broadcast_arrays(*inputs)
 
-        if isinstance(inputs, u.Quantity):
-            inputs = inputs.value
         shape = inputs[0].shape
         inputs = [inp.flatten() for inp in inputs[: self.n_inputs]]
         inputs = np.array(inputs).T
@@ -235,7 +240,7 @@ class _Tabular(Model):
     @property
     def inverse(self):
         if self.n_inputs == 1:
-            # If the wavelength array is decending instead of ascending, both
+            # If the wavelength array is descending instead of ascending, both
             # points and lookup_table need to be reversed in the inverse transform
             # for scipy.interpolate to work properly
             if np.all(np.diff(self.lookup_table) > 0):
