@@ -51,7 +51,9 @@ Explanation of keywords of the dictionaries:
 
 
 from astropy.modeling.functional_models import (
-    Gaussian1D, Sine1D, Box1D, Linear1D, Lorentz1D,
+    Gaussian1D,
+    Sine1D, Cosine1D, Tangent1D, ArcSine1D, ArcCosine1D, ArcTangent1D,
+    Box1D, Linear1D, Lorentz1D,
     RickerWavelet1D, Trapezoid1D, Const1D, Moffat1D,
     Gaussian2D, Const2D, Box2D, RickerWavelet2D,
     TrapezoidDisk2D, AiryDisk2D, Moffat2D, Disk2D,
@@ -71,7 +73,8 @@ models_1D = {
         'x_values': [0, np.sqrt(2), -np.sqrt(2)],
         'y_values': [1.0, 0.367879, 0.367879],
         'x_lim': [-10, 10],
-        'integral': np.sqrt(2 * np.pi)
+        'integral': np.sqrt(2 * np.pi),
+        'bbox_peak': True
     },
 
     Sine1D: {
@@ -82,12 +85,53 @@ models_1D = {
         'integral': 0
     },
 
+    Cosine1D: {
+        'parameters': [1, 0.1, 0],
+        'x_values': [0, 2.5],
+        'y_values': [1, 0],
+        'x_lim': [-10, 10],
+        'integral': 0
+    },
+
+    Tangent1D: {
+        'parameters': [1, 0.1, 0],
+        'x_values': [0, 1.25],
+        'y_values': [0, 1],
+        'x_lim': [-10, 10],
+        'integral': 0
+    },
+
+    ArcSine1D: {
+        'parameters': [1, 0.1, 0],
+        'x_values': [0, 1],
+        'y_values': [0, 2.5],
+        'x_lim': [-0.5, 0.5],
+        'integral': 0
+    },
+
+    ArcCosine1D: {
+        'parameters': [1, 0.1, 0],
+        'x_values': [1, 0],
+        'y_values': [0, 2.5],
+        'x_lim': [-0.5, 0.5],
+        'integral': 0
+    },
+
+    ArcTangent1D: {
+        'parameters': [1, 0.1, 0],
+        'x_values': [0, 1],
+        'y_values': [0, 1.25],
+        'x_lim': [-10, 10],
+        'integral': 0
+    },
+
     Box1D: {
         'parameters': [1, 0, 10],
         'x_values': [-5, 5, 0, -10, 10],
         'y_values': [1, 1, 1, 0, 0],
         'x_lim': [-10, 10],
-        'integral': 10
+        'integral': 10,
+        'bbox_peak': True
     },
 
     Linear1D: {
@@ -103,7 +147,8 @@ models_1D = {
         'x_values': [0, -1, 1, 0.5, -0.5],
         'y_values': [1., 0.2, 0.2, 0.5, 0.5],
         'x_lim': [-10, 10],
-        'integral': 1
+        'integral': 1,
+        'bbox_peak': True
     },
 
     RickerWavelet1D: {
@@ -111,7 +156,8 @@ models_1D = {
         'x_values': [0, 1, -1, 3, -3],
         'y_values': [1.0, 0.0, 0.0, -0.088872, -0.088872],
         'x_lim': [-20, 20],
-        'integral': 0
+        'integral': 0,
+        'bbox_peak': True
     },
 
     Trapezoid1D: {
@@ -119,7 +165,8 @@ models_1D = {
         'x_values': [0, 1, -1, 1.5, -1.5, 2, 2],
         'y_values': [1, 1, 1, 0.5, 0.5, 0, 0],
         'x_lim': [-10, 10],
-        'integral': 3
+        'integral': 3,
+        'bbox_peak': True
     },
 
     Const1D: {
@@ -207,8 +254,9 @@ models_1D = {
 
     Voigt1D: {
         'parameters': [0, 1, 0.5, 0.9],
-        'x_values': [0, 2, 4, 8, 10],
-        'y_values': [0.520935, 0.017205, 0.003998, 0.000983, 0.000628],
+        'x_values': [0, 0.2, 0.5, 1, 2, 4, 8, 20],
+        'y_values': [0.52092360, 0.479697445, 0.317550374, 0.0988079347,
+                     1.73876624e-2, 4.00173216e-3, 9.82351731e-4, 1.56396993e-4],
         'x_lim': [-3, 3]
      },
 
@@ -218,6 +266,7 @@ models_1D = {
         'y_values': [0.30557281, 0.30011069, 0.2, 0.1113258],
         'x_lim': [0, 10],
         'y_lim': [0, 10],
+        'bbox_peak': True
     },
 
     Drude1D: {
@@ -225,7 +274,8 @@ models_1D = {
         'x_values': [7.0, 8.0, 9.0, 10.0],
         'y_values': [0.17883212, 1.0, 0.21891892, 0.07163324],
         'x_lim': [1.0, 20.0],
-        'y_lim': [0.0, 10.0]
+        'y_lim': [0.0, 10.0],
+        'bbox_peak': True
     },
 
     Plummer1D: {
@@ -265,7 +315,8 @@ models_2D = {
         'y_lim': [-10, 10],
         'integral': 2 * np.pi,
         'deriv_parameters': [137., 5.1, 5.4, 1.5, 2., np.pi/4],
-        'deriv_initial': [10, 5, 5, 4, 4, .5]
+        'deriv_initial': [10, 5, 5, 4, 4, .5],
+        'bbox_peak': True
     },
 
     Const2D: {
@@ -285,7 +336,8 @@ models_2D = {
         'z_values': [1, 1, 1, 1, 1, 0, 0],
         'x_lim': [-10, 10],
         'y_lim': [-10, 10],
-        'integral': 100
+        'integral': 100,
+        'bbox_peak': True
     },
 
     RickerWavelet2D: {
@@ -305,7 +357,8 @@ models_2D = {
         'y_values': [0, 0.5, 1.5, 0],
         'z_values': [1, 1, 0.5, 0.5],
         'x_lim': [-3, 3],
-        'y_lim': [-3, 3]
+        'y_lim': [-3, 3],
+        'bbox_peak': True
     },
 
     AiryDisk2D: {
@@ -343,7 +396,8 @@ models_2D = {
         'z_values': [0, 0, 1, 1, 1, 0, 0],
         'x_lim': [-10, 10],
         'y_lim': [-10, 10],
-        'integral': np.pi * 5 ** 2
+        'integral': np.pi * 5 ** 2,
+        'bbox_peak': True
     },
 
     Ring2D: {
@@ -353,7 +407,8 @@ models_2D = {
         'z_values': [1, 1, 1, 1, 0, 0, 0],
         'x_lim': [-10, 10],
         'y_lim': [-10, 10],
-        'integral': np.pi * (10 ** 2 - 5 ** 2)
+        'integral': np.pi * (10 ** 2 - 5 ** 2),
+        'bbox_peak': True
     },
 
     Sersic2D: {
