@@ -115,7 +115,7 @@ class Record:
         try:
             farr = np.array(xyz)
         except Exception:
-            log.debug("Could not read array field {}".format(fieldlist[0].split()[0]))
+            log.debug(f"Could not read array field {fieldlist[0].split()[0]}")
         return farr.astype(np.float64)
 
 
