@@ -14,8 +14,9 @@ from astropy.modeling.parameters import Parameter
 from astropy.modeling.models import (Const1D, Shift, Scale, Rotation2D, Gaussian1D,
                                      Gaussian2D, Polynomial1D, Polynomial2D,
                                      Chebyshev2D, Legendre2D, Chebyshev1D, Legendre1D,
-                                     Identity, Mapping,
-                                     Tabular1D, fix_inputs)
+                                     Identity, Mapping, Linear1D,
+                                     Tabular1D, fix_inputs,)
+from astropy.modeling.fitting import LevMarLSQFitter
 import astropy.units as u
 from astropy.utils.compat.optional_deps import HAS_SCIPY  # noqa
 
@@ -919,3 +920,149 @@ def test_compound_evaluate_fix_inputs_by_position():
         compound.evaluate(x, y, *model_params),
         model.evaluate(x + 5, y, *model_params),
     )
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_fit_multiplied_compound_model_with_mixed_units():
+    """
+    Regression test for issue #12320
+    """
+
+    fitter = LevMarLSQFitter()
+    x = np.linspace(0, 1, 101) * u.s
+    y = np.linspace(5, 10, 101) * u.m * u.kg / u.s
+
+    m1 = Linear1D(slope=5*u.m/u.s/u.s, intercept=1.0*u.m/u.s)
+    m2 = Linear1D(slope=0.0*u.kg/u.s, intercept=10.0*u.kg)
+    truth = m1 * m2
+    fit = fitter(truth, x, y)
+
+    unfit_output = truth(x)
+    fit_output = fit(x)
+
+    assert unfit_output.unit == fit_output.unit == (u.kg * u.m / u.s)
+    assert_allclose(unfit_output, fit_output)
+
+    for name in truth.param_names:
+        assert getattr(truth, name) == getattr(fit, name)
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_fit_multiplied_recursive_compound_model_with_mixed_units():
+    """
+    Regression test for issue #12320
+    """
+
+    fitter = LevMarLSQFitter()
+
+    x = np.linspace(0, 1, 101) * u.s
+    y = np.linspace(5, 10, 101) * u.m * u.m * u.kg / u.s
+
+    m1 = Linear1D(slope=5*u.m/u.s/u.s, intercept=1.0*u.m/u.s)
+    m2 = Linear1D(slope=0.0*u.kg/u.s, intercept=10.0*u.kg)
+    m3 = Linear1D(slope=0.0*u.m/u.s, intercept=10.0*u.m)
+    truth = m1 * m2 * m3
+    fit = fitter(truth, x, y)
+
+    unfit_output = truth(x)
+    fit_output = fit(x)
+
+    assert unfit_output.unit == fit_output.unit == (u.kg * u.m * u.m / u.s)
+    assert_allclose(unfit_output, fit_output)
+
+    for name in truth.param_names:
+        assert getattr(truth, name) == getattr(fit, name)
+
+    x = np.linspace(0, 1, 101) * u.s
+    y = np.linspace(5, 10, 101) * u.m * u.m * u.kg * u.kg / u.s
+
+    m1 = Linear1D(slope=5*u.m/u.s/u.s, intercept=1.0*u.m/u.s)
+    m2 = Linear1D(slope=0.0*u.kg/u.s, intercept=10.0*u.kg)
+    m3 = Linear1D(slope=0.0*u.m/u.s, intercept=10.0*u.m)
+    m4 = Linear1D(slope=0.0*u.kg/u.s, intercept=10.0*u.kg)
+    m11 = m1 * m2
+    m22 = m3 * m4
+    truth = m11 * m22
+    fit = fitter(truth, x, y)
+
+    unfit_output = truth(x)
+    fit_output = fit(x)
+
+    assert unfit_output.unit == fit_output.unit == (u.kg * u.kg * u.m * u.m / u.s)
+    assert_allclose(unfit_output, fit_output)
+
+    for name in truth.param_names:
+        assert getattr(truth, name) == getattr(fit, name)
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_fit_divided_compound_model_with_mixed_units():
+    """
+    Regression test for issue #12320
+    """
+
+    fitter = LevMarLSQFitter()
+    x = np.linspace(0, 1, 101) * u.s
+    y = np.linspace(5, 10, 101) * u.kg * u.m / u.s
+
+    m1 = Linear1D(slope=5*u.kg*u.m/u.s, intercept=1.0*u.kg*u.m)
+    m2 = Linear1D(slope=0.0*u.s/u.s, intercept=10.0*u.s)
+    truth = m1 / m2
+    fit = fitter(truth, x, y)
+
+    unfit_output = truth(x)
+    fit_output = fit(x)
+
+    assert unfit_output.unit == fit_output.unit == (u.kg * u.m / u.s)
+    assert_allclose(unfit_output, fit_output)
+
+    for name in truth.param_names:
+        assert getattr(truth, name) == getattr(fit, name)
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_fit_mixed_recursive_compound_model_with_mixed_units():
+    """
+    Regression test for issue #12320
+    """
+
+    fitter = LevMarLSQFitter()
+
+    x = np.linspace(0, 1, 101) * u.s
+    y = np.linspace(5, 10, 101) * u.kg * u.m * u.m / u.s
+
+    m1 = Linear1D(slope=5*u.kg*u.m/u.s, intercept=1.0*u.kg*u.m)
+    m2 = Linear1D(slope=0.0*u.s/u.s, intercept=10.0*u.s)
+    m3 = Linear1D(slope=0.0*u.m/u.s, intercept=10.0*u.m)
+    truth = m1 / m2 * m3
+    fit = fitter(truth, x, y)
+
+    unfit_output = truth(x)
+    fit_output = fit(x)
+
+    assert unfit_output.unit == fit_output.unit == (u.kg * u.m * u.m / u.s)
+    assert_allclose(unfit_output, fit_output)
+
+    for name in truth.param_names:
+        assert getattr(truth, name) == getattr(fit, name)
+
+    x = np.linspace(0, 1, 101) * u.s
+    y = np.linspace(5, 10, 101) * u.kg * u.kg * u.m * u.m / u.s
+
+    m1 = Linear1D(slope=5*u.kg*u.m/u.s, intercept=1.0*u.kg*u.m)
+    m2 = Linear1D(slope=0.0*u.s/u.s, intercept=10.0*u.s)
+    m3 = Linear1D(slope=0.0*u.m/u.s, intercept=10.0*u.m)
+    m4 = Linear1D(slope=0.0*u.kg/u.s, intercept=10.0*u.kg)
+    m11 = m1 / m2
+    m22 = m3 * m4
+    truth = m11 * m22
+    fit = fitter(truth, x, y)
+
+    unfit_output = truth(x)
+    fit_output = fit(x)
+
+    assert unfit_output.unit == fit_output.unit == (u.kg * u.kg * u.m * u.m / u.s)
+    assert_allclose(unfit_output, fit_output)
+
+    for name in truth.param_names:
+        assert getattr(truth, name) == getattr(fit, name)
