@@ -6,7 +6,6 @@ import pytest
 
 from astropy import units as u
 from astropy.tests.helper import assert_quantity_allclose
-from astropy.utils.exceptions import AstropyDeprecationWarning
 
 from astropy.modeling.models import Mapping, Pix2Sky_TAN, Gaussian1D
 from astropy.modeling import models
@@ -15,7 +14,7 @@ from astropy.modeling.core import _ModelMeta
 
 def test_gaussian1d_bounding_box():
     g = Gaussian1D(mean=3 * u.m, stddev=3 * u.cm, amplitude=3 * u.Jy)
-    bbox = g.bounding_box
+    bbox = g.bounding_box.bounding_box()
     assert_quantity_allclose(bbox[0], 2.835 * u.m)
     assert_quantity_allclose(bbox[1], 3.165 * u.m)
 
@@ -115,10 +114,7 @@ def _allmodels():
         model = getattr(models, name)
         if type(model) is _ModelMeta:
             try:
-                with warnings.catch_warnings():
-                    # Ignore deprecation warnings from BlackBody1D and MexicanHat
-                    warnings.simplefilter('ignore', category=AstropyDeprecationWarning)
-                    m = model()
+                m = model()
             except Exception:
                 pass
             allmodels.append(m)
