@@ -8,10 +8,11 @@ import pytest
 import numpy as np
 from numpy.testing import assert_allclose
 
-from astropy.modeling import models
+from astropy.modeling import custom_model, models
 from astropy.modeling.models import Mapping
 from astropy.modeling.separable import (_coord_matrix, is_separable, _cdot,
                                         _cstack, _arith_oper, separability_matrix)
+from astropy.modeling.core import ModelDefinitionError
 
 
 sh1 = models.Shift(1, name='shift1')
@@ -27,6 +28,13 @@ p22 = models.Polynomial2D(2, name='p22')
 p1 = models.Polynomial1D(1, name='p1')
 
 
+cm_4d_expected = (np.array([False, False, True, True]),
+                  np.array([[True,  True,  False, False],
+                            [True,  True,  False, False],
+                            [False, False, True,  False],
+                            [False, False, False, True]]))
+
+
 compound_models = {
     'cm1': (map3 & sh1 | rot & sh1 | sh1 & sh2 & sh1,
             (np.array([False, False, True]),
@@ -51,7 +59,17 @@ compound_models = {
     'cm7': (map2 | p2 & sh1,
             (np.array([False, True]),
              np.array([[True, False], [False, True]]))
-            )
+            ),
+    'cm8': (rot & (sh1 & sh2), cm_4d_expected),
+    'cm9': (rot & sh1 & sh2, cm_4d_expected),
+    'cm10': ((rot & sh1) & sh2, cm_4d_expected),
+    'cm11': (rot & sh1 & (scl1 & scl2),
+             (np.array([False, False, True, True, True]),
+              np.array([[True,  True,  False, False, False],
+                        [True,  True,  False, False, False],
+                        [False, False, True,  False, False],
+                        [False, False, False, True,  False],
+                        [False, False, False, False, True]]))),
 }
 
 
@@ -89,6 +107,10 @@ def test_cdot():
     result = _cdot(Mapping((0, 0)), rot)
     assert_allclose(result, np.array([[2], [2]]))
 
+    with pytest.raises(ModelDefinitionError,
+                       match=r"Models cannot be combined with the \"|\" operator; .*"):
+        _cdot(sh1, map1)
+
 
 def test_cstack():
     result = _cstack(sh1, scl1)
@@ -109,13 +131,37 @@ def test_cstack():
 
 
 def test_arith_oper():
+    # Models as inputs
     result = _arith_oper(sh1, scl1)
     assert_allclose(result, np.array([[1]]))
     result = _arith_oper(rot, rot)
     assert_allclose(result, np.array([[1, 1], [1, 1]]))
 
+    # ndarray
+    result = _arith_oper(np.array([[1, 2], [3, 4]]), np.array([[1, 2], [3, 4]]))
+    assert_allclose(result, np.array([[1, 1], [1, 1]]))
+
+    # Error
+    with pytest.raises(ModelDefinitionError, match=r"Unsupported operands for arithmetic operator: .*"):
+        _arith_oper(sh1, map1)
+
 
 @pytest.mark.parametrize(('compound_model', 'result'), compound_models.values())
 def test_separable(compound_model, result):
     assert_allclose(is_separable(compound_model), result[0])
     assert_allclose(separability_matrix(compound_model), result[1])
+
+
+def test_custom_model_separable():
+    @custom_model
+    def model_a(x):
+        return x
+
+    assert model_a().separable
+
+    @custom_model
+    def model_c(x, y):
+        return x + y
+
+    assert not model_c().separable
+    assert np.all(separability_matrix(model_c()) == [True, True])
