@@ -1,7 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """
 This subpackage provides classes to communicate with other applications via the
-`Simple Application Messaging Protocal (SAMP)
+`Simple Application Messaging Protocol (SAMP)
 <http://www.ivoa.net/documents/SAMP/>`_.
 
 Before integration into Astropy it was known as
