@@ -156,8 +156,9 @@ class BST:
         Sorted columns of the original table
     row_index : Column object
         Row numbers corresponding to data columns
-    unique : bool (defaults to False)
-        Whether the values of the index must be unique
+    unique : bool
+        Whether the values of the index must be unique.
+        Defaults to False.
     '''
     NodeClass = Node
 
@@ -393,11 +394,11 @@ class BST:
             Lower bound
         upper : tuple
             Upper bound
-        bounds : tuple (x, y) of bools
+        bounds : (2,) tuple of bool
             Indicates whether the search should be inclusive or
             exclusive with respect to the endpoints. The first
-            argument x corresponds to an inclusive lower bound,
-            and the second argument y to an inclusive upper bound.
+            argument corresponds to an inclusive lower bound,
+            and the second argument to an inclusive upper bound.
         '''
         nodes = self.range_nodes(lower, upper, bounds)
         return [x for node in nodes for x in node.data]
@@ -442,13 +443,8 @@ class BST:
             self._same_prefix(val, node.left, lst)
         return lst
 
-    def __str__(self):
-        if self.root is None:
-            return 'Empty'
-        return self._print(self.root, 0)
-
     def __repr__(self):
-        return str(self)
+        return f'<{self.__class__.__name__}>'
 
     def _print(self, node, level):
         line = '\t' * level + str(node) + '\n'
