@@ -96,7 +96,7 @@ def get_auto_format_func(
                 if val is np.ma.masked:
                     return str(val)
 
-                raise ValueError(f'Format function for value {val} failed: {err}')
+                raise ValueError(f'Format function for value {val} failed.') from err
             # If the user-supplied function handles formatting masked elements, use
             # it directly.  Otherwise, wrap it in a function that traps them.
             try:
@@ -189,6 +189,10 @@ class TableFormatter:
         max_lines, max_width : int
 
         """
+        # Declare to keep static type checker happy.
+        lines = None
+        width = None
+
         if max_lines is None:
             max_lines = conf.max_lines
 
@@ -394,7 +398,7 @@ class TableFormatter:
             try:
                 dtype = dtype_info_name(col.dtype)
             except AttributeError:
-                dtype = 'object'
+                dtype = col.__class__.__qualname__ or 'object'
             yield str(dtype)
         if show_unit or show_name or show_dtype:
             i_dashes = n_header
@@ -539,7 +543,6 @@ class TableFormatter:
         # "Print" all the values into temporary lists by column for subsequent
         # use and to determine the width
         max_lines, max_width = self._get_pprint_size(max_lines, max_width)
-        cols = []
 
         if show_unit is None:
             show_unit = any(col.info.unit for col in table.columns.values())
@@ -562,6 +565,8 @@ class TableFormatter:
         # pprint_exclude_names attributes and get the set of columns to show.
         pprint_include_names = _get_pprint_include_names(table)
 
+        cols = []
+        outs = None  # Initialize so static type checker is happy
         for align_, col in zip(align, table.columns.values()):
             if col.info.name not in pprint_include_names:
                 continue
