@@ -17,7 +17,8 @@ import pytest
 import numpy as np
 
 from astropy import table
-from astropy.table import table_helpers, Table, QTable
+from astropy.table import Table, QTable
+from astropy.table.table_helpers import ArrayWrapper
 from astropy import time
 from astropy import units as u
 from astropy import coordinates
@@ -134,6 +135,7 @@ MIXIN_COLS = {'quantity': [0, 1, 2, 3] * u.m,
                                                  wrap_angle=180. * u.deg),
               'latitude': coordinates.Latitude([5., 6., 10., 11.] * u.deg),
               'time': time.Time([2000, 2001, 2002, 2003], format='jyear'),
+              'timedelta': time.TimeDelta([1, 2, 3, 4], format='jd'),
               'skycoord': coordinates.SkyCoord(ra=[0, 1, 2, 3] * u.deg,
                                                dec=[0, 1, 2, 3] * u.deg),
               'sphericalrep': coordinates.SphericalRepresentation(
@@ -143,9 +145,12 @@ MIXIN_COLS = {'quantity': [0, 1, 2, 3] * u.m,
               'sphericaldiff': coordinates.SphericalCosLatDifferential(
                   [0, 1, 2, 3]*u.mas/u.yr, [0, 1, 2, 3]*u.mas/u.yr,
                   10*u.km/u.s),
-              'arraywrap': table_helpers.ArrayWrapper([0, 1, 2, 3]),
-              'ndarray': np.array([(7, 'a'), (8, 'b'), (9, 'c'), (9, 'c')],
+              'arraywrap': ArrayWrapper([0, 1, 2, 3]),
+              'arrayswap': ArrayWrapper(np.arange(4, dtype='i').byteswap().newbyteorder()),
+              'ndarraylil': np.array([(7, 'a'), (8, 'b'), (9, 'c'), (9, 'c')],
                                   dtype='<i4,|S1').view(table.NdarrayMixin),
+              'ndarraybig': np.array([(7, 'a'), (8, 'b'), (9, 'c'), (9, 'c')],
+                                  dtype='>i4,|S1').view(table.NdarrayMixin),
               }
 MIXIN_COLS['earthlocation'] = coordinates.EarthLocation(
     lon=MIXIN_COLS['longitude'], lat=MIXIN_COLS['latitude'],
