@@ -3,20 +3,19 @@
 import fnmatch
 import time
 import re
-import sys
 import datetime
 import warnings
 from decimal import Decimal
 from collections import OrderedDict, defaultdict
-from pathlib import Path
 
 import numpy as np
 import erfa
 
 from astropy.utils.decorators import lazyproperty, classproperty
 from astropy.utils.exceptions import AstropyDeprecationWarning
-from astropy import units as u
+import astropy.units as u
 
+from . import _parse_times
 from . import utils
 from .utils import day_frac, quantity_day_frac, two_sum, two_product
 from . import conf
@@ -77,37 +76,7 @@ def _regexify_subfmts(subfmts):
     return tuple(new_subfmts)
 
 
-class TimeFormatMeta(type):
-    """
-    Metaclass that adds `TimeFormat` and `TimeDeltaFormat` to the
-    `TIME_FORMATS` and `TIME_DELTA_FORMATS` registries, respectively.
-    """
-
-    _registry = TIME_FORMATS
-
-    def __new__(mcls, name, bases, members):
-        cls = super().__new__(mcls, name, bases, members)
-
-        # Register time formats that have a name, but leave out astropy_time since
-        # it is not a user-accessible format and is only used for initialization into
-        # a different format.
-        if 'name' in members and cls.name != 'astropy_time':
-            # FIXME: check here that we're not introducing a collision with
-            # an existing method or attribute; problem is it could be either
-            # astropy.time.Time or astropy.time.TimeDelta, and at the point
-            # where this is run neither of those classes have necessarily been
-            # constructed yet.
-            if 'value' in members and not hasattr(members['value'], "fget"):
-                raise ValueError("If defined, 'value' must be a property")
-            mcls._registry[cls.name] = cls
-
-        if 'subfmts' in members:
-            cls.subfmts = _regexify_subfmts(members['subfmts'])
-
-        return cls
-
-
-class TimeFormat(metaclass=TimeFormatMeta):
+class TimeFormat:
     """
     Base class for time representations.
 
@@ -132,6 +101,7 @@ class TimeFormat(metaclass=TimeFormatMeta):
 
     _default_scale = 'utc'  # As of astropy 0.4
     subfmts = ()
+    _registry = TIME_FORMATS
 
     def __init__(self, val1, val2, scale, precision,
                  in_subfmt, out_subfmt, from_jd=False):
@@ -149,6 +119,27 @@ class TimeFormat(metaclass=TimeFormatMeta):
             val1, val2 = self._check_val_type(val1, val2)
             self.set_jds(val1, val2)
 
+    def __init_subclass__(cls, **kwargs):
+        # Register time formats that define a name, but leave out astropy_time since
+        # it is not a user-accessible format and is only used for initialization into
+        # a different format.
+        if 'name' in cls.__dict__ and cls.name != 'astropy_time':
+            # FIXME: check here that we're not introducing a collision with
+            # an existing method or attribute; problem is it could be either
+            # astropy.time.Time or astropy.time.TimeDelta, and at the point
+            # where this is run neither of those classes have necessarily been
+            # constructed yet.
+            if 'value' in cls.__dict__ and not hasattr(cls.value, "fget"):
+                raise ValueError("If defined, 'value' must be a property")
+
+            cls._registry[cls.name] = cls
+
+        # If this class defines its own subfmts, preprocess the definitions.
+        if 'subfmts' in cls.__dict__:
+            cls.subfmts = _regexify_subfmts(cls.subfmts)
+
+        return super().__init_subclass__(**kwargs)
+
     @classmethod
     def _get_allowed_subfmt(cls, subfmt):
         """Get an allowed subfmt for this class, either the input ``subfmt``
@@ -266,7 +257,7 @@ class TimeFormat(metaclass=TimeFormatMeta):
         if getattr(val1, 'unit', None) is not None:
             # Convert any quantity-likes to days first, attempting to be
             # careful with the conversion, so that, e.g., large numbers of
-            # seconds get converted without loosing precision because
+            # seconds get converted without losing precision because
             # 1/86400 is not exactly representable as a float.
             val1 = u.Quantity(val1, copy=False)
             if val2 is not None:
@@ -458,7 +449,7 @@ class TimeNumeric(TimeFormat):
         Subclasses that require ``parent`` or to adjust the jds should
         override this method.
         """
-        # TODO: do this in metaclass.
+        # TODO: do this in __init_subclass__?
         if self.__class__.value.fget is not self.__class__.to_value:
             return self.value
 
@@ -1259,43 +1250,19 @@ class TimeString(TimeUnique):
       day-of-year
     """
 
-    @classproperty(lazy=True)
-    def time_struct_dtype(cls):
-        return np.dtype([('year', np.intc),
-                         ('month', np.intc),
-                         ('day', np.intc),
-                         ('hour', np.intc),
-                         ('minute', np.intc),
-                         ('second_int', np.intc),
-                         ('second_frac', np.double)])
+    def __init_subclass__(cls, **kwargs):
+        if 'fast_parser_pars' in cls.__dict__:
+            fpp = cls.fast_parser_pars
+            fpp = np.array(list(zip(map(chr, fpp['delims']),
+                                    fpp['starts'],
+                                    fpp['stops'],
+                                    fpp['break_allowed'])),
+                           _parse_times.dt_pars)
+            if cls.fast_parser_pars['has_day_of_year']:
+                fpp['start'][1] = fpp['stop'][1] = -1
+            cls._fast_parser = _parse_times.create_parser(fpp)
 
-    @classproperty(lazy=True)
-    def lib_parse_time(cls):
-        """Class property for ctypes library for fast C parsing of string times."""
-        import numpy.ctypeslib as npct
-        from ctypes import c_int
-
-        # Input types in the parse_times.c code
-        array_1d_char = npct.ndpointer(dtype=np.uint8, ndim=1, flags='C_CONTIGUOUS')
-        array_1d_int = npct.ndpointer(dtype=np.intc, ndim=1, flags='C_CONTIGUOUS')
-
-        array_1d_time_struct = npct.ndpointer(dtype=cls.time_struct_dtype,
-                                              ndim=1, flags='C_CONTIGUOUS')
-
-        # load the library, using numpy mechanisms
-        libpt = npct.load_library("_parse_times", Path(__file__).parent)
-
-        # Set up the return types and argument types for parse_ymdhms_times()
-        # int parse_ymdhms_times(char *times, int n_times, int max_str_len,
-        #                    char *delims, int *starts, int *stops, int *break_allowed,
-        #                    int *years, int *months, int *days, int *hours,
-        #                    int *minutes, double *seconds)
-        libpt.parse_ymdhms_times.restype = c_int
-        libpt.parse_ymdhms_times.argtypes = [array_1d_char, c_int, c_int, c_int,
-                                             array_1d_char, array_1d_int, array_1d_int,
-                                             array_1d_int, array_1d_time_struct]
-
-        return libpt
+        super().__init_subclass__(**kwargs)
 
     def _check_val_type(self, val1, val2):
         if val1.dtype.kind not in ('S', 'U') and val1.size:
@@ -1352,7 +1319,7 @@ class TimeString(TimeUnique):
         # if the fast parser is entirely disabled. Note that `use_fast_parser`
         # is ignored for format classes that don't have a fast parser.
         if (self.in_subfmt != '*'
-                or 'fast_parser_pars' not in self.__class__.__dict__
+                or '_fast_parser' not in self.__class__.__dict__
                 or conf.use_fast_parser == 'False'):
             jd1, jd2 = self.get_jds_python(val1, val2)
         else:
@@ -1393,61 +1360,34 @@ class TimeString(TimeUnique):
 
     def get_jds_fast(self, val1, val2):
         """Use fast C parser to parse time strings in val1 and get jd1, jd2"""
-        # Handle bytes or str input and flatten down to a single array of uint8.
+        # Handle bytes or str input and convert to uint8.  We need to the
+        # dtype _parse_times.dt_u1 instead of uint8, since otherwise it is
+        # not possible to create a gufunc with structured dtype output.
+        # See note about ufunc type resolver in pyerfa/erfa/ufunc.c.templ.
         if val1.dtype.kind == 'U':
-            val1_str_len = val1.dtype.itemsize // 4
-            # Check that this is pure ASCII.
-            if np.any(val1.view((np.uint32, val1_str_len)) > 127):
+            # Note: val1.astype('S') is *very* slow, so we check ourselves
+            # that the input is pure ASCII.
+            val1_uint32 = val1.view((np.uint32, val1.dtype.itemsize // 4))
+            if np.any(val1_uint32 > 127):
                 raise ValueError('input is not pure ASCII')
 
-            # It might be possible to avoid having ravel() make a copy with
+            # It might be possible to avoid making a copy via astype with
             # cleverness in parse_times.c but leave that for another day.
-            if sys.byteorder == 'big':  # pragma: no cover
-                chars = val1.view((np.uint8, 4*val1_str_len))[..., 3::4].ravel()
-            else:
-                chars = val1.view((np.uint8, 4*val1_str_len))[..., ::4].ravel()
+            chars = val1_uint32.astype(_parse_times.dt_u1)
 
         else:
-            val1_str_len = val1.dtype.itemsize
-            chars = val1.view((np.uint8, val1_str_len)).ravel()
+            chars = val1.view((_parse_times.dt_u1, val1.dtype.itemsize))
 
-        # Pre-allocate output components
-        n_times = val1.size
-        time_struct = np.empty(n_times, dtype=self.time_struct_dtype)
-
-        # Set up parser parameters as numpy arrays for passing to C parser
-        pars = self.fast_parser_pars
-        delims = np.array(pars['delims'], dtype=np.uint8)
-        starts = np.array(pars['starts'], dtype=np.intc)
-        stops = np.array(pars['stops'], dtype=np.intc)
-        break_allowed = np.array(pars['break_allowed'], dtype=np.intc)
-
-        # Call C parser
-        status = self.lib_parse_time.parse_ymdhms_times(
-            chars, n_times, val1_str_len, pars['has_day_of_year'],
-            delims, starts, stops, break_allowed, time_struct)
-
-        if status == 0:
-            # All went well, finish the job
-            jd1, jd2 = erfa.dtf2d(self.scale.upper().encode('ascii'),
-                                  time_struct['year'],
-                                  time_struct['month'],
-                                  time_struct['day'],
-                                  time_struct['hour'],
-                                  time_struct['minute'],
-                                  time_struct['second_int'] + time_struct['second_frac'])
-            jd1.shape = val1.shape
-            jd2.shape = val1.shape
-            jd1, jd2 = day_frac(jd1, jd2)
-        else:
-            msgs = {1: 'time string ends at beginning of component where break is not allowed',
-                    2: 'time string ends in middle of component',
-                    3: 'required delimiter character not found',
-                    4: 'non-digit found where digit (0-9) required',
-                    5: 'bad day of year (1 <= doy <= 365 or 366 for leap year'}
-            raise ValueError(f'fast C time string parser failed: {msgs[status]}')
-
-        return jd1, jd2
+        # Call the fast parsing ufunc.
+        time_struct = self._fast_parser(chars)
+        jd1, jd2 = erfa.dtf2d(self.scale.upper().encode('ascii'),
+                              time_struct['year'],
+                              time_struct['month'],
+                              time_struct['day'],
+                              time_struct['hour'],
+                              time_struct['minute'],
+                              time_struct['second'])
+        return day_frac(jd1, jd2)
 
     def str_kwargs(self):
         """
@@ -1461,11 +1401,8 @@ class TimeString(TimeUnique):
         # Get the str_fmt element of the first allowed output subformat
         _, _, str_fmt = self._select_subfmts(self.out_subfmt)[0]
 
-        if '{yday:' in str_fmt:
-            has_yday = True
-        else:
-            has_yday = False
-            yday = None
+        yday = None
+        has_yday = '{yday:' in str_fmt
 
         ihrs = ihmsfs['h']
         imins = ihmsfs['m']
@@ -1585,7 +1522,7 @@ class TimeISOT(TimeISO):
                 '%Y-%m-%d',
                 '{year:d}-{mon:02d}-{day:02d}'))
 
-    # See TimeISO for expanation
+    # See TimeISO for explanation
     fast_parser_pars = dict(
         delims=(0, ord('-'), ord('-'), ord('T'), ord(':'), ord(':'), ord('.')),
         starts=(0, 4, 7, 10, 13, 16, 19),
@@ -1844,7 +1781,7 @@ class TimeEpochDateString(TimeString):
                 if epoch_type.upper() != epoch_prefix:
                     raise ValueError
             except (IndexError, ValueError, UnicodeEncodeError):
-                raise ValueError(f'Time {time_str} does not match {self.name} format')
+                raise ValueError(f'Time {val} does not match {self.name} format')
             else:
                 years[...] = year
 
@@ -1879,13 +1816,11 @@ class TimeJulianEpochString(TimeEpochDateString):
     epoch_prefix = 'J'
 
 
-class TimeDeltaFormatMeta(TimeFormatMeta):
-    _registry = TIME_DELTA_FORMATS
-
-
-class TimeDeltaFormat(TimeFormat, metaclass=TimeDeltaFormatMeta):
+class TimeDeltaFormat(TimeFormat):
     """Base class for time delta representations"""
 
+    _registry = TIME_DELTA_FORMATS
+
     def _check_scale(self, scale):
         """
         Check that the scale is in the allowed list of scales, or is `None`
