@@ -33,22 +33,22 @@ class BoxLeastSquares(BasePeriodogram):
 
     Parameters
     ----------
-    t : array_like, `~astropy.units.Quantity`, `~astropy.time.Time`, or `~astropy.time.TimeDelta`
+    t : array-like, `~astropy.units.Quantity`, `~astropy.time.Time`, or `~astropy.time.TimeDelta`
         Sequence of observation times.
-    y : array_like or `~astropy.units.Quantity`
+    y : array-like or `~astropy.units.Quantity`
         Sequence of observations associated with times ``t``.
-    dy : float, array_like, or `~astropy.units.Quantity`, optional
+    dy : float, array-like, or `~astropy.units.Quantity`, optional
         Error or sequence of observational errors associated with times ``t``.
 
     Examples
     --------
     Generate noisy data with a transit:
 
-    >>> rand = np.random.RandomState(42)
+    >>> rand = np.random.default_rng(42)
     >>> t = rand.uniform(0, 10, 500)
     >>> y = np.ones_like(t)
     >>> y[np.abs((t + 1.0)%2.0-1)<0.08] = 1.0 - 0.1
-    >>> y += 0.01 * rand.randn(len(t))
+    >>> y += 0.01 * rand.standard_normal(len(t))
 
     Compute the transit periodogram on a heuristically determined period grid
     and find the period with maximum power:
@@ -56,14 +56,14 @@ class BoxLeastSquares(BasePeriodogram):
     >>> model = BoxLeastSquares(t, y)
     >>> results = model.autopower(0.16)
     >>> results.period[np.argmax(results.power)]  # doctest: +FLOAT_CMP
-    1.9923406038842544
+    2.000412388152837
 
     Compute the periodogram on a user-specified period grid:
 
     >>> periods = np.linspace(1.9, 2.1, 5)
     >>> results = model.power(periods, 0.16)
     >>> results.power  # doctest: +FLOAT_CMP
-    array([0.01421067, 0.02842475, 0.10867671, 0.05117755, 0.01783253])
+    array([0.01723948, 0.0643028 , 0.1338783 , 0.09428816, 0.03577543])
 
     If the inputs are AstroPy Quantities with units, the units will be
     validated and the outputs will also be Quantities with appropriate units:
@@ -123,9 +123,9 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        duration : float, array_like, or `~astropy.units.Quantity`
+        duration : float, array-like, or `~astropy.units.Quantity` ['time']
             The set of durations that will be considered.
-        minimum_period, maximum_period : float or `~astropy.units.Quantity`, optional
+        minimum_period, maximum_period : float or `~astropy.units.Quantity` ['time'], optional
             The minimum/maximum periods to search. If not provided, these will
             be computed as described in the notes below.
         minimum_n_transits : int, optional
@@ -141,7 +141,7 @@ class BoxLeastSquares(BasePeriodogram):
 
         Returns
         -------
-        period : array_like or `~astropy.units.Quantity`
+        period : array-like or `~astropy.units.Quantity` ['time']
             The set of periods computed using these heuristics with the same
             units as ``t``.
 
@@ -237,9 +237,9 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        period : array_like or `~astropy.units.Quantity`
+        period : array-like or `~astropy.units.Quantity` ['time']
             The periods where the power should be computed
-        duration : float, array_like, or `~astropy.units.Quantity`
+        duration : float, array-like, or `~astropy.units.Quantity` ['time']
             The set of durations to test
         objective : {'likelihood', 'snr'}, optional
             The scalar that should be optimized to find the best fit phase,
@@ -277,8 +277,7 @@ class BoxLeastSquares(BasePeriodogram):
         try:
             oversample = int(oversample)
         except TypeError:
-            raise ValueError("oversample must be an int, got {}"
-                             .format(oversample))
+            raise ValueError(f"oversample must be an int, got {oversample}")
         if oversample < 1:
             raise ValueError("oversample must be greater than or equal to 1")
 
@@ -378,18 +377,18 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        t_model : array_like, `~astropy.units.Quantity`, or `~astropy.time.Time`
+        t_model : array-like, `~astropy.units.Quantity`, or `~astropy.time.Time`
             Times at which to compute the model.
-        period : float or `~astropy.units.Quantity`
+        period : float or `~astropy.units.Quantity` ['time']
             The period of the transits.
-        duration : float or `~astropy.units.Quantity`
+        duration : float or `~astropy.units.Quantity` ['time']
             The duration of the transit.
         transit_time : float or `~astropy.units.Quantity` or `~astropy.time.Time`
             The mid-transit time of a reference transit.
 
         Returns
         -------
-        y_model : array_like or `~astropy.units.Quantity`
+        y_model : array-like or `~astropy.units.Quantity`
             The model evaluated at the times ``t_model`` with units of ``y``.
 
         """
@@ -432,9 +431,9 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        period : float or `~astropy.units.Quantity`
+        period : float or `~astropy.units.Quantity` ['time']
             The period of the transits.
-        duration : float or `~astropy.units.Quantity`
+        duration : float or `~astropy.units.Quantity` ['time']
             The duration of the transit.
         transit_time : float or `~astropy.units.Quantity` or `~astropy.time.Time`
             The mid-transit time of a reference transit.
@@ -575,18 +574,18 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        t_model : array_like or `~astropy.units.Quantity`
+        t_model : array-like or `~astropy.units.Quantity` ['time']
             Times where the mask should be evaluated.
-        period : float or `~astropy.units.Quantity`
+        period : float or `~astropy.units.Quantity` ['time']
             The period of the transits.
-        duration : float or `~astropy.units.Quantity`
+        duration : float or `~astropy.units.Quantity` ['time']
             The duration of the transit.
         transit_time : float or `~astropy.units.Quantity` or `~astropy.time.Time`
             The mid-transit time of a reference transit.
 
         Returns
         -------
-        transit_mask : array_like
+        transit_mask : array-like
             A boolean array where ``True`` indicates and in transit point and
             ``False`` indicates and out-of-transit point.
 
@@ -608,16 +607,16 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        t : array_like, `~astropy.units.Quantity`, `~astropy.time.Time`, or `~astropy.time.TimeDelta`
+        t : array-like, `~astropy.units.Quantity`, `~astropy.time.Time`, or `~astropy.time.TimeDelta`
             Sequence of observation times.
-        y : array_like or `~astropy.units.Quantity`
+        y : array-like or `~astropy.units.Quantity`
             Sequence of observations associated with times t.
-        dy : float, array_like, or `~astropy.units.Quantity`
+        dy : float, array-like, or `~astropy.units.Quantity`
             Error or sequence of observational errors associated with times t.
 
         Returns
         -------
-        t, y, dy : array_like, `~astropy.units.Quantity`, or `~astropy.time.Time`
+        t, y, dy : array-like, `~astropy.units.Quantity`, or `~astropy.time.Time`
             The inputs with consistent shapes and units.
 
         Raises
@@ -647,12 +646,12 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        duration : float, array_like, or `~astropy.units.Quantity`
+        duration : float, array-like, or `~astropy.units.Quantity`
             The set of durations that will be considered.
 
         Returns
         -------
-        duration : array_like or `~astropy.units.Quantity`
+        duration : array-like or `~astropy.units.Quantity`
             The input reformatted with the correct shape and units.
 
         Raises
@@ -671,14 +670,14 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        period : float, array_like, or `~astropy.units.Quantity`
+        period : float, array-like, or `~astropy.units.Quantity` ['time']
             The set of test periods.
-        duration : float, array_like, or `~astropy.units.Quantity`
+        duration : float, array-like, or `~astropy.units.Quantity` ['time']
             The set of durations that will be considered.
 
         Returns
         -------
-        period, duration : array_like or `~astropy.units.Quantity`
+        period, duration : array-like or `~astropy.units.Quantity` ['time']
             The inputs reformatted with the correct shapes and units.
 
         Raises
@@ -709,7 +708,7 @@ class BoxLeastSquares(BasePeriodogram):
             The minimum time in the time series (a reference time).
         objective : str
             The name of the objective used in the optimization.
-        period : array_like or `~astropy.units.Quantity`
+        period : array-like or `~astropy.units.Quantity` ['time']
             The set of trial periods.
         results : tuple
             The output of one of the periodogram implementations.
@@ -766,9 +765,9 @@ class BoxLeastSquaresResults(dict):
     objective : str
         The scalar used to optimize to find the best fit phase, duration, and
         depth. See :func:`BoxLeastSquares.power` for more information.
-    period : array_like or `~astropy.units.Quantity`
+    period : array-like or `~astropy.units.Quantity` ['time']
         The set of test periods.
-    power : array_like or `~astropy.units.Quantity`
+    power : array-like or `~astropy.units.Quantity`
         The periodogram evaluated at the periods in ``period``. If
         ``objective`` is:
 
@@ -778,19 +777,19 @@ class BoxLeastSquaresResults(dict):
           which the depth is measured maximized over phase, depth, and
           duration.
 
-    depth : array_like or `~astropy.units.Quantity`
+    depth : array-like or `~astropy.units.Quantity`
         The estimated depth of the maximum power model at each period.
-    depth_err : array_like or `~astropy.units.Quantity`
+    depth_err : array-like or `~astropy.units.Quantity`
         The 1-sigma uncertainty on ``depth``.
-    duration : array_like or `~astropy.units.Quantity`
+    duration : array-like or `~astropy.units.Quantity` ['time']
         The maximum power duration at each period.
-    transit_time : array_like, `~astropy.units.Quantity`, or `~astropy.time.Time`
+    transit_time : array-like, `~astropy.units.Quantity`, or `~astropy.time.Time`
         The maximum power phase of the transit in units of time. This
         indicates the mid-transit time and it will always be in the range
         (0, period).
-    depth_snr : array_like or `~astropy.units.Quantity`
+    depth_snr : array-like or `~astropy.units.Quantity`
         The signal-to-noise with which the depth is measured at maximum power.
-    log_likelihood : array_like or `~astropy.units.Quantity`
+    log_likelihood : array-like or `~astropy.units.Quantity`
         The log likelihood of the maximum power model.
 
     """
