@@ -36,11 +36,11 @@ class LombScargle(BasePeriodogram):
 
     Parameters
     ----------
-    t : array_like or Quantity
+    t : array-like or `~astropy.units.Quantity` ['time']
         sequence of observation times
-    y : array_like or Quantity
+    y : array-like or `~astropy.units.Quantity`
         sequence of observations associated with times t
-    dy : float, array_like, or Quantity, optional
+    dy : float, array-like, or `~astropy.units.Quantity`, optional
         error or sequence of observational errors associated with times t
     fit_mean : bool, optional
         if True, include a constant offset as part of the model at each
@@ -58,22 +58,22 @@ class LombScargle(BasePeriodogram):
     --------
     Generate noisy periodic data:
 
-    >>> rand = np.random.RandomState(42)
-    >>> t = 100 * rand.rand(100)
-    >>> y = np.sin(2 * np.pi * t) + rand.randn(100)
+    >>> rand = np.random.default_rng(42)
+    >>> t = 100 * rand.random(100)
+    >>> y = np.sin(2 * np.pi * t) + rand.standard_normal(100)
 
     Compute the Lomb-Scargle periodogram on an automatically-determined
     frequency grid & find the frequency of max power:
 
     >>> frequency, power = LombScargle(t, y).autopower()
     >>> frequency[np.argmax(power)]  # doctest: +FLOAT_CMP
-    1.0016662310392956
+    1.0007641728995051
 
     Compute the Lomb-Scargle periodogram at a user-specified frequency grid:
 
     >>> freq = np.arange(0.8, 1.3, 0.1)
     >>> LombScargle(t, y).power(freq)  # doctest: +FLOAT_CMP
-    array([0.0204304 , 0.01393845, 0.35552682, 0.01358029, 0.03083737])
+    array([0.0792948 , 0.01778874, 0.25328167, 0.01064157, 0.01471387])
 
     If the inputs are astropy Quantities with units, the units will be
     validated and the outputs will also be Quantities with appropriate units:
@@ -223,7 +223,7 @@ class LombScargle(BasePeriodogram):
 
         Returns
         -------
-        frequency : ndarray or Quantity
+        frequency : ndarray or `~astropy.units.Quantity` ['frequency']
             The heuristically-determined optimal frequency bin
         """
         baseline = self._trel.max() - self._trel.min()
@@ -280,18 +280,18 @@ class LombScargle(BasePeriodogram):
         nyquist_factor : float, optional
             The multiple of the average nyquist frequency used to choose the
             maximum frequency if maximum_frequency is not provided.
-        minimum_frequency : float or `~astropy.units.Quantity`, optional
+        minimum_frequency : float or `~astropy.units.Quantity` ['frequency'], optional
             If specified, then use this minimum frequency rather than one
             chosen based on the size of the baseline. Should be `~astropy.units.Quantity`
             if inputs to LombScargle are `~astropy.units.Quantity`.
-        maximum_frequency : float or `~astropy.units.Quantity`, optional
+        maximum_frequency : float or `~astropy.units.Quantity` ['frequency'], optional
             If specified, then use this maximum frequency rather than one
             chosen based on the average nyquist frequency. Should be `~astropy.units.Quantity`
             if inputs to LombScargle are `~astropy.units.Quantity`.
 
         Returns
         -------
-        frequency, power : ndarrays
+        frequency, power : ndarray
             The frequency and Lomb-Scargle power
         """
         frequency = self.autofrequency(samples_per_peak=samples_per_peak,
@@ -310,7 +310,7 @@ class LombScargle(BasePeriodogram):
 
         Parameters
         ----------
-        frequency : array_like or Quantity
+        frequency : array-like or `~astropy.units.Quantity` ['frequency']
             frequencies (not angular frequencies) at which to evaluate the
             periodogram. Note that in order to use method='fast', frequencies
             must be regularly-spaced.
@@ -399,15 +399,16 @@ class LombScargle(BasePeriodogram):
 
         Parameters
         ----------
-        t : array_like or Quantity, length n_samples
-            times at which to compute the model
+        t : array-like or `~astropy.units.Quantity` ['time']
+            Times (length ``n_samples``) at which to compute the model.
         frequency : float
             the frequency for the model
 
         Returns
         -------
-        y : np.ndarray, length n_samples
+        y : np.ndarray
             The model fit corresponding to the input times
+            (will have length ``n_samples``).
 
         See Also
         --------
@@ -502,14 +503,16 @@ class LombScargle(BasePeriodogram):
         ----------
         frequency : float
             the frequency for the model
-        t : array_like or `~astropy.units.Quantity` or `~astropy.time.Time`, length n_samples
-            times at which to compute the model (optional). If not specified,
-            then the times and uncertainties of the input data are used
+        t : array-like, `~astropy.units.Quantity`, or `~astropy.time.Time` (optional)
+            Times (length ``n_samples``) at which to compute the model.
+            If not specified, then the times and uncertainties of the input
+            data are used.
 
         Returns
         -------
-        X : np.ndarray (len(t), n_parameters)
+        X : array
             The design matrix for the model at the given frequency.
+            This should have a shape of (``len(t)``, ``n_parameters``).
 
         See Also
         --------
@@ -536,7 +539,7 @@ class LombScargle(BasePeriodogram):
 
         Parameters
         ----------
-        power : array_like
+        power : array-like
             The periodogram power at which to compute the distribution.
         cumulative : bool, optional
             If True, then return the cumulative distribution.
@@ -569,7 +572,7 @@ class LombScargle(BasePeriodogram):
 
         Parameters
         ----------
-        power : array_like
+        power : array-like
             The periodogram value.
         method : {'baluev', 'davies', 'naive', 'bootstrap'}, optional
             The approximation method to use.
@@ -640,7 +643,7 @@ class LombScargle(BasePeriodogram):
 
         Parameters
         ----------
-        false_alarm_probability : array_like
+        false_alarm_probability : array-like
             The false alarm probability (0 < fap < 1).
         maximum_frequency : float
             The maximum frequency of the periodogram.
