@@ -18,12 +18,12 @@ NORMALIZATIONS = ['standard', 'psd', 'log', 'model']
 @pytest.fixture
 def data(N=100, period=1, theta=[10, 2, 3], dy=1, rseed=0):
     """Generate some data for testing"""
-    rng = np.random.RandomState(rseed)
-    t = 20 * period * rng.rand(N)
+    rng = np.random.default_rng(rseed)
+    t = 20 * period * rng.random(N)
     omega = 2 * np.pi / period
     y = theta[0] + theta[1] * np.sin(omega * t) + theta[2] * np.cos(omega * t)
-    dy = dy * (0.5 + rng.rand(N))
-    y += dy * rng.randn(N)
+    dy = dy * (0.5 + rng.random(N))
+    y += dy * rng.standard_normal(N)
 
     return t, y, dy
 
@@ -300,9 +300,9 @@ def test_unit_conversions(data, with_error):
 @pytest.mark.parametrize('with_units', [True, False])
 @pytest.mark.parametrize('freq', [1.0, 2.0])
 def test_model(fit_mean, with_units, freq):
-    rand = np.random.RandomState(0)
-    t = 10 * rand.rand(40)
-    params = 10 * rand.rand(3)
+    rand = np.random.default_rng(0)
+    t = 10 * rand.random(40)
+    params = 10 * rand.random(3)
 
     y = np.zeros_like(t)
     if fit_mean:
