@@ -36,6 +36,7 @@ from .equivalencies import *
 from .function.core import *
 from .function.logarithmic import *
 
+from .structured import *
 from .decorators import *
 
 del bases
@@ -44,3 +45,16 @@ del bases
 # Imperial units.
 
 set_enabled_units([si, cgs, astrophys, function_units, misc, photometric])
+
+
+# -------------------------------------------------------------------------
+
+def __getattr__(attr):
+    if attr == "littleh":
+        from astropy.units.astrophys import littleh
+        return littleh
+    elif attr == "with_H0":
+        from astropy.units.equivalencies import with_H0
+        return with_H0
+
+    raise AttributeError(f"module {__name__!r} has no attribute {attr!r}.")
