@@ -186,12 +186,28 @@ class VOUnit(generic.Generic):
                     return core.PrefixUnit(
                         [prefix + x for x in base_unit.names],
                         core.CompositeUnit(factor, [base_unit], [1],
-                                        _error_check=False),
+                                           _error_check=False),
                         format={'vounit': prefix + base_unit.names[-1]},
                         namespace=cls._custom_units)
 
         return def_base(unit)
 
+    @classmethod
+    def _format_unit_list(cls, units):
+        out = []
+        units.sort(key=lambda x: cls._get_unit_name(x[0]).lower())
+
+        for base, power in units:
+            if power == 1:
+                out.append(cls._get_unit_name(base))
+            else:
+                power = utils.format_power(power)
+                if '/' in power or '.' in power:
+                    out.append(f'{cls._get_unit_name(base)}({power})')
+                else:
+                    out.append(f'{cls._get_unit_name(base)}**{power}')
+        return '.'.join(out)
+
     @classmethod
     def to_string(cls, unit):
         from astropy.units import core
@@ -208,17 +224,7 @@ class VOUnit(generic.Generic):
                     .format(unit.scale))
             s = ''
             if unit.scale != 1:
-                m, ex = utils.split_mantissa_exponent(unit.scale)
-                parts = []
-                if m:
-                    parts.append(m)
-                if ex:
-                    fex = '10'
-                    if not ex.startswith('-'):
-                        fex += '+'
-                    fex += ex
-                    parts.append(fex)
-                s += ' '.join(parts)
+                s += f'{unit.scale:.8g}'
 
             pairs = list(zip(unit.bases, unit.powers))
             pairs.sort(key=operator.itemgetter(1), reverse=True)
