@@ -44,7 +44,7 @@ _units_and_physical_types = [
     (si.m ** 3 / si.mol, "molar volume"),
     (si.kg * si.m / si.s, {"momentum", "impulse"}),
     (si.kg * si.m ** 2 / si.s, {"angular momentum", "action"}),
-    (si.rad / si.s, "angular speed"),
+    (si.rad / si.s, {"angular speed", "angular velocity", "angular frequency"}),
     (si.rad / si.s ** 2, "angular acceleration"),
     (si.rad / si.m, "plate scale"),
     (si.g / (si.m * si.s), "dynamic viscosity"),
@@ -130,6 +130,8 @@ _units_and_physical_types = [
 _physical_unit_mapping = {}
 _unit_physical_mapping = {}
 _name_physical_mapping = {}
+# mapping from attribute-accessible name (no spaces, etc.) to the actual name.
+_attrname_physical_mapping = {}
 
 
 def _physical_type_from_str(name):
@@ -140,7 +142,9 @@ def _physical_type_from_str(name):
     if name == "unknown":
         raise ValueError("cannot uniquely identify an 'unknown' physical type.")
 
-    if name in _name_physical_mapping:
+    elif name in _attrname_physical_mapping:
+        return _attrname_physical_mapping[name]  # convert attribute-accessible
+    elif name in _name_physical_mapping:
         return _name_physical_mapping[name]
     else:
         raise ValueError(f"{name!r} is not a known physical type.")
@@ -477,6 +481,9 @@ def def_physical_type(unit, name):
 
     for ptype_name in physical_type_names:
         _name_physical_mapping[ptype_name] = physical_type
+        # attribute-accessible name
+        attr_name = ptype_name.replace(' ', '_').replace('(', '').replace(')', '')
+        _attrname_physical_mapping[attr_name] = physical_type
 
 
 def get_physical_type(obj):
@@ -543,10 +550,48 @@ def get_physical_type(obj):
         return PhysicalType(unit, "unknown")
 
 
+# ------------------------------------------------------------------------------
+# Script section creating the physical types and the documentation
+
+# define the physical types
 for unit, physical_type in _units_and_physical_types:
     def_physical_type(unit, physical_type)
 
 
+# For getting the physical types.
+def __getattr__(name):
+    """Checks for physical types using lazy import.
+
+    This also allows user-defined physical types to be accessible from the
+    :mod:`astropy.units.physical` module.
+    See `PEP 562 <https://www.python.org/dev/peps/pep-0562/>`_
+
+    Parameters
+    ----------
+    name : str
+        The name of the attribute in this module. If it is already defined,
+        then this function is not called.
+
+    Returns
+    -------
+    ptype : `~astropy.units.physical.PhysicalType`
+
+    Raises
+    ------
+    AttributeError
+        If the ``name`` does not correspond to a physical type
+    """
+    if name in _attrname_physical_mapping:
+        return _attrname_physical_mapping[name]
+
+    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
+
+
+def __dir__():
+    """Return contents directory (__all__ + all physical type names)."""
+    return list(set(__all__) | set(_attrname_physical_mapping.keys()))
+
+
 # This generates a docstring addition for this module that describes all of the
 # standard physical types defined here.
 if __doc__ is not None:
