@@ -402,8 +402,7 @@ class Quantity(np.ndarray):
         # Quantity does not (yet) properly extend the NumPy generics types,
         # introduced in numpy v1.22+, instead just including the unit info as
         # metadata using Annotated.
-        if not NUMPY_LT_1_22:
-            cls = super().__class_getitem__((cls, *shape_dtype))
+        # TODO: ensure we do interact with NDArray.__class_getitem__.
         return Annotated.__class_getitem__((cls, unit))
 
     def __new__(cls, value, unit=None, dtype=None, copy=True, order=None,
@@ -1382,13 +1381,12 @@ class Quantity(np.ndarray):
             formatter = {'float_kind': float_formatter,
                          'complex_kind': complex_formatter}
             if conf.latex_array_threshold > -1:
-                np.set_printoptions(threshold=conf.latex_array_threshold,
-                                    formatter=formatter)
+                np.set_printoptions(threshold=conf.latex_array_threshold)
 
             # the view is needed for the scalar case - value might be float
             latex_value = np.array2string(
                 self.view(np.ndarray),
-                max_line_width=np.inf, separator=',~')
+                formatter=formatter, max_line_width=np.inf, separator=',~')
 
             latex_value = latex_value.replace('...', r'\dots')
         finally:
