@@ -42,7 +42,7 @@ import numpy as np
 
 from astropy.units.core import (
     UnitsError, UnitTypeError, dimensionless_unscaled)
-from astropy.utils.compat import NUMPY_LT_1_20
+from astropy.utils.compat import NUMPY_LT_1_20, NUMPY_LT_1_23
 from astropy.utils import isiterable
 
 # In 1.17, overrides are enabled by default, but it is still possible to
@@ -112,8 +112,6 @@ UNSUPPORTED_FUNCTIONS |= {np.linalg.slogdet}
 # variable so that we can check consistency in the test routine -
 # test_quantity_non_ufuncs.py)
 IGNORED_FUNCTIONS = {
-    # Deprecated
-    np.asscalar, np.alen,
     # I/O - useless for Quantity, since no way to store the unit.
     np.save, np.savez, np.savetxt, np.savez_compressed,
     # Polynomials
@@ -123,7 +121,11 @@ if NUMPY_LT_1_20:
     # financial
     IGNORED_FUNCTIONS |= {np.fv, np.ipmt, np.irr, np.mirr, np.nper,
                           np.npv, np.pmt, np.ppmt, np.pv, np.rate}
-
+if NUMPY_LT_1_23:
+    IGNORED_FUNCTIONS |= {
+        # Deprecated, removed in numpy 1.23
+        np.asscalar, np.alen,
+    }
 UNSUPPORTED_FUNCTIONS |= IGNORED_FUNCTIONS
 
 
