@@ -4,7 +4,8 @@
 """
 Regression tests for the units.format package
 """
-
+import warnings
+from contextlib import nullcontext
 from fractions import Fraction
 
 import pytest
@@ -16,7 +17,6 @@ from astropy.constants import si
 from astropy.units import core, dex, UnitsWarning
 from astropy.units import format as u_format
 from astropy.units.utils import is_effectively_unity
-from astropy.utils.compat.context import nullcontext
 
 
 @pytest.mark.parametrize('strings, unit', [
@@ -181,18 +181,19 @@ def test_ogip_grammar_fail(string):
 class RoundtripBase:
     deprecated_units = set()
 
-    def check_roundtrip(self, unit):
-        with pytest.warns(None) as w:
-            s = unit.to_string(self.format_)
-            a = core.Unit(s, format=self.format_)
+    def check_roundtrip(self, unit, output_format=None):
+        if output_format is None:
+            output_format = self.format_
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore')  # Same warning shows up multiple times
+            s = unit.to_string(output_format)
 
         if s in self.deprecated_units:
-            assert len(w) == 3  # Same warning shows up multiple times
-            for ww in w:
-                assert issubclass(ww.category, UnitsWarning)
-                assert 'deprecated' in str(ww.message)
+            with pytest.warns(UnitsWarning, match='deprecated') as w:
+                a = core.Unit(s, format=self.format_)
+            assert len(w) == 1
         else:
-            assert len(w) == 0
+            a = core.Unit(s, format=self.format_)  # No warning
 
         assert_allclose(a.decompose().scale, unit.decompose().scale, rtol=1e-9)
 
@@ -213,6 +214,7 @@ class TestRoundtripGeneric(RoundtripBase):
             not isinstance(unit, core.PrefixUnit))])
     def test_roundtrip(self, unit):
         self.check_roundtrip(unit)
+        self.check_roundtrip(unit, output_format='unicode')
         self.check_roundtrip_decompose(unit)
 
 
@@ -286,7 +288,7 @@ class TestRoundtripOGIP(RoundtripBase):
         if str(unit) in ('mag', 'byte', 'Crab'):
             # Skip mag and byte, which decompose into dex and bit, resp.,
             # both of which are unknown to OGIP, as well as Crab, which does
-            # not decompose, and thus gives a depecated unit warning.
+            # not decompose, and thus gives a deprecated unit warning.
             return
 
         power_of_ten = np.log10(unit.decompose().scale)
@@ -379,6 +381,16 @@ def test_flexible_float():
     assert u.min._represents.to_string('latex') == r'$\mathrm{60\,s}$'
 
 
+def test_fits_to_string_function_error():
+    """Test function raises TypeError on bad input.
+
+    This instead of returning None, see gh-11825.
+    """
+
+    with pytest.raises(TypeError, match='unit argument must be'):
+        u_format.Fits.to_string(None)
+
+
 def test_fraction_repr():
     area = u.cm ** 2.0
     assert '.' not in area.to_string('latex')
@@ -463,9 +475,9 @@ def test_fits_function(string):
 @pytest.mark.parametrize('string', ['mag(ct/s)', 'dB(mW)', 'dex(cm s**-2)'])
 def test_vounit_function(string):
     # Function units cannot be written, so ensure they're not parsed either.
-    with pytest.raises(ValueError):
-        with pytest.warns(None):  # ct, dex also raise warnings - irrelevant here.
-            u_format.VOUnit().parse(string)
+    with pytest.raises(ValueError), warnings.catch_warnings():
+        warnings.simplefilter('ignore')    # ct, dex also raise warnings - irrelevant here.
+        u_format.VOUnit().parse(string)
 
 
 def test_vounit_binary_prefix():
@@ -490,20 +502,42 @@ def test_vounit_details():
 
     # The da- prefix is not allowed, and the d- prefix is discouraged
     assert u.dam.to_string('vounit') == '10m'
-    assert u.Unit('dam dag').to_string('vounit') == '100g m'
+    assert u.Unit('dam dag').to_string('vounit') == '100g.m'
+
+    # Parse round-trip
+    with pytest.warns(UnitsWarning, match='deprecated'):
+        flam = u.erg / u.cm / u.cm / u.s / u.AA
+        x = u.format.VOUnit.to_string(flam)
+        assert x == 'Angstrom**-1.cm**-2.erg.s**-1'
+        new_flam = u.format.VOUnit.parse(x)
+        assert new_flam == flam
+
+
+@pytest.mark.parametrize('unit, vounit, number, scale, voscale',
+                         [('nm', 'nm', 0.1, '10^-1', '0.1'),
+                          ('fm', 'fm', 100.0, '10+2', '100'),
+                          ('m^2', 'm**2', 100.0, '100.0', '100'),
+                          ('cm', 'cm', 2.54, '2.54', '2.54'),
+                          ('kg', 'kg', 1.898124597e27, '1.898124597E27', '1.8981246e+27'),
+                          ('m/s', 'm.s**-1', 299792458.0, '299792458', '2.9979246e+08'),
+                          ('cm2', 'cm**2', 1.e-20, '10^(-20)', '1e-20')])
+def test_vounit_scale_factor(unit, vounit, number, scale, voscale):
+    x = u.Unit(f'{scale} {unit}')
+    assert x == number * u.Unit(unit)
+    assert x.to_string(format='vounit') == voscale + vounit
 
 
 def test_vounit_custom():
     x = u.Unit("'foo' m", format='vounit')
     x_vounit = x.to_string('vounit')
-    assert x_vounit == "'foo' m"
+    assert x_vounit == "'foo'.m"
     x_string = x.to_string()
     assert x_string == "foo m"
 
     x = u.Unit("m'foo' m", format='vounit')
     assert x.bases[1]._represents.scale == 0.001
     x_vounit = x.to_string('vounit')
-    assert x_vounit == "m m'foo'"
+    assert x_vounit == "m.m'foo'"
     x_string = x.to_string()
     assert x_string == 'm mfoo'
 
@@ -606,8 +640,17 @@ def test_powers(power, expected):
     ('\N{ANGSTROM SIGN} \N{OHM SIGN}', u.Angstrom * u.Ohm),
     ('\N{LATIN CAPITAL LETTER A WITH RING ABOVE}', u.Angstrom),
     ('\N{LATIN CAPITAL LETTER A}\N{COMBINING RING ABOVE}', u.Angstrom),
+    ('m\N{ANGSTROM SIGN}', u.milliAngstrom),
     ('°C', u.deg_C),
     ('°', u.deg),
+    ('M⊙', u.Msun),  # \N{CIRCLED DOT OPERATOR}
+    ('L☉', u.Lsun),  # \N{SUN}
+    ('M⊕', u.Mearth),  # normal earth symbol = \N{CIRCLED PLUS}
+    ('M♁', u.Mearth),  # be generous with \N{EARTH}
+    ('R♃', u.Rjup),  # \N{JUPITER}
+    ('′', u.arcmin),  # \N{PRIME}
+    ('R∞', u.Ry),
+    ('Mₚ', u.M_p),
 ])
 def test_unicode(string, unit):
     assert u_format.Generic.parse(string) == unit
@@ -620,8 +663,19 @@ def test_unicode(string, unit):
     'm\N{SUPERSCRIPT MINUS}1',
     'm+\N{SUPERSCRIPT ONE}',
     'm\N{MINUS SIGN}\N{SUPERSCRIPT ONE}',
-    'm\N{ANGSTROM SIGN}',
+    'k\N{ANGSTROM SIGN}',
 ])
 def test_unicode_failures(string):
     with pytest.raises(ValueError):
         u.Unit(string)
+
+
+@pytest.mark.parametrize('format_', ('unicode', 'latex', 'latex_inline'))
+def test_parse_error_message_for_output_only_format(format_):
+    with pytest.raises(NotImplementedError, match='not parse'):
+        u.Unit('m', format=format_)
+
+
+def test_unknown_parser():
+    with pytest.raises(ValueError, match=r"Unknown.*unicode'\] for output only"):
+        u.Unit('m', format='foo')
