@@ -989,6 +989,7 @@ class TestQuantityDisplay:
             assert r'\dots' in lsbig
             lsvbig = qvbig._repr_latex_()
             assert r'\dots' in lsvbig
+            assert lsvbig.endswith(',~1 \\times 10^{13}] \\; \\mathrm{m}$')
         finally:
             # prevent side-effects from influencing other tests
             np.set_printoptions(**pops)
@@ -1034,7 +1035,7 @@ def test_arrays():
     assert isinstance(qsecsub25, u.Quantity)
     assert len(qsecsub25) == 3
 
-    # make sure isscalar, len, and indexing behave correcly for non-arrays.
+    # make sure isscalar, len, and indexing behave correctly for non-arrays.
     qsecnotarray = u.Quantity(10., u.second)
     assert qsecnotarray.isscalar
     with pytest.raises(TypeError):
