@@ -3,12 +3,16 @@
 """
 Test Structured units and quantities.
 """
+import copy
+
 import pytest
 import numpy as np
 from numpy.testing import assert_array_equal
 
 from astropy import units as u
 from astropy.units import StructuredUnit, Unit, UnitBase, Quantity
+from astropy.tests.helper import pickle_protocol, check_pickling_recovery
+from astropy.utils.compat import NUMPY_LT_1_21_1
 from astropy.utils.masked import Masked
 
 
@@ -193,6 +197,24 @@ class TestStructuredUnitBasics(StructuredTestBase):
         assert eval(repr(su)) == su
 
 
+class TestStructuredUnitsCopyPickle(StructuredTestBaseWithUnits):
+    def test_copy(self):
+        su_copy = copy.copy(self.pv_t_unit)
+        assert su_copy is not self.pv_t_unit
+        assert su_copy == self.pv_t_unit
+        assert su_copy._units is self.pv_t_unit._units
+
+    def test_deepcopy(self):
+        su_copy = copy.deepcopy(self.pv_t_unit)
+        assert su_copy is not self.pv_t_unit
+        assert su_copy == self.pv_t_unit
+        assert su_copy._units is not self.pv_t_unit._units
+
+    @pytest.mark.skipif(NUMPY_LT_1_21_1, reason="https://stackoverflow.com/q/69571643")
+    def test_pickle(self, pickle_protocol):
+        check_pickling_recovery(self.pv_t_unit, pickle_protocol)
+
+
 class TestStructuredUnitAsMapping(StructuredTestBaseWithUnits):
 
     def test_len(self):
