@@ -3,16 +3,18 @@
 `PEP 562 <https://www.python.org/dev/peps/pep-0562/>`_.
 """
 import importlib
+import warnings
 
 # First, the top-level packages:
 # TODO: This list is a duplicate of the dependencies in setup.cfg "all", but
 # some of the package names are different from the pip-install name (e.g.,
 # beautifulsoup4 -> bs4).
-_optional_deps = ['bleach', 'bottleneck', 'bs4', 'bz2', 'h5py', 'html5lib',
-                  'IPython', 'jplephem', 'lxml', 'matplotlib', 'mpmath',
-                  'pandas', 'PIL', 'pytz', 'scipy', 'skyfield',
-                  'sortedcontainers', 'lzma', 'yaml']
-_deps = {k.upper(): k for k in _optional_deps}
+_optional_deps = ['asdf', 'bleach', 'bottleneck', 'bs4', 'bz2', 'h5py',
+                  'html5lib', 'IPython', 'jplephem', 'lxml', 'matplotlib',
+                  'mpmath', 'pandas', 'PIL', 'pytz', 'scipy', 'skyfield',
+                  'sortedcontainers', 'lzma', 'pyarrow']
+_formerly_optional_deps = ['yaml']  # for backward compatibility
+_deps = {k.upper(): k for k in _optional_deps + _formerly_optional_deps}
 
 # Any subpackages that have different import behavior:
 _deps['PLT'] = 'matplotlib.pyplot'
@@ -24,6 +26,12 @@ def __getattr__(name):
     if name in __all__:
         module_name = name[4:]
 
+        if module_name == "YAML":
+            warnings.warn(
+                "PyYaml is now a strict dependency. HAS_YAML is deprecated as "
+                "of v5.0 and will be removed in a subsequent version.",
+                category=AstropyDeprecationWarning)
+
         try:
             importlib.import_module(_deps[module_name])
         except (ImportError, ModuleNotFoundError):
