@@ -128,9 +128,11 @@ class Masked(NDArrayShapeMethods):
         """Get the masked wrapper for a given data class.
 
         If the data class does not exist yet but is a subclass of any of the
-        registered base data classes, it is automatically generated.
+        registered base data classes, it is automatically generated
+        (except we skip `~numpy.ma.MaskedArray` subclasses, since then the
+        masking mechanisms would interfere).
         """
-        if issubclass(data_cls, Masked):
+        if issubclass(data_cls, (Masked, np.ma.MaskedArray)):
             return data_cls
 
         masked_cls = cls._masked_classes.get(data_cls)
@@ -350,9 +352,12 @@ class MaskedNDArrayInfo(MaskedInfoBase, ParentDtypeInfo):
         return out
 
     def _construct_from_dict(self, map):
-        # 'data' may be a Column or a MaskedColumn.  In the former case,
-        # there will also be a 'mask'.
-        return Masked(map.pop('data').data, mask=map.pop('mask', None))
+        # Override usual handling, since MaskedNDArray takes shape and buffer
+        # as input, which is less useful here.
+        # The map can contain either a MaskedColumn or a Column and a mask.
+        # Extract the mask for the former case.
+        map.setdefault('mask', getattr(map['data'], 'mask', False))
+        return self._parent_cls.from_unmasked(**map)
 
 
 class MaskedArraySubclassInfo(MaskedInfoBase):
@@ -518,6 +523,16 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
         """
         return MaskedIterator(self)
 
+    @property
+    def _baseclass(self):
+        """Work-around for MaskedArray initialization.
+
+        Allows the base class to be inferred correctly when a masked instance
+        is used to initialize (or viewed as) a `~numpy.ma.MaskedArray`.
+
+        """
+        return self._data_cls
+
     def view(self, dtype=None, type=None):
         """New view of the masked array.
 
