@@ -13,7 +13,7 @@ import numpy as np
 
 from astropy.units.quantity_helper.function_helpers import (
     FunctionAssigner)
-from astropy.utils.compat import NUMPY_LT_1_19, NUMPY_LT_1_20
+from astropy.utils.compat import NUMPY_LT_1_19, NUMPY_LT_1_20, NUMPY_LT_1_23
 
 # This module should not really be imported, but we define __all__
 # such that sphinx can typeset the functions with docstrings.
@@ -109,8 +109,6 @@ MASKED_SAFE_FUNCTIONS |= {
 }
 
 IGNORED_FUNCTIONS = {
-    # Deprecated
-    np.asscalar, np.alen,
     # I/O - useless for Masked, since no way to store the mask.
     np.save, np.savez, np.savetxt, np.savez_compressed,
     # Polynomials
@@ -142,6 +140,12 @@ IGNORED_FUNCTIONS |= set(getattr(np, setopsname)
                          for setopsname in np.lib.arraysetops.__all__)
 
 
+if NUMPY_LT_1_23:
+    IGNORED_FUNCTIONS |= {
+        # Deprecated, removed in numpy 1.23
+        np.asscalar, np.alen,
+    }
+
 # Explicitly unsupported functions
 UNSUPPORTED_FUNCTIONS |= {
     np.unravel_index, np.ravel_multi_index, np.ix_,
@@ -611,8 +615,7 @@ def _masked_quantile(a, q, axis=None, out=None, **kwargs):
 
 
 @dispatched_function
-def quantile(a, q, axis=None, out=None, overwrite_input=False,
-             interpolation='linear', keepdims=False):
+def quantile(a, q, axis=None, out=None, **kwargs):
     from astropy.utils.masked import Masked
     if isinstance(q, Masked) or out is not None and not isinstance(out, Masked):
         raise NotImplementedError
@@ -622,9 +625,9 @@ def quantile(a, q, axis=None, out=None, overwrite_input=False,
     if not np.lib.function_base._quantile_is_valid(q):
         raise ValueError("Quantiles must be in the range [0, 1]")
 
+    keepdims = kwargs.pop('keepdims', False)
     r, k = np.lib.function_base._ureduce(
-        a, func=_masked_quantile, q=q, axis=axis, out=out,
-        interpolation=interpolation, overwrite_input=overwrite_input)
+        a, func=_masked_quantile, q=q, axis=axis, out=out, **kwargs)
     return (r.reshape(k) if keepdims else r) if out is None else out
 
 
