@@ -9,7 +9,7 @@ from astropy import units as u
 from astropy.table import QTable, hstack, vstack, join
 
 from astropy.utils.masked import Masked
-from astropy.utils.compat.optional_deps import HAS_YAML, HAS_H5PY
+from astropy.utils.compat.optional_deps import HAS_H5PY
 
 from .test_masked import assert_masked_equal
 
@@ -66,7 +66,6 @@ class TestMaskedArrayTable(MaskedArrayTableSetup):
         assert 'serialize_method' in t3['ma'].info.attr_names
         assert t3['ma'].info.serialize_method['fits'] == 'nonsense'
 
-    @pytest.mark.skipif(not HAS_YAML, reason='serialization needs yaml')
     @pytest.mark.parametrize('file_format', FILE_FORMATS)
     def test_table_write(self, file_format, tmpdir):
         name = str(tmpdir.join(f"a.{file_format}"))
@@ -86,7 +85,6 @@ class TestMaskedArrayTable(MaskedArrayTableSetup):
         else:
             assert t2['ma'].info.format == self.t['ma'].info.format
 
-    @pytest.mark.skipif(not HAS_YAML, reason='serialization needs yaml')
     @pytest.mark.parametrize('serialize_method', ['data_mask', 'null_value'])
     def test_table_write_serialization(self, serialize_method, tmpdir):
         name = str(tmpdir.join("test.ecsv"))
