@@ -379,10 +379,8 @@ def test_download_with_sources_and_bogus_original(
         assert is_url_in_cache(u)
 
 
-@pytest.mark.skipif((3, 7) <= sys.version_info < (3, 8) or
-                    (sys.platform.startswith('win') and CI),
-                    reason="mystery segfault that is possibly bug #10008 "
-                           "for python < 3.8, flaky cache error on Windows CI")
+@pytest.mark.skipif((sys.platform.startswith('win') and CI),
+                    reason="flaky cache error on Windows CI")
 def test_download_file_threaded_many(temp_cache, valid_urls):
     """Hammer download_file with multiple threaded requests.
 
@@ -400,10 +398,8 @@ def test_download_file_threaded_many(temp_cache, valid_urls):
         assert get_file_contents(r) == c
 
 
-@pytest.mark.skipif((3, 7) <= sys.version_info < (3, 8) or
-                    (sys.platform.startswith('win') and CI),
-                    reason="mystery segfault that is possibly bug #10008 "
-                           "for python < 3.8, flaky cache error on Windows CI")
+@pytest.mark.skipif((sys.platform.startswith('win') and CI),
+                    reason="flaky cache error on Windows CI")
 def test_threaded_segfault(valid_urls):
     """Demonstrate urllib's segfault."""
     def slurp_url(u):
@@ -418,10 +414,8 @@ def test_threaded_segfault(valid_urls):
                    [u for (u, c) in urls]))
 
 
-@pytest.mark.skipif((3, 7) <= sys.version_info < (3, 8) or
-                    (sys.platform.startswith('win') and CI),
-                    reason="mystery segfault that is possibly bug #10008 "
-                           "for python < 3.8, flaky cache error on Windows CI")
+@pytest.mark.skipif((sys.platform.startswith('win') and CI),
+                    reason="flaky cache error on Windows CI")
 def test_download_file_threaded_many_partial_success(
         temp_cache, valid_urls, invalid_urls):
     """Hammer download_file with multiple threaded requests.
@@ -841,10 +835,8 @@ def test_download_parallel_update(temp_cache, tmpdir):
         assert get_file_contents(r_3) == c_plus
 
 
-@pytest.mark.skipif(sys.version_info < (3, 8) or
-                    (sys.platform.startswith('win') and CI),
-                    reason="mystery segfault that is possibly bug #10008 "
-                           "for python < 3.8, flaky cache error on Windows CI")
+@pytest.mark.skipif((sys.platform.startswith('win') and CI),
+                    reason="flaky cache error on Windows CI")
 def test_update_parallel(temp_cache, valid_urls):
     u, c = next(valid_urls)
     u2, c2 = next(valid_urls)
@@ -863,10 +855,8 @@ def test_update_parallel(temp_cache, valid_urls):
         assert get_file_contents(f) == c2
 
 
-@pytest.mark.skipif(sys.version_info < (3, 8) or
-                    (sys.platform.startswith('win') and CI),
-                    reason="mystery segfault that is possibly bug #10008 "
-                           "for python < 3.8, flaky cache error on Windows CI")
+@pytest.mark.skipif((sys.platform.startswith('win') and CI),
+                    reason="flaky cache error on Windows CI")
 def test_update_parallel_multi(temp_cache, valid_urls):
     u, c = next(valid_urls)
     iucs = list(islice(valid_urls, N_THREAD_HAMMER))
@@ -1088,8 +1078,6 @@ def test_data_noastropy_fallback(monkeypatch):
         fnout = download_file(TESTURL, cache=True)
     n_warns = len(warning_lines)
 
-    assert n_warns in (2, 4), f'Expected 2 or 4 warnings, got {n_warns}'
-
     partial_warn_msgs = ['remote data cache could not be accessed', 'temporary file']
     if n_warns == 4:
         partial_warn_msgs.extend(['socket', 'socket'])
@@ -1102,6 +1090,8 @@ def test_data_noastropy_fallback(monkeypatch):
                 break
     assert len(partial_warn_msgs) == 0, f'Got some unexpected warnings: {partial_warn_msgs}'
 
+    assert n_warns in (2, 4), f'Expected 2 or 4 warnings, got {n_warns}'
+
     assert os.path.isfile(fnout)
 
     # clearing the cache should be a no-up that doesn't affect fnout
@@ -2082,16 +2072,6 @@ def test_update_of_open_files_windows(temp_cache, valid_urls, monkeypatch):
     assert get_file_contents(download_file(u, cache=True, sources=[])) == c
 
 
-def test_zero_remote_timeout(temp_cache, valid_urls):
-    u, c = next(valid_urls)
-    with pytest.raises(urllib.error.URLError):
-        download_file(u, timeout=0)
-    assert not is_url_in_cache(u)
-    with pytest.raises(urllib.error.URLError):
-        # This will trigger the remote data error if it's allowed to touch the internet
-        download_file(TESTURL, timeout=0)
-
-
 def test_no_allow_internet(temp_cache, valid_urls):
     u, c = next(valid_urls)
     with conf.set_temp('allow_internet', False):
