@@ -5,10 +5,11 @@ from collections import namedtuple
 from unittest import mock
 
 import pytest
+import yaml
 
 from astropy.utils import introspection
 from astropy.utils.introspection import (find_current_module, find_mod_objs,
-                             isinstancemethod, minversion)
+                                         minversion)
 
 
 def test_pkg_finder():
@@ -65,15 +66,18 @@ def test_find_mod_objs():
 
 
 def test_minversion():
-    from types import ModuleType
-    test_module = ModuleType("test_module")
-    test_module.__version__ = '0.12.2'
-    good_versions = ['0.12', '0.12.1', '0.12.0.dev', '0.12dev']
-    bad_versions = ['1', '1.2rc1']
+    import numpy
+    good_versions = ['1.16', '1.16.1', '1.16.0.dev', '1.16dev']
+    bad_versions = ['100000', '100000.2rc1']
     for version in good_versions:
-        assert minversion(test_module, version)
+        assert minversion(numpy, version)
+        assert minversion("numpy", version)
     for version in bad_versions:
-        assert not minversion(test_module, version)
+        assert not minversion(numpy, version)
+        assert not minversion("numpy", version)
+
+    assert minversion(yaml, '3.1')
+    assert minversion('yaml', '3.1')
 
 
 def test_find_current_module_bundle():
