@@ -19,7 +19,7 @@ def wrap_180(values):
     return values_new
 
 
-def find_coordinate_range(transform, extent, coord_types, coord_units):
+def find_coordinate_range(transform, extent, coord_types, coord_units, coord_wraps):
     """
     Find the range of coordinates to use for ticks/grids
 
@@ -36,17 +36,24 @@ def find_coordinate_range(transform, extent, coord_types, coord_units):
         Whether each coordinate is a ``'longitude'``, ``'latitude'``, or
         ``'scalar'`` value.
     coord_units : list of `astropy.units.Unit`
-        The units for each coordinate
+        The units for each coordinate.
+    coord_wraps : list of float
+        The wrap angles for longitudes.
     """
-
     # Sample coordinates on a NX x NY grid.
     from . import conf
-    nx = ny = conf.coordinate_range_samples
-    x = np.linspace(extent[0], extent[1], nx + 1)
-    y = np.linspace(extent[2], extent[3], ny + 1)
-    xp, yp = np.meshgrid(x, y)
-    with np.errstate(invalid='ignore'):
-        world = transform.transform(np.vstack([xp.ravel(), yp.ravel()]).transpose())
+    if len(extent) == 4:
+        nx = ny = conf.coordinate_range_samples
+        x = np.linspace(extent[0], extent[1], nx + 1)
+        y = np.linspace(extent[2], extent[3], ny + 1)
+        xp, yp = np.meshgrid(x, y)
+        with np.errstate(invalid='ignore'):
+            world = transform.transform(np.vstack([xp.ravel(), yp.ravel()]).transpose())
+    else:
+        nx = conf.coordinate_range_samples
+        xp = np.linspace(extent[0], extent[1], nx + 1)[None]
+        with np.errstate(invalid='ignore'):
+            world = transform.transform(xp.T)
 
     ranges = []
 
@@ -111,8 +118,8 @@ def find_coordinate_range(transform, extent, coord_types, coord_units):
         x_range = xw_max - xw_min
         if coord_type == 'longitude':
             if x_range > 300.:
-                xw_min = 0.
-                xw_max = 360 - np.spacing(360.)
+                xw_min = coord_wraps[coord_index] - 360
+                xw_max = coord_wraps[coord_index] - np.spacing(360.)
             elif xw_min < 0.:
                 xw_min = max(-180., xw_min - 0.1 * x_range)
                 xw_max = min(+180., xw_max + 0.1 * x_range)
