@@ -8,7 +8,6 @@ import numpy as np
 import astropy.units as u
 from astropy.coordinates import FK5, SkyCoord
 from astropy.io import fits
-from astropy.tests.image_tests import ignore_matplotlibrc
 from astropy.time import Time
 from astropy.utils.data import get_pkg_data_filename
 from astropy.visualization.wcsaxes.core import WCSAxes
@@ -23,8 +22,7 @@ class TestDisplayWorldCoordinate(BaseImageTests):
     def teardown_method(self, method):
         plt.close('all')
 
-    @ignore_matplotlibrc
-    def test_overlay_coords(self, tmpdir):
+    def test_overlay_coords(self, ignore_matplotlibrc, tmpdir):
         wcs = WCS(self.msx_header)
 
         fig = plt.figure(figsize=(4, 4))
@@ -104,8 +102,7 @@ class TestDisplayWorldCoordinate(BaseImageTests):
 
         assert string_world5 == '267.652\xb0 -28\xb046\'23" (world, overlay 3)'
 
-    @ignore_matplotlibrc
-    def test_cube_coords(self, tmpdir):
+    def test_cube_coords(self, ignore_matplotlibrc, tmpdir):
         wcs = WCS(self.cube_header)
 
         fig = plt.figure(figsize=(4, 4))
@@ -128,8 +125,7 @@ class TestDisplayWorldCoordinate(BaseImageTests):
         string_pixel = ax._display_world_coords(0.523412, 0.523412)
         assert string_pixel == "0.523412 0.523412 (pixel)"
 
-    @ignore_matplotlibrc
-    def test_cube_coords_uncorr_slicing(self, tmpdir):
+    def test_cube_coords_uncorr_slicing(self, ignore_matplotlibrc, tmpdir):
 
         # Regression test for a bug that occurred with coordinate formatting if
         # some dimensions were uncorrelated and sliced out.
