@@ -7,7 +7,8 @@ import numpy as np
 import pytest
 from numpy.testing import assert_array_almost_equal
 
-from astropy.utils.data import get_pkg_data_contents, get_pkg_data_fileobj
+from astropy.utils.data import (get_pkg_data_contents, get_pkg_data_fileobj,
+                                get_pkg_data_filename)
 from astropy.utils.exceptions import AstropyDeprecationWarning
 from astropy.utils.misc import NumpyRNGContext
 from astropy.io import fits
@@ -19,8 +20,7 @@ from astropy.wcs.wcs import FITSFixedWarning
 def test_basic():
     wcs1 = wcs.WCS()
     s = pickle.dumps(wcs1)
-    with pytest.warns(FITSFixedWarning):
-        pickle.loads(s)
+    pickle.loads(s)
 
 
 def test_dist():
@@ -33,8 +33,7 @@ def test_dist():
         assert wcs1.det2im2 is not None
 
         s = pickle.dumps(wcs1)
-        with pytest.warns(FITSFixedWarning):
-            wcs2 = pickle.loads(s)
+        wcs2 = pickle.loads(s)
 
         with NumpyRNGContext(123456789):
             x = np.random.rand(2 ** 16, wcs1.wcs.naxis)
@@ -52,8 +51,7 @@ def test_sip():
             wcs1 = wcs.WCS(hdulist[0].header)
         assert wcs1.sip is not None
         s = pickle.dumps(wcs1)
-        with pytest.warns(FITSFixedWarning):
-            wcs2 = pickle.loads(s)
+        wcs2 = pickle.loads(s)
 
         with NumpyRNGContext(123456789):
             x = np.random.rand(2 ** 16, wcs1.wcs.naxis)
@@ -71,8 +69,7 @@ def test_sip2():
             wcs1 = wcs.WCS(hdulist[0].header)
         assert wcs1.sip is not None
         s = pickle.dumps(wcs1)
-        with pytest.warns(FITSFixedWarning):
-            wcs2 = pickle.loads(s)
+        wcs2 = pickle.loads(s)
 
         with NumpyRNGContext(123456789):
             x = np.random.rand(2 ** 16, wcs1.wcs.naxis)
@@ -90,8 +87,7 @@ def test_wcs():
 
     wcs1 = wcs.WCS(header)
     s = pickle.dumps(wcs1)
-    with pytest.warns(FITSFixedWarning):
-        wcs2 = pickle.loads(s)
+    wcs2 = pickle.loads(s)
 
     with NumpyRNGContext(123456789):
         x = np.random.rand(2 ** 16, wcs1.wcs.naxis)
@@ -103,16 +99,62 @@ def test_wcs():
 
 class Sub(wcs.WCS):
     def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         self.foo = 42
 
 
 def test_subclass():
-    wcs = Sub()
-    s = pickle.dumps(wcs)
-    with pytest.warns(FITSFixedWarning):
-        wcs2 = pickle.loads(s)
+    wcs1 = Sub()
+    wcs1.foo = 45
+    s = pickle.dumps(wcs1)
+    wcs2 = pickle.loads(s)
 
     assert isinstance(wcs2, Sub)
-    assert wcs.foo == 42
-    assert wcs2.foo == 42
+    assert wcs1.foo == 45
+    assert wcs2.foo == 45
     assert wcs2.wcs is not None
+
+
+def test_axes_info():
+    w = wcs.WCS(naxis=3)
+    w.pixel_shape = [100, 200, 300]
+    w.pixel_bounds = ((11, 22), (33, 45), (55, 67))
+    w.extra = 111
+
+    w2 = pickle.loads(pickle.dumps(w))
+
+    # explicitly test naxis-related info
+    assert w.naxis == w2.naxis
+    assert w.pixel_shape == w2.pixel_shape
+    assert w.pixel_bounds == w2.pixel_bounds
+
+    # test all attributes
+    for k, v in w.__dict__.items():
+        assert getattr(w2, k) == v
+
+
+def test_pixlist_wcs_colsel():
+    """
+    Test selection of a specific pixel list WCS using ``colsel``. See #11412.
+    """
+    hdr_file = get_pkg_data_filename('data/chandra-pixlist-wcs.hdr')
+    hdr = fits.Header.fromtextfile(hdr_file)
+    with pytest.warns(wcs.FITSFixedWarning):
+        w0 = wcs.WCS(hdr, keysel=['image', 'pixel'], colsel=[11, 12])
+
+    with pytest.warns(wcs.FITSFixedWarning):
+        w = pickle.loads(pickle.dumps(w0))
+
+    assert w.naxis == 2
+    assert list(w.wcs.ctype) == ['RA---TAN', 'DEC--TAN']
+    assert np.allclose(w.wcs.crval, [229.38051931869, -58.81108068885])
+    assert np.allclose(w.wcs.pc, [[1, 0], [0, 1]])
+    assert np.allclose(w.wcs.cdelt, [-0.00013666666666666, 0.00013666666666666])
+    assert np.allclose(w.wcs.lonpole, 180.)
+
+
+def test_alt_wcskey():
+    w = wcs.WCS(key='A')
+    w2 = pickle.loads(pickle.dumps(w))
+
+    assert w2.wcs.alt == 'A'
