@@ -98,10 +98,14 @@ CTYPE_TO_UCD1 = {
     'TLAT': 'pos.bodyrc.lat',
     'HPLT': 'custom:pos.helioprojective.lat',
     'HPLN': 'custom:pos.helioprojective.lon',
+    'HPRZ': 'custom:pos.helioprojective.z',
     'HGLN': 'custom:pos.heliographic.stonyhurst.lon',
     'HGLT': 'custom:pos.heliographic.stonyhurst.lat',
     'CRLN': 'custom:pos.heliographic.carrington.lon',
     'CRLT': 'custom:pos.heliographic.carrington.lat',
+    'SOLX': 'custom:pos.heliocentric.x',
+    'SOLY': 'custom:pos.heliocentric.y',
+    'SOLZ': 'custom:pos.heliocentric.z',
 
     # Spectral coordinates (WCS paper 3)
     'FREQ': 'em.freq',  # Frequency
@@ -114,6 +118,7 @@ CTYPE_TO_UCD1 = {
     'AWAV': 'em.wl',  # Air wavelength
     'VELO': 'spect.dopplerVeloc',  # Apparent radial velocity
     'BETA': 'custom:spect.doplerVeloc.beta',  # Beta factor (v/c)
+    'STOKES': 'phys.polarization.stokes',  # STOKES parameters
 
     # Time coordinates (https://www.aanda.org/articles/aa/pdf/2015/02/aa24653-14.pdf)
     'TIME': 'time',
@@ -129,7 +134,11 @@ CTYPE_TO_UCD1 = {
     'TCG': 'time',
     'TCB': 'time',
     'TDB': 'time',
-    'LOCAL': 'time'
+    'LOCAL': 'time',
+
+    # Distance coordinates
+    'DIST': 'pos.distance',
+    'DSUN': 'custom:pos.distance.sunToObserver'
 
     # UT() and TT() are handled separately in world_axis_physical_types
 
@@ -482,6 +491,8 @@ class FITSWCSAPIMixin(BaseLowLevelWCS, HighLevelWCSMixin):
             if ctype == 'ZOPT':
 
                 def spectralcoord_from_redshift(redshift):
+                    if isinstance(redshift, SpectralCoord):
+                        return redshift
                     return SpectralCoord((redshift + 1) * self.wcs.restwav,
                                          unit=u.m, observer=observer, target=target)
 
@@ -493,7 +504,7 @@ class FITSWCSAPIMixin(BaseLowLevelWCS, HighLevelWCSMixin):
                                       'frame change', AstropyUserWarning)
                         return spectralcoord.to_value(u.m) / self.wcs.restwav - 1.
                     else:
-                        return spectralcoord.in_observer_velocity_frame(observer).to_value(u.m) / self.wcs.restwav - 1.
+                        return spectralcoord.with_observer_stationary_relative_to(observer).to_value(u.m) / self.wcs.restwav - 1.
 
                 classes['spectral'] = (u.Quantity, (), {}, spectralcoord_from_redshift)
                 components[self.wcs.spec] = ('spectral', 0, redshift_from_spectralcoord)
@@ -501,6 +512,8 @@ class FITSWCSAPIMixin(BaseLowLevelWCS, HighLevelWCSMixin):
             elif ctype == 'BETA':
 
                 def spectralcoord_from_beta(beta):
+                    if isinstance(beta, SpectralCoord):
+                        return beta
                     return SpectralCoord(beta * C_SI,
                                          unit=u.m / u.s,
                                          doppler_convention='relativistic',
@@ -516,7 +529,7 @@ class FITSWCSAPIMixin(BaseLowLevelWCS, HighLevelWCSMixin):
                                       'frame change', AstropyUserWarning)
                         return spectralcoord.to_value(u.m / u.s, doppler_equiv) / C_SI
                     else:
-                        return spectralcoord.in_observer_velocity_frame(observer).to_value(u.m / u.s, doppler_equiv) / C_SI
+                        return spectralcoord.with_observer_stationary_relative_to(observer).to_value(u.m / u.s, doppler_equiv) / C_SI
 
                 classes['spectral'] = (u.Quantity, (), {}, spectralcoord_from_beta)
                 components[self.wcs.spec] = ('spectral', 0, beta_from_spectralcoord)
@@ -547,7 +560,7 @@ class FITSWCSAPIMixin(BaseLowLevelWCS, HighLevelWCSMixin):
                                       'frame change', AstropyUserWarning)
                         return spectralcoord.to_value(**kwargs)
                     else:
-                        return spectralcoord.in_observer_velocity_frame(observer).to_value(**kwargs)
+                        return spectralcoord.with_observer_stationary_relative_to(observer).to_value(**kwargs)
 
                 classes['spectral'] = (u.Quantity, (), {}, spectralcoord_from_value)
                 components[self.wcs.spec] = ('spectral', 0, value_from_spectralcoord)
