@@ -11,11 +11,9 @@ def test_validate_physical_types():
     validate_physical_types(['time', None])
 
     # Make sure validation is case sensitive
-    with raises(ValueError) as exc:
+    with raises(ValueError, match=r"'Pos\.eq\.dec' is not a valid IOVA UCD1\+ physical type"):
         validate_physical_types(['pos.eq.ra', 'Pos.eq.dec'])
-    assert exc.value.args[0] == 'Invalid physical type: Pos.eq.dec'
 
     # Make sure nonsense types are picked up
-    with raises(ValueError) as exc:
+    with raises(ValueError, match=r"'spam' is not a valid IOVA UCD1\+ physical type"):
         validate_physical_types(['spam'])
-    assert exc.value.args[0] == 'Invalid physical type: spam'
