@@ -88,7 +88,7 @@ with open('large.fits', 'rb+') as fobj:
 ##############################################################################
 # More generally, this can be written:
 
-shape = tuple(header['NAXIS{0}'.format(ii)] for ii in range(1, header['NAXIS']+1))
+shape = tuple(header[f'NAXIS{ii}'] for ii in range(1, header['NAXIS']+1))
 with open('large.fits', 'rb+') as fobj:
     fobj.seek(len(header.tostring()) + (np.product(shape) * np.abs(header['BITPIX']//8)) - 1)
     fobj.write(b'\0')
